AnimationNodeAnimation

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 24, 2026 License: MIT Imports: 29 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Advanced

type Advanced = class

Advanced exposes a 1:1 low-level instance of the class, undocumented, for those who know what they are doing.

type Any

type Any interface {
	gd.IsClass
	AsAnimationNodeAnimation() Instance
}

type Extension

type Extension[T gdclass.Interface] struct{ gdclass.Extension[T, Instance] }

Extension can be embedded in a new struct to create a Go extension of this class.

T must be a type that is embedding this Extension as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.

func (*Extension[T]) AddInput

func (o *Extension[T]) AddInput(name string) bool

AddInput is promoted from AnimationNode.Instance.AddInput.

func (*Extension[T]) AdvanceOnStart

func (o *Extension[T]) AdvanceOnStart() bool

func (*Extension[T]) Animation

func (o *Extension[T]) Animation() string

func (*Extension[T]) AsAnimationNode

func (o *Extension[T]) AsAnimationNode() AnimationNode.Instance

func (*Extension[T]) AsAnimationNodeAnimation

func (o *Extension[T]) AsAnimationNodeAnimation() Instance

func (*Extension[T]) AsAnimationRootNode

func (o *Extension[T]) AsAnimationRootNode() AnimationRootNode.Instance

func (*Extension[T]) AsObject

func (o *Extension[T]) AsObject() [1]gdreference.Object

func (*Extension[T]) AsRefCounted

func (o *Extension[T]) AsRefCounted() ie.RC

func (*Extension[T]) AsResource

func (o *Extension[T]) AsResource() Resource.Instance

func (*Extension[T]) EmitChanged

func (o *Extension[T]) EmitChanged()

EmitChanged is promoted from Resource.Instance.EmitChanged.

func (*Extension[T]) FilterEnabled

func (o *Extension[T]) FilterEnabled() bool

func (*Extension[T]) FindInput

func (o *Extension[T]) FindInput(name string) int

FindInput is promoted from AnimationNode.Instance.FindInput.

func (*Extension[T]) GetIdForPath

func (o *Extension[T]) GetIdForPath(path string) string

GetIdForPath is promoted from Resource.Instance.GetIdForPath.

func (*Extension[T]) GetInputCount

func (o *Extension[T]) GetInputCount() int

GetInputCount is promoted from AnimationNode.Instance.GetInputCount.

func (*Extension[T]) GetInputName

func (o *Extension[T]) GetInputName(input int) string

GetInputName is promoted from AnimationNode.Instance.GetInputName.

func (*Extension[T]) GetParameter

func (o *Extension[T]) GetParameter(name string) any

GetParameter is promoted from AnimationNode.Instance.GetParameter.

func (*Extension[T]) GetProcessingAnimationTreeInstanceId

func (o *Extension[T]) GetProcessingAnimationTreeInstanceId() int

GetProcessingAnimationTreeInstanceId is promoted from AnimationNode.Instance.GetProcessingAnimationTreeInstanceId.

func (*Extension[T]) GetRid

func (o *Extension[T]) GetRid() Resource.ID

GetRid is promoted from Resource.Instance.GetRid.

func (*Extension[T]) IsBuiltIn

func (o *Extension[T]) IsBuiltIn() bool

IsBuiltIn is promoted from Resource.Instance.IsBuiltIn.

func (*Extension[T]) IsPathFiltered

func (o *Extension[T]) IsPathFiltered(path string) bool

IsPathFiltered is promoted from AnimationNode.Instance.IsPathFiltered.

func (*Extension[T]) IsProcessTesting

func (o *Extension[T]) IsProcessTesting() bool

IsProcessTesting is promoted from AnimationNode.Instance.IsProcessTesting.

func (*Extension[T]) LoopMode

func (o *Extension[T]) LoopMode() Animation.LoopMode

func (*Extension[T]) OnAnimationNodeRemoved

func (o *Extension[T]) OnAnimationNodeRemoved(cb func(object_id int, name string), flags ...Signal.Flags) *Extension[T]

OnAnimationNodeRemoved is promoted from AnimationNode.Instance.OnAnimationNodeRemoved.

func (*Extension[T]) OnAnimationNodeRenamed

func (o *Extension[T]) OnAnimationNodeRenamed(cb func(object_id int, old_name string, new_name string), flags ...Signal.Flags) *Extension[T]

OnAnimationNodeRenamed is promoted from AnimationNode.Instance.OnAnimationNodeRenamed.

func (*Extension[T]) OnChanged

func (o *Extension[T]) OnChanged(cb func(), flags ...Signal.Flags) *Extension[T]

OnChanged is promoted from Resource.Instance.OnChanged.

func (*Extension[T]) OnSetupLocalToSceneRequested

func (o *Extension[T]) OnSetupLocalToSceneRequested(cb func(), flags ...Signal.Flags) *Extension[T]

OnSetupLocalToSceneRequested is promoted from Resource.Instance.OnSetupLocalToSceneRequested.

func (*Extension[T]) OnTreeChanged

func (o *Extension[T]) OnTreeChanged(cb func(), flags ...Signal.Flags) *Extension[T]

OnTreeChanged is promoted from AnimationNode.Instance.OnTreeChanged.

func (*Extension[T]) PlayMode

func (o *Extension[T]) PlayMode() PlayMode

func (*Extension[T]) RemoveInput

func (o *Extension[T]) RemoveInput(index int)

RemoveInput is promoted from AnimationNode.Instance.RemoveInput.

func (*Extension[T]) ResetState

func (o *Extension[T]) ResetState()

ResetState is promoted from Resource.Instance.ResetState.

func (*Extension[T]) ResourceLocalToScene

func (o *Extension[T]) ResourceLocalToScene() bool

func (*Extension[T]) ResourceName

func (o *Extension[T]) ResourceName() string

func (*Extension[T]) ResourcePath

func (o *Extension[T]) ResourcePath() string

func (*Extension[T]) ResourceSceneUniqueId

func (o *Extension[T]) ResourceSceneUniqueId() string

func (*Extension[T]) SetAdvanceOnStart

func (o *Extension[T]) SetAdvanceOnStart(value bool) *Extension[T]

func (*Extension[T]) SetAnimation

func (o *Extension[T]) SetAnimation(value string) *Extension[T]

func (*Extension[T]) SetFilterEnabled

func (o *Extension[T]) SetFilterEnabled(value bool) *Extension[T]

func (*Extension[T]) SetFilterPath

func (o *Extension[T]) SetFilterPath(path string, enable bool) *Extension[T]

SetFilterPath is promoted from AnimationNode.Instance.SetFilterPath.

func (*Extension[T]) SetIdForPath

func (o *Extension[T]) SetIdForPath(path string, id string) *Extension[T]

SetIdForPath is promoted from Resource.Instance.SetIdForPath.

func (*Extension[T]) SetInputName

func (o *Extension[T]) SetInputName(input int, name string) bool

SetInputName is promoted from AnimationNode.Instance.SetInputName.

func (*Extension[T]) SetLoopMode

func (o *Extension[T]) SetLoopMode(value Animation.LoopMode) *Extension[T]

func (*Extension[T]) SetParameter

func (o *Extension[T]) SetParameter(name string, value any) *Extension[T]

SetParameter is promoted from AnimationNode.Instance.SetParameter.

func (*Extension[T]) SetPathCache

func (o *Extension[T]) SetPathCache(path string) *Extension[T]

SetPathCache is promoted from Resource.Instance.SetPathCache.

func (*Extension[T]) SetPlayMode

func (o *Extension[T]) SetPlayMode(value PlayMode) *Extension[T]

func (*Extension[T]) SetResourceLocalToScene

func (o *Extension[T]) SetResourceLocalToScene(value bool) *Extension[T]

func (*Extension[T]) SetResourceName

func (o *Extension[T]) SetResourceName(value string) *Extension[T]

func (*Extension[T]) SetResourcePath

func (o *Extension[T]) SetResourcePath(value string) *Extension[T]

func (*Extension[T]) SetResourceSceneUniqueId

func (o *Extension[T]) SetResourceSceneUniqueId(value string) *Extension[T]

func (*Extension[T]) SetStartOffset

func (o *Extension[T]) SetStartOffset(value Float.X) *Extension[T]

func (*Extension[T]) SetStretchTimeScale

func (o *Extension[T]) SetStretchTimeScale(value bool) *Extension[T]

func (*Extension[T]) SetTimelineLength

func (o *Extension[T]) SetTimelineLength(value Float.X) *Extension[T]

func (*Extension[T]) SetUseCustomTimeline

func (o *Extension[T]) SetUseCustomTimeline(value bool) *Extension[T]

func (*Extension[T]) SetupLocalToScene

func (o *Extension[T]) SetupLocalToScene()

SetupLocalToScene is promoted from Resource.Instance.SetupLocalToScene.

func (*Extension[T]) StartOffset

func (o *Extension[T]) StartOffset() Float.X

func (*Extension[T]) StretchTimeScale

func (o *Extension[T]) StretchTimeScale() bool

func (*Extension[T]) TakeOverPath

func (o *Extension[T]) TakeOverPath(path string)

TakeOverPath is promoted from Resource.Instance.TakeOverPath.

func (*Extension[T]) TimelineLength

func (o *Extension[T]) TimelineLength() Float.X

func (*Extension[T]) UseCustomTimeline

func (o *Extension[T]) UseCustomTimeline() bool

type ID

type ID Object.ID

ID is a typed object ID (reference) to an instance of this class, use it to store references to objects with unknown lifetimes, as an ID will not panic on use if the underlying object has been destroyed.

func (ID) Instance

func (id ID) Instance() (Instance, bool)

type Instance

type Instance [1]gdclass.AnimationNodeAnimation

Instance of the class with convieniently typed arguments and results.

var Nil Instance

Nil is a nil/null instance of the class. Equivalent to the zero value.

func New

func New() Instance

func (Instance) AddInput

func (self Instance) AddInput(name string) bool

AddInput is promoted from AnimationNode.Instance.AddInput.

func (Instance) AdvanceOnStart

func (self Instance) AdvanceOnStart() bool

func (Instance) Animation

func (self Instance) Animation() string

func (Instance) AsAnimationNode

func (o Instance) AsAnimationNode() AnimationNode.Instance

func (Instance) AsAnimationNodeAnimation

func (o Instance) AsAnimationNodeAnimation() Instance

func (Instance) AsAnimationRootNode

func (o Instance) AsAnimationRootNode() AnimationRootNode.Instance

func (Instance) AsObject

func (o Instance) AsObject() [1]gdreference.Object

func (Instance) AsRefCounted

func (o Instance) AsRefCounted() ie.RC

func (Instance) AsResource

func (o Instance) AsResource() Resource.Instance

func (Instance) EmitChanged

func (self Instance) EmitChanged()

EmitChanged is promoted from Resource.Instance.EmitChanged.

func (Instance) FilterEnabled

func (self Instance) FilterEnabled() bool

FilterEnabled is promoted from AnimationNode.Instance.FilterEnabled.

func (Instance) FindInput

func (self Instance) FindInput(name string) int

FindInput is promoted from AnimationNode.Instance.FindInput.

func (Instance) GetIdForPath

func (self Instance) GetIdForPath(path string) string

GetIdForPath is promoted from Resource.Instance.GetIdForPath.

func (Instance) GetInputCount

func (self Instance) GetInputCount() int

GetInputCount is promoted from AnimationNode.Instance.GetInputCount.

func (Instance) GetInputName

func (self Instance) GetInputName(input int) string

GetInputName is promoted from AnimationNode.Instance.GetInputName.

func (Instance) GetParameter

func (self Instance) GetParameter(name string) any

GetParameter is promoted from AnimationNode.Instance.GetParameter.

func (Instance) GetProcessingAnimationTreeInstanceId

func (self Instance) GetProcessingAnimationTreeInstanceId() int

GetProcessingAnimationTreeInstanceId is promoted from AnimationNode.Instance.GetProcessingAnimationTreeInstanceId.

func (Instance) GetRid

func (self Instance) GetRid() Resource.ID

GetRid is promoted from Resource.Instance.GetRid.

func (Instance) ID

func (self Instance) ID() ID

func (Instance) IsBuiltIn

func (self Instance) IsBuiltIn() bool

IsBuiltIn is promoted from Resource.Instance.IsBuiltIn.

func (Instance) IsPathFiltered

func (self Instance) IsPathFiltered(path string) bool

IsPathFiltered is promoted from AnimationNode.Instance.IsPathFiltered.

func (Instance) IsProcessTesting

func (self Instance) IsProcessTesting() bool

IsProcessTesting is promoted from AnimationNode.Instance.IsProcessTesting.

func (Instance) LoopMode

func (self Instance) LoopMode() Animation.LoopMode

func (Instance) OnAnimationNodeRemoved

func (self Instance) OnAnimationNodeRemoved(cb func(object_id int, name string), flags ...Signal.Flags) Instance

OnAnimationNodeRemoved is promoted from AnimationNode.Instance.OnAnimationNodeRemoved.

func (Instance) OnAnimationNodeRenamed

func (self Instance) OnAnimationNodeRenamed(cb func(object_id int, old_name string, new_name string), flags ...Signal.Flags) Instance

OnAnimationNodeRenamed is promoted from AnimationNode.Instance.OnAnimationNodeRenamed.

func (Instance) OnChanged

func (self Instance) OnChanged(cb func(), flags ...Signal.Flags) Instance

OnChanged is promoted from Resource.Instance.OnChanged.

func (Instance) OnSetupLocalToSceneRequested

func (self Instance) OnSetupLocalToSceneRequested(cb func(), flags ...Signal.Flags) Instance

OnSetupLocalToSceneRequested is promoted from Resource.Instance.OnSetupLocalToSceneRequested.

func (Instance) OnTreeChanged

func (self Instance) OnTreeChanged(cb func(), flags ...Signal.Flags) Instance

OnTreeChanged is promoted from AnimationNode.Instance.OnTreeChanged.

func (Instance) PlayMode

func (self Instance) PlayMode() PlayMode

func (Instance) RemoveInput

func (self Instance) RemoveInput(index int)

RemoveInput is promoted from AnimationNode.Instance.RemoveInput.

func (Instance) ResetState

func (self Instance) ResetState()

ResetState is promoted from Resource.Instance.ResetState.

func (Instance) ResourceLocalToScene

func (self Instance) ResourceLocalToScene() bool

ResourceLocalToScene is promoted from Resource.Instance.ResourceLocalToScene.

func (Instance) ResourceName

func (self Instance) ResourceName() string

ResourceName is promoted from Resource.Instance.ResourceName.

func (Instance) ResourcePath

func (self Instance) ResourcePath() string

ResourcePath is promoted from Resource.Instance.ResourcePath.

func (Instance) ResourceSceneUniqueId

func (self Instance) ResourceSceneUniqueId() string

ResourceSceneUniqueId is promoted from Resource.Instance.ResourceSceneUniqueId.

func (Instance) SetAdvanceOnStart

func (self Instance) SetAdvanceOnStart(value bool) Instance

SetAdvanceOnStart sets the property returned by [IsAdvanceOnStart]. Returns the instance, so that property settings can be chained.

func (Instance) SetAnimation

func (self Instance) SetAnimation(value string) Instance

SetAnimation sets the property returned by [GetAnimation]. Returns the instance, so that property settings can be chained.

func (Instance) SetFilterEnabled

func (self Instance) SetFilterEnabled(value bool) Instance

SetFilterEnabled is promoted from AnimationNode.Instance.SetFilterEnabled.

func (Instance) SetFilterPath

func (self Instance) SetFilterPath(path string, enable bool) Instance

SetFilterPath is promoted from AnimationNode.Instance.SetFilterPath.

func (Instance) SetIdForPath

func (self Instance) SetIdForPath(path string, id string) Instance

SetIdForPath is promoted from Resource.Instance.SetIdForPath.

func (Instance) SetInputName

func (self Instance) SetInputName(input int, name string) bool

SetInputName is promoted from AnimationNode.Instance.SetInputName.

func (Instance) SetLoopMode

func (self Instance) SetLoopMode(value Animation.LoopMode) Instance

SetLoopMode sets the property returned by [GetLoopMode]. Returns the instance, so that property settings can be chained.

func (*Instance) SetObject

func (self *Instance) SetObject(obj [1]gdreference.Object) bool

func (Instance) SetParameter

func (self Instance) SetParameter(name string, value any) Instance

SetParameter is promoted from AnimationNode.Instance.SetParameter.

func (Instance) SetPathCache

func (self Instance) SetPathCache(path string) Instance

SetPathCache is promoted from Resource.Instance.SetPathCache.

func (Instance) SetPlayMode

func (self Instance) SetPlayMode(value PlayMode) Instance

SetPlayMode sets the property returned by [GetPlayMode]. Returns the instance, so that property settings can be chained.

func (Instance) SetResourceLocalToScene

func (self Instance) SetResourceLocalToScene(value bool) Instance

SetResourceLocalToScene is promoted from Resource.Instance.SetResourceLocalToScene.

func (Instance) SetResourceName

func (self Instance) SetResourceName(value string) Instance

SetResourceName is promoted from Resource.Instance.SetResourceName.

func (Instance) SetResourcePath

func (self Instance) SetResourcePath(value string) Instance

SetResourcePath is promoted from Resource.Instance.SetResourcePath.

func (Instance) SetResourceSceneUniqueId

func (self Instance) SetResourceSceneUniqueId(value string) Instance

SetResourceSceneUniqueId is promoted from Resource.Instance.SetResourceSceneUniqueId.

func (Instance) SetStartOffset

func (self Instance) SetStartOffset(value Float.X) Instance

SetStartOffset sets the property returned by [GetStartOffset]. Returns the instance, so that property settings can be chained.

func (Instance) SetStretchTimeScale

func (self Instance) SetStretchTimeScale(value bool) Instance

SetStretchTimeScale sets the property returned by [IsStretchingTimeScale]. Returns the instance, so that property settings can be chained.

func (Instance) SetTimelineLength

func (self Instance) SetTimelineLength(value Float.X) Instance

SetTimelineLength sets the property returned by [GetTimelineLength]. Returns the instance, so that property settings can be chained.

func (Instance) SetUseCustomTimeline

func (self Instance) SetUseCustomTimeline(value bool) Instance

SetUseCustomTimeline sets the property returned by [IsUsingCustomTimeline]. Returns the instance, so that property settings can be chained.

func (Instance) SetupLocalToScene

func (self Instance) SetupLocalToScene()

SetupLocalToScene is promoted from Resource.Instance.SetupLocalToScene.

func (Instance) StartOffset

func (self Instance) StartOffset() Float.X

func (Instance) StretchTimeScale

func (self Instance) StretchTimeScale() bool

func (Instance) TakeOverPath

func (self Instance) TakeOverPath(path string)

TakeOverPath is promoted from Resource.Instance.TakeOverPath.

func (Instance) TimelineLength

func (self Instance) TimelineLength() Float.X

func (Instance) UseCustomTimeline

func (self Instance) UseCustomTimeline() bool

func (Instance) Virtual

func (self Instance) Virtual(name string) reflect.Value

type PlayMode

type PlayMode int64 //gd:AnimationNodeAnimation.PlayMode
const (
	PlayModeForward  PlayMode = 0
	PlayModeBackward PlayMode = 1
)

type Singleton

type Singleton[T gdclass.Interface] = Extension[T]

Singleton can be embedded in a new struct to create a Go singleton extension of the class.

It will become available as a global inside scripts and any any other Go Extension types will have any *T typed fields filled in to point at this singleton once they have been instantiated.

T must be a type that is embedding this Singleton as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.

Jump to