Documentation
¶
Index ¶
- type Advanced
- type Any
- type Extension
- func (o *Extension[T]) AsAudioBusLayout() Instance
- func (o *Extension[T]) AsObject() [1]gdreference.Object
- func (o *Extension[T]) AsRefCounted() ie.RC
- func (o *Extension[T]) AsResource() Resource.Instance
- func (o *Extension[T]) EmitChanged()
- func (o *Extension[T]) GetIdForPath(path string) string
- func (o *Extension[T]) GetRid() Resource.ID
- func (o *Extension[T]) IsBuiltIn() bool
- func (o *Extension[T]) OnChanged(cb func(), flags ...Signal.Flags) *Extension[T]
- func (o *Extension[T]) OnSetupLocalToSceneRequested(cb func(), flags ...Signal.Flags) *Extension[T]
- func (o *Extension[T]) ResetState()
- func (o *Extension[T]) ResourceLocalToScene() bool
- func (o *Extension[T]) ResourceName() string
- func (o *Extension[T]) ResourcePath() string
- func (o *Extension[T]) ResourceSceneUniqueId() string
- func (o *Extension[T]) SetIdForPath(path string, id string) *Extension[T]
- func (o *Extension[T]) SetPathCache(path string) *Extension[T]
- func (o *Extension[T]) SetResourceLocalToScene(value bool) *Extension[T]
- func (o *Extension[T]) SetResourceName(value string) *Extension[T]
- func (o *Extension[T]) SetResourcePath(value string) *Extension[T]
- func (o *Extension[T]) SetResourceSceneUniqueId(value string) *Extension[T]
- func (o *Extension[T]) SetupLocalToScene()
- func (o *Extension[T]) TakeOverPath(path string)
- type ID
- type Instance
- func (o Instance) AsAudioBusLayout() Instance
- func (o Instance) AsObject() [1]gdreference.Object
- func (o Instance) AsRefCounted() ie.RC
- func (o Instance) AsResource() Resource.Instance
- func (self Instance) EmitChanged()
- func (self Instance) GetIdForPath(path string) string
- func (self Instance) GetRid() Resource.ID
- func (self Instance) ID() ID
- func (self Instance) IsBuiltIn() bool
- func (self Instance) OnChanged(cb func(), flags ...Signal.Flags) Instance
- func (self Instance) OnSetupLocalToSceneRequested(cb func(), flags ...Signal.Flags) Instance
- func (self Instance) ResetState()
- func (self Instance) ResourceLocalToScene() bool
- func (self Instance) ResourceName() string
- func (self Instance) ResourcePath() string
- func (self Instance) ResourceSceneUniqueId() string
- func (self Instance) SetIdForPath(path string, id string) Instance
- func (self *Instance) SetObject(obj [1]gdreference.Object) bool
- func (self Instance) SetPathCache(path string) Instance
- func (self Instance) SetResourceLocalToScene(value bool) Instance
- func (self Instance) SetResourceName(value string) Instance
- func (self Instance) SetResourcePath(value string) Instance
- func (self Instance) SetResourceSceneUniqueId(value string) Instance
- func (self Instance) SetupLocalToScene()
- func (self Instance) TakeOverPath(path string)
- func (self Instance) Virtual(name string) reflect.Value
- type Singleton
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Advanced ¶
type Advanced = class
Advanced exposes a 1:1 low-level instance of the class, undocumented, for those who know what they are doing.
type Extension ¶
Extension can be embedded in a new struct to create a Go extension of this class.
T must be a type that is embedding this Extension as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.
func (*Extension[T]) AsAudioBusLayout ¶
func (*Extension[T]) AsObject ¶
func (o *Extension[T]) AsObject() [1]gdreference.Object
func (*Extension[T]) AsRefCounted ¶
func (*Extension[T]) AsResource ¶
func (*Extension[T]) EmitChanged ¶
func (o *Extension[T]) EmitChanged()
EmitChanged is promoted from Resource.Instance.EmitChanged.
func (*Extension[T]) GetIdForPath ¶
GetIdForPath is promoted from Resource.Instance.GetIdForPath.
func (*Extension[T]) GetRid ¶
GetRid is promoted from Resource.Instance.GetRid.
func (*Extension[T]) IsBuiltIn ¶
IsBuiltIn is promoted from Resource.Instance.IsBuiltIn.
func (*Extension[T]) OnChanged ¶
OnChanged is promoted from Resource.Instance.OnChanged.
func (*Extension[T]) OnSetupLocalToSceneRequested ¶
OnSetupLocalToSceneRequested is promoted from Resource.Instance.OnSetupLocalToSceneRequested.
func (*Extension[T]) ResetState ¶
func (o *Extension[T]) ResetState()
ResetState is promoted from Resource.Instance.ResetState.
func (*Extension[T]) ResourceLocalToScene ¶
func (*Extension[T]) ResourceName ¶
func (*Extension[T]) ResourcePath ¶
func (*Extension[T]) ResourceSceneUniqueId ¶
func (*Extension[T]) SetIdForPath ¶
SetIdForPath is promoted from Resource.Instance.SetIdForPath.
func (*Extension[T]) SetPathCache ¶
SetPathCache is promoted from Resource.Instance.SetPathCache.
func (*Extension[T]) SetResourceLocalToScene ¶
func (*Extension[T]) SetResourceName ¶
func (*Extension[T]) SetResourcePath ¶
func (*Extension[T]) SetResourceSceneUniqueId ¶
func (*Extension[T]) SetupLocalToScene ¶
func (o *Extension[T]) SetupLocalToScene()
SetupLocalToScene is promoted from Resource.Instance.SetupLocalToScene.
func (*Extension[T]) TakeOverPath ¶
TakeOverPath is promoted from Resource.Instance.TakeOverPath.
type ID ¶
ID is a typed object ID (reference) to an instance of this class, use it to store references to objects with unknown lifetimes, as an ID will not panic on use if the underlying object has been destroyed.
type Instance ¶
type Instance [1]gdclass.AudioBusLayout
Instance of the class with convieniently typed arguments and results.
var Nil Instance
Nil is a nil/null instance of the class. Equivalent to the zero value.
func (Instance) AsAudioBusLayout ¶
func (Instance) AsObject ¶
func (o Instance) AsObject() [1]gdreference.Object
func (Instance) AsRefCounted ¶
func (Instance) AsResource ¶
func (Instance) EmitChanged ¶
func (self Instance) EmitChanged()
EmitChanged is promoted from Resource.Instance.EmitChanged.
func (Instance) GetIdForPath ¶
GetIdForPath is promoted from Resource.Instance.GetIdForPath.
func (Instance) GetRid ¶
GetRid is promoted from Resource.Instance.GetRid.
func (Instance) IsBuiltIn ¶
IsBuiltIn is promoted from Resource.Instance.IsBuiltIn.
func (Instance) OnChanged ¶
OnChanged is promoted from Resource.Instance.OnChanged.
func (Instance) OnSetupLocalToSceneRequested ¶
OnSetupLocalToSceneRequested is promoted from Resource.Instance.OnSetupLocalToSceneRequested.
func (Instance) ResetState ¶
func (self Instance) ResetState()
ResetState is promoted from Resource.Instance.ResetState.
func (Instance) ResourceLocalToScene ¶
ResourceLocalToScene is promoted from Resource.Instance.ResourceLocalToScene.
func (Instance) ResourceName ¶
ResourceName is promoted from Resource.Instance.ResourceName.
func (Instance) ResourcePath ¶
ResourcePath is promoted from Resource.Instance.ResourcePath.
func (Instance) ResourceSceneUniqueId ¶
ResourceSceneUniqueId is promoted from Resource.Instance.ResourceSceneUniqueId.
func (Instance) SetIdForPath ¶
SetIdForPath is promoted from Resource.Instance.SetIdForPath.
func (Instance) SetPathCache ¶
SetPathCache is promoted from Resource.Instance.SetPathCache.
func (Instance) SetResourceLocalToScene ¶
SetResourceLocalToScene is promoted from Resource.Instance.SetResourceLocalToScene.
func (Instance) SetResourceName ¶
SetResourceName is promoted from Resource.Instance.SetResourceName.
func (Instance) SetResourcePath ¶
SetResourcePath is promoted from Resource.Instance.SetResourcePath.
func (Instance) SetResourceSceneUniqueId ¶
SetResourceSceneUniqueId is promoted from Resource.Instance.SetResourceSceneUniqueId.
func (Instance) SetupLocalToScene ¶
func (self Instance) SetupLocalToScene()
SetupLocalToScene is promoted from Resource.Instance.SetupLocalToScene.
func (Instance) TakeOverPath ¶
TakeOverPath is promoted from Resource.Instance.TakeOverPath.
type Singleton ¶
Singleton can be embedded in a new struct to create a Go singleton extension of the class.
It will become available as a global inside scripts and any any other Go Extension types will have any *T typed fields filled in to point at this singleton once they have been instantiated.
T must be a type that is embedding this Singleton as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.