AudioStreamRandomizer

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 24, 2026 License: MIT Imports: 29 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Advanced

type Advanced = class

Advanced exposes a 1:1 low-level instance of the class, undocumented, for those who know what they are doing.

type Any

type Any interface {
	gd.IsClass
	AsAudioStreamRandomizer() Instance
}

type Expanded

type Expanded = MoreArgs

type Extension

type Extension[T gdclass.Interface] struct{ gdclass.Extension[T, Instance] }

Extension can be embedded in a new struct to create a Go extension of this class.

T must be a type that is embedding this Extension as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.

func (*Extension[T]) AsAudioStream

func (o *Extension[T]) AsAudioStream() AudioStream.Instance

func (*Extension[T]) AsAudioStreamRandomizer

func (o *Extension[T]) AsAudioStreamRandomizer() Instance

func (*Extension[T]) AsObject

func (o *Extension[T]) AsObject() [1]gdreference.Object

func (*Extension[T]) AsRefCounted

func (o *Extension[T]) AsRefCounted() ie.RC

func (*Extension[T]) AsResource

func (o *Extension[T]) AsResource() Resource.Instance

func (*Extension[T]) CanBeSampled

func (o *Extension[T]) CanBeSampled() bool

CanBeSampled is promoted from AudioStream.Instance.CanBeSampled.

func (*Extension[T]) EmitChanged

func (o *Extension[T]) EmitChanged()

EmitChanged is promoted from Resource.Instance.EmitChanged.

func (*Extension[T]) GenerateSample

func (o *Extension[T]) GenerateSample() AudioSample.Instance

GenerateSample is promoted from AudioStream.Instance.GenerateSample.

func (*Extension[T]) GetIdForPath

func (o *Extension[T]) GetIdForPath(path string) string

GetIdForPath is promoted from Resource.Instance.GetIdForPath.

func (*Extension[T]) GetLength

func (o *Extension[T]) GetLength() Float.X

GetLength is promoted from AudioStream.Instance.GetLength.

func (*Extension[T]) GetRid

func (o *Extension[T]) GetRid() Resource.ID

GetRid is promoted from Resource.Instance.GetRid.

func (*Extension[T]) GetStream

func (o *Extension[T]) GetStream(index int) AudioStream.Instance

func (*Extension[T]) GetStreamProbabilityWeight

func (o *Extension[T]) GetStreamProbabilityWeight(index int) Float.X

func (*Extension[T]) InstantiatePlayback

func (o *Extension[T]) InstantiatePlayback() AudioStreamPlayback.Instance

InstantiatePlayback is promoted from AudioStream.Instance.InstantiatePlayback.

func (*Extension[T]) IsBuiltIn

func (o *Extension[T]) IsBuiltIn() bool

IsBuiltIn is promoted from Resource.Instance.IsBuiltIn.

func (*Extension[T]) IsMetaStream

func (o *Extension[T]) IsMetaStream() bool

IsMetaStream is promoted from AudioStream.Instance.IsMetaStream.

func (*Extension[T]) IsMonophonic

func (o *Extension[T]) IsMonophonic() bool

IsMonophonic is promoted from AudioStream.Instance.IsMonophonic.

func (*Extension[T]) MoveStream

func (o *Extension[T]) MoveStream(index_from int, index_to int)

func (*Extension[T]) OnChanged

func (o *Extension[T]) OnChanged(cb func(), flags ...Signal.Flags) *Extension[T]

OnChanged is promoted from Resource.Instance.OnChanged.

func (*Extension[T]) OnParameterListChanged

func (o *Extension[T]) OnParameterListChanged(cb func(), flags ...Signal.Flags) *Extension[T]

OnParameterListChanged is promoted from AudioStream.Instance.OnParameterListChanged.

func (*Extension[T]) OnSetupLocalToSceneRequested

func (o *Extension[T]) OnSetupLocalToSceneRequested(cb func(), flags ...Signal.Flags) *Extension[T]

OnSetupLocalToSceneRequested is promoted from Resource.Instance.OnSetupLocalToSceneRequested.

func (*Extension[T]) PlaybackMode

func (o *Extension[T]) PlaybackMode() PlaybackMode

func (*Extension[T]) RandomPitch

func (o *Extension[T]) RandomPitch() Float.X

func (*Extension[T]) RandomPitchSemitones

func (o *Extension[T]) RandomPitchSemitones() Float.X

func (*Extension[T]) RandomVolumeOffsetDb

func (o *Extension[T]) RandomVolumeOffsetDb() Float.X

func (*Extension[T]) RemoveStream

func (o *Extension[T]) RemoveStream(index int)

func (*Extension[T]) ResetState

func (o *Extension[T]) ResetState()

ResetState is promoted from Resource.Instance.ResetState.

func (*Extension[T]) ResourceLocalToScene

func (o *Extension[T]) ResourceLocalToScene() bool

func (*Extension[T]) ResourceName

func (o *Extension[T]) ResourceName() string

func (*Extension[T]) ResourcePath

func (o *Extension[T]) ResourcePath() string

func (*Extension[T]) ResourceSceneUniqueId

func (o *Extension[T]) ResourceSceneUniqueId() string

func (*Extension[T]) SetIdForPath

func (o *Extension[T]) SetIdForPath(path string, id string) *Extension[T]

SetIdForPath is promoted from Resource.Instance.SetIdForPath.

func (*Extension[T]) SetPathCache

func (o *Extension[T]) SetPathCache(path string) *Extension[T]

SetPathCache is promoted from Resource.Instance.SetPathCache.

func (*Extension[T]) SetPlaybackMode

func (o *Extension[T]) SetPlaybackMode(value PlaybackMode) *Extension[T]

func (*Extension[T]) SetRandomPitch

func (o *Extension[T]) SetRandomPitch(value Float.X) *Extension[T]

func (*Extension[T]) SetRandomPitchSemitones

func (o *Extension[T]) SetRandomPitchSemitones(value Float.X) *Extension[T]

func (*Extension[T]) SetRandomVolumeOffsetDb

func (o *Extension[T]) SetRandomVolumeOffsetDb(value Float.X) *Extension[T]

func (*Extension[T]) SetResourceLocalToScene

func (o *Extension[T]) SetResourceLocalToScene(value bool) *Extension[T]

func (*Extension[T]) SetResourceName

func (o *Extension[T]) SetResourceName(value string) *Extension[T]

func (*Extension[T]) SetResourcePath

func (o *Extension[T]) SetResourcePath(value string) *Extension[T]

func (*Extension[T]) SetResourceSceneUniqueId

func (o *Extension[T]) SetResourceSceneUniqueId(value string) *Extension[T]

func (*Extension[T]) SetStream

func (o *Extension[T]) SetStream(index int, stream AudioStream.Instance) *Extension[T]

func (*Extension[T]) SetStreamProbabilityWeight

func (o *Extension[T]) SetStreamProbabilityWeight(index int, weight Float.X) *Extension[T]

func (*Extension[T]) SetStreamsCount

func (o *Extension[T]) SetStreamsCount(value int) *Extension[T]

func (*Extension[T]) SetupLocalToScene

func (o *Extension[T]) SetupLocalToScene()

SetupLocalToScene is promoted from Resource.Instance.SetupLocalToScene.

func (*Extension[T]) StreamsCount

func (o *Extension[T]) StreamsCount() int

func (*Extension[T]) TakeOverPath

func (o *Extension[T]) TakeOverPath(path string)

TakeOverPath is promoted from Resource.Instance.TakeOverPath.

type ID

type ID Object.ID

ID is a typed object ID (reference) to an instance of this class, use it to store references to objects with unknown lifetimes, as an ID will not panic on use if the underlying object has been destroyed.

func (ID) Instance

func (id ID) Instance() (Instance, bool)

type Instance

type Instance [1]gdclass.AudioStreamRandomizer

Instance of the class with convieniently typed arguments and results.

var Nil Instance

Nil is a nil/null instance of the class. Equivalent to the zero value.

func New

func New() Instance

func (Instance) AddStream

func (self Instance) AddStream(index int, stream AudioStream.Instance)

func (Instance) AsAudioStream

func (o Instance) AsAudioStream() AudioStream.Instance

func (Instance) AsAudioStreamRandomizer

func (o Instance) AsAudioStreamRandomizer() Instance

func (Instance) AsObject

func (o Instance) AsObject() [1]gdreference.Object

func (Instance) AsRefCounted

func (o Instance) AsRefCounted() ie.RC

func (Instance) AsResource

func (o Instance) AsResource() Resource.Instance

func (Instance) CanBeSampled

func (self Instance) CanBeSampled() bool

CanBeSampled is promoted from AudioStream.Instance.CanBeSampled.

func (Instance) EmitChanged

func (self Instance) EmitChanged()

EmitChanged is promoted from Resource.Instance.EmitChanged.

func (Instance) GenerateSample

func (self Instance) GenerateSample() AudioSample.Instance

GenerateSample is promoted from AudioStream.Instance.GenerateSample.

func (Instance) GetIdForPath

func (self Instance) GetIdForPath(path string) string

GetIdForPath is promoted from Resource.Instance.GetIdForPath.

func (Instance) GetLength

func (self Instance) GetLength() Float.X

GetLength is promoted from AudioStream.Instance.GetLength.

func (Instance) GetRid

func (self Instance) GetRid() Resource.ID

GetRid is promoted from Resource.Instance.GetRid.

func (Instance) GetStream

func (self Instance) GetStream(index int) AudioStream.Instance

func (Instance) GetStreamProbabilityWeight

func (self Instance) GetStreamProbabilityWeight(index int) Float.X

func (Instance) ID

func (self Instance) ID() ID

func (Instance) InstantiatePlayback

func (self Instance) InstantiatePlayback() AudioStreamPlayback.Instance

InstantiatePlayback is promoted from AudioStream.Instance.InstantiatePlayback.

func (Instance) IsBuiltIn

func (self Instance) IsBuiltIn() bool

IsBuiltIn is promoted from Resource.Instance.IsBuiltIn.

func (Instance) IsMetaStream

func (self Instance) IsMetaStream() bool

IsMetaStream is promoted from AudioStream.Instance.IsMetaStream.

func (Instance) IsMonophonic

func (self Instance) IsMonophonic() bool

IsMonophonic is promoted from AudioStream.Instance.IsMonophonic.

func (Instance) MoreArgs

func (self Instance) MoreArgs() MoreArgs

MoreArgs enables certain functions to be called with additional 'optional' arguments.

func (Instance) MoveStream

func (self Instance) MoveStream(index_from int, index_to int)

func (Instance) OnChanged

func (self Instance) OnChanged(cb func(), flags ...Signal.Flags) Instance

OnChanged is promoted from Resource.Instance.OnChanged.

func (Instance) OnParameterListChanged

func (self Instance) OnParameterListChanged(cb func(), flags ...Signal.Flags) Instance

OnParameterListChanged is promoted from AudioStream.Instance.OnParameterListChanged.

func (Instance) OnSetupLocalToSceneRequested

func (self Instance) OnSetupLocalToSceneRequested(cb func(), flags ...Signal.Flags) Instance

OnSetupLocalToSceneRequested is promoted from Resource.Instance.OnSetupLocalToSceneRequested.

func (Instance) PlaybackMode

func (self Instance) PlaybackMode() PlaybackMode

func (Instance) RandomPitch

func (self Instance) RandomPitch() Float.X

func (Instance) RandomPitchSemitones

func (self Instance) RandomPitchSemitones() Float.X

func (Instance) RandomVolumeOffsetDb

func (self Instance) RandomVolumeOffsetDb() Float.X

func (Instance) RemoveStream

func (self Instance) RemoveStream(index int)

func (Instance) ResetState

func (self Instance) ResetState()

ResetState is promoted from Resource.Instance.ResetState.

func (Instance) ResourceLocalToScene

func (self Instance) ResourceLocalToScene() bool

ResourceLocalToScene is promoted from Resource.Instance.ResourceLocalToScene.

func (Instance) ResourceName

func (self Instance) ResourceName() string

ResourceName is promoted from Resource.Instance.ResourceName.

func (Instance) ResourcePath

func (self Instance) ResourcePath() string

ResourcePath is promoted from Resource.Instance.ResourcePath.

func (Instance) ResourceSceneUniqueId

func (self Instance) ResourceSceneUniqueId() string

ResourceSceneUniqueId is promoted from Resource.Instance.ResourceSceneUniqueId.

func (Instance) SetIdForPath

func (self Instance) SetIdForPath(path string, id string) Instance

SetIdForPath is promoted from Resource.Instance.SetIdForPath.

func (*Instance) SetObject

func (self *Instance) SetObject(obj [1]gdreference.Object) bool

func (Instance) SetPathCache

func (self Instance) SetPathCache(path string) Instance

SetPathCache is promoted from Resource.Instance.SetPathCache.

func (Instance) SetPlaybackMode

func (self Instance) SetPlaybackMode(value PlaybackMode) Instance

SetPlaybackMode sets the property returned by [GetPlaybackMode]. Returns the instance, so that property settings can be chained.

func (Instance) SetRandomPitch

func (self Instance) SetRandomPitch(value Float.X) Instance

SetRandomPitch sets the property returned by [GetRandomPitch]. Returns the instance, so that property settings can be chained.

func (Instance) SetRandomPitchSemitones

func (self Instance) SetRandomPitchSemitones(value Float.X) Instance

SetRandomPitchSemitones sets the property returned by [GetRandomPitchSemitones]. Returns the instance, so that property settings can be chained.

func (Instance) SetRandomVolumeOffsetDb

func (self Instance) SetRandomVolumeOffsetDb(value Float.X) Instance

SetRandomVolumeOffsetDb sets the property returned by [GetRandomVolumeOffsetDb]. Returns the instance, so that property settings can be chained.

func (Instance) SetResourceLocalToScene

func (self Instance) SetResourceLocalToScene(value bool) Instance

SetResourceLocalToScene is promoted from Resource.Instance.SetResourceLocalToScene.

func (Instance) SetResourceName

func (self Instance) SetResourceName(value string) Instance

SetResourceName is promoted from Resource.Instance.SetResourceName.

func (Instance) SetResourcePath

func (self Instance) SetResourcePath(value string) Instance

SetResourcePath is promoted from Resource.Instance.SetResourcePath.

func (Instance) SetResourceSceneUniqueId

func (self Instance) SetResourceSceneUniqueId(value string) Instance

SetResourceSceneUniqueId is promoted from Resource.Instance.SetResourceSceneUniqueId.

func (Instance) SetStream

func (self Instance) SetStream(index int, stream AudioStream.Instance) Instance

func (Instance) SetStreamProbabilityWeight

func (self Instance) SetStreamProbabilityWeight(index int, weight Float.X) Instance

func (Instance) SetStreamsCount

func (self Instance) SetStreamsCount(value int) Instance

SetStreamsCount sets the property returned by [GetStreamsCount]. Returns the instance, so that property settings can be chained.

func (Instance) SetupLocalToScene

func (self Instance) SetupLocalToScene()

SetupLocalToScene is promoted from Resource.Instance.SetupLocalToScene.

func (Instance) StreamsCount

func (self Instance) StreamsCount() int

func (Instance) TakeOverPath

func (self Instance) TakeOverPath(path string)

TakeOverPath is promoted from Resource.Instance.TakeOverPath.

func (Instance) Virtual

func (self Instance) Virtual(name string) reflect.Value

type MoreArgs

type MoreArgs [1]gdclass.AudioStreamRandomizer

MoreArgs is a container for Instance functions with additional 'optional' arguments.

func (MoreArgs) AddStream

func (self MoreArgs) AddStream(index int, stream AudioStream.Instance, weight Float.X)

type PlaybackMode

type PlaybackMode int64 //gd:AudioStreamRandomizer.PlaybackMode
const (
	PlaybackRandomNoRepeats PlaybackMode = 0
	PlaybackRandom          PlaybackMode = 1
	PlaybackSequential      PlaybackMode = 2
)

type Singleton

type Singleton[T gdclass.Interface] = Extension[T]

Singleton can be embedded in a new struct to create a Go singleton extension of the class.

It will become available as a global inside scripts and any any other Go Extension types will have any *T typed fields filled in to point at this singleton once they have been instantiated.

T must be a type that is embedding this Singleton as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.

Jump to