ConfigFile

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 24, 2026 License: MIT Imports: 25 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Advanced

type Advanced = class

Advanced exposes a 1:1 low-level instance of the class, undocumented, for those who know what they are doing.

type Any

type Any interface {
	gd.IsClass
	AsConfigFile() Instance
}

type Expanded

type Expanded = MoreArgs

type Extension

type Extension[T gdclass.Interface] struct{ gdclass.Extension[T, Instance] }

Extension can be embedded in a new struct to create a Go extension of this class.

T must be a type that is embedding this Extension as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.

func (*Extension[T]) AsConfigFile

func (o *Extension[T]) AsConfigFile() Instance

func (*Extension[T]) AsObject

func (o *Extension[T]) AsObject() [1]gdreference.Object

func (*Extension[T]) AsRefCounted

func (o *Extension[T]) AsRefCounted() ie.RC

func (*Extension[T]) Clear

func (o *Extension[T]) Clear()

func (*Extension[T]) EncodeToText

func (o *Extension[T]) EncodeToText() string

func (*Extension[T]) EraseSection

func (o *Extension[T]) EraseSection(section string)

func (*Extension[T]) EraseSectionKey

func (o *Extension[T]) EraseSectionKey(section string, key string)

func (*Extension[T]) GetSectionKeys

func (o *Extension[T]) GetSectionKeys(section string) []string

func (*Extension[T]) GetSections

func (o *Extension[T]) GetSections() []string

func (*Extension[T]) HasSection

func (o *Extension[T]) HasSection(section string) bool

func (*Extension[T]) HasSectionKey

func (o *Extension[T]) HasSectionKey(section string, key string) bool

func (*Extension[T]) Load

func (o *Extension[T]) Load(path string) error

func (*Extension[T]) LoadEncrypted

func (o *Extension[T]) LoadEncrypted(path string, key []byte) error

func (*Extension[T]) LoadEncryptedPass

func (o *Extension[T]) LoadEncryptedPass(path string, password string) error

func (*Extension[T]) Parse

func (o *Extension[T]) Parse(data string) error

func (*Extension[T]) Save

func (o *Extension[T]) Save(path string) error

func (*Extension[T]) SaveEncrypted

func (o *Extension[T]) SaveEncrypted(path string, key []byte) error

func (*Extension[T]) SaveEncryptedPass

func (o *Extension[T]) SaveEncryptedPass(path string, password string) error

func (*Extension[T]) SetValue

func (o *Extension[T]) SetValue(section string, key string, value any) *Extension[T]

type ID

type ID Object.ID

ID is a typed object ID (reference) to an instance of this class, use it to store references to objects with unknown lifetimes, as an ID will not panic on use if the underlying object has been destroyed.

func (ID) Instance

func (id ID) Instance() (Instance, bool)

type Instance

type Instance [1]gdclass.ConfigFile

Instance of the class with convieniently typed arguments and results.

var Nil Instance

Nil is a nil/null instance of the class. Equivalent to the zero value.

func New

func New() Instance

func (Instance) AsConfigFile

func (o Instance) AsConfigFile() Instance

func (Instance) AsObject

func (o Instance) AsObject() [1]gdreference.Object

func (Instance) AsRefCounted

func (o Instance) AsRefCounted() ie.RC

func (Instance) Clear

func (self Instance) Clear()

func (Instance) EncodeToText

func (self Instance) EncodeToText() string

func (Instance) EraseSection

func (self Instance) EraseSection(section string)

func (Instance) EraseSectionKey

func (self Instance) EraseSectionKey(section string, key string)

func (Instance) GetSectionKeys

func (self Instance) GetSectionKeys(section string) []string

func (Instance) GetSections

func (self Instance) GetSections() []string

func (Instance) GetValue

func (self Instance) GetValue(section string, key string) any

func (Instance) HasSection

func (self Instance) HasSection(section string) bool

func (Instance) HasSectionKey

func (self Instance) HasSectionKey(section string, key string) bool

func (Instance) ID

func (self Instance) ID() ID

func (Instance) Load

func (self Instance) Load(path string) error

func (Instance) LoadEncrypted

func (self Instance) LoadEncrypted(path string, key []byte) error

func (Instance) LoadEncryptedPass

func (self Instance) LoadEncryptedPass(path string, password string) error

func (Instance) MoreArgs

func (self Instance) MoreArgs() MoreArgs

MoreArgs enables certain functions to be called with additional 'optional' arguments.

func (Instance) Parse

func (self Instance) Parse(data string) error

func (Instance) Save

func (self Instance) Save(path string) error

func (Instance) SaveEncrypted

func (self Instance) SaveEncrypted(path string, key []byte) error

func (Instance) SaveEncryptedPass

func (self Instance) SaveEncryptedPass(path string, password string) error

func (*Instance) SetObject

func (self *Instance) SetObject(obj [1]gdreference.Object) bool

func (Instance) SetValue

func (self Instance) SetValue(section string, key string, value any) Instance

func (Instance) Virtual

func (self Instance) Virtual(name string) reflect.Value

type MoreArgs

type MoreArgs [1]gdclass.ConfigFile

MoreArgs is a container for Instance functions with additional 'optional' arguments.

func (MoreArgs) GetValue

func (self MoreArgs) GetValue(section string, key string, def any) any

type Singleton

type Singleton[T gdclass.Interface] = Extension[T]

Singleton can be embedded in a new struct to create a Go singleton extension of the class.

It will become available as a global inside scripts and any any other Go Extension types will have any *T typed fields filled in to point at this singleton once they have been instantiated.

T must be a type that is embedding this Singleton as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.

Jump to