EditorDebuggerSession

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 24, 2026 License: MIT Imports: 26 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Advanced

type Advanced = class

Advanced exposes a 1:1 low-level instance of the class, undocumented, for those who know what they are doing.

type Any

type Any interface {
	gd.IsClass
	AsEditorDebuggerSession() Instance
}

type Expanded

type Expanded = MoreArgs

type Extension

type Extension[T gdclass.Interface] struct{ gdclass.Extension[T, Instance] }

Extension can be embedded in a new struct to create a Go extension of this class.

T must be a type that is embedding this Extension as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.

func (*Extension[T]) AddSessionTab

func (o *Extension[T]) AddSessionTab(control Control.Instance)

func (*Extension[T]) AsEditorDebuggerSession

func (o *Extension[T]) AsEditorDebuggerSession() Instance

func (*Extension[T]) AsObject

func (o *Extension[T]) AsObject() [1]gdreference.Object

func (*Extension[T]) AsRefCounted

func (o *Extension[T]) AsRefCounted() ie.RC

func (*Extension[T]) IsActive

func (o *Extension[T]) IsActive() bool

func (*Extension[T]) IsBreaked

func (o *Extension[T]) IsBreaked() bool

func (*Extension[T]) IsDebuggable

func (o *Extension[T]) IsDebuggable() bool

func (*Extension[T]) OnBreaked

func (o *Extension[T]) OnBreaked(cb func(can_debug bool), flags ...Signal.Flags) *Extension[T]

func (*Extension[T]) OnContinued

func (o *Extension[T]) OnContinued(cb func(), flags ...Signal.Flags) *Extension[T]

func (*Extension[T]) OnStarted

func (o *Extension[T]) OnStarted(cb func(), flags ...Signal.Flags) *Extension[T]

func (*Extension[T]) OnStopped

func (o *Extension[T]) OnStopped(cb func(), flags ...Signal.Flags) *Extension[T]

func (*Extension[T]) RemoveSessionTab

func (o *Extension[T]) RemoveSessionTab(control Control.Instance)

func (*Extension[T]) SetBreakpoint

func (o *Extension[T]) SetBreakpoint(path string, line int, enabled bool) *Extension[T]

type ID

type ID Object.ID

ID is a typed object ID (reference) to an instance of this class, use it to store references to objects with unknown lifetimes, as an ID will not panic on use if the underlying object has been destroyed.

func (ID) Instance

func (id ID) Instance() (Instance, bool)

type Instance

type Instance [1]gdclass.EditorDebuggerSession

Instance of the class with convieniently typed arguments and results.

var Nil Instance

Nil is a nil/null instance of the class. Equivalent to the zero value.

func New

func New() Instance

func (Instance) AddSessionTab

func (self Instance) AddSessionTab(control Control.Instance)

func (Instance) AsEditorDebuggerSession

func (o Instance) AsEditorDebuggerSession() Instance

func (Instance) AsObject

func (o Instance) AsObject() [1]gdreference.Object

func (Instance) AsRefCounted

func (o Instance) AsRefCounted() ie.RC

func (Instance) ID

func (self Instance) ID() ID

func (Instance) IsActive

func (self Instance) IsActive() bool

func (Instance) IsBreaked

func (self Instance) IsBreaked() bool

func (Instance) IsDebuggable

func (self Instance) IsDebuggable() bool

func (Instance) MoreArgs

func (self Instance) MoreArgs() MoreArgs

MoreArgs enables certain functions to be called with additional 'optional' arguments.

func (Instance) OnBreaked

func (self Instance) OnBreaked(cb func(can_debug bool), flags ...Signal.Flags) Instance

func (Instance) OnContinued

func (self Instance) OnContinued(cb func(), flags ...Signal.Flags) Instance

func (Instance) OnStarted

func (self Instance) OnStarted(cb func(), flags ...Signal.Flags) Instance

func (Instance) OnStopped

func (self Instance) OnStopped(cb func(), flags ...Signal.Flags) Instance

func (Instance) RemoveSessionTab

func (self Instance) RemoveSessionTab(control Control.Instance)

func (Instance) SendMessage

func (self Instance) SendMessage(message string)

func (Instance) SetBreakpoint

func (self Instance) SetBreakpoint(path string, line int, enabled bool) Instance

func (*Instance) SetObject

func (self *Instance) SetObject(obj [1]gdreference.Object) bool

func (Instance) ToggleProfiler

func (self Instance) ToggleProfiler(profiler string, enable bool)

func (Instance) Virtual

func (self Instance) Virtual(name string) reflect.Value

type MoreArgs

type MoreArgs [1]gdclass.EditorDebuggerSession

MoreArgs is a container for Instance functions with additional 'optional' arguments.

func (MoreArgs) SendMessage

func (self MoreArgs) SendMessage(message string, data []any)

func (MoreArgs) ToggleProfiler

func (self MoreArgs) ToggleProfiler(profiler string, enable bool, data []any)

type Singleton

type Singleton[T gdclass.Interface] = Extension[T]

Singleton can be embedded in a new struct to create a Go singleton extension of the class.

It will become available as a global inside scripts and any any other Go Extension types will have any *T typed fields filled in to point at this singleton once they have been instantiated.

T must be a type that is embedding this Singleton as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.

Jump to