EditorExportPlatformAndroid

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 24, 2026 License: MIT Imports: 27 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Advanced

type Advanced = class

Advanced exposes a 1:1 low-level instance of the class, undocumented, for those who know what they are doing.

type Any

type Any interface {
	gd.IsClass
	AsEditorExportPlatformAndroid() Instance
}

type Extension

type Extension[T gdclass.Interface] struct{ gdclass.Extension[T, Instance] }

Extension can be embedded in a new struct to create a Go extension of this class.

T must be a type that is embedding this Extension as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.

func (*Extension[T]) AddMessage

func (o *Extension[T]) AddMessage(atype EditorExportPlatform.ExportMessageType, category string, message string)

AddMessage is promoted from EditorExportPlatform.Instance.AddMessage.

func (*Extension[T]) AsEditorExportPlatform

func (o *Extension[T]) AsEditorExportPlatform() EditorExportPlatform.Instance

func (*Extension[T]) AsEditorExportPlatformAndroid

func (o *Extension[T]) AsEditorExportPlatformAndroid() Instance

func (*Extension[T]) AsObject

func (o *Extension[T]) AsObject() [1]gdreference.Object

func (*Extension[T]) AsRefCounted

func (o *Extension[T]) AsRefCounted() ie.RC

func (*Extension[T]) ClearMessages

func (o *Extension[T]) ClearMessages()

ClearMessages is promoted from EditorExportPlatform.Instance.ClearMessages.

func (*Extension[T]) CreatePreset

func (o *Extension[T]) CreatePreset() EditorExportPreset.Instance

CreatePreset is promoted from EditorExportPlatform.Instance.CreatePreset.

func (*Extension[T]) FindExportTemplate

func (o *Extension[T]) FindExportTemplate(template_file_name string) EditorExportPlatform.Template

FindExportTemplate is promoted from EditorExportPlatform.Instance.FindExportTemplate.

func (*Extension[T]) GenExportFlags

func (o *Extension[T]) GenExportFlags(flags EditorExportPlatform.DebugFlags) []string

GenExportFlags is promoted from EditorExportPlatform.Instance.GenExportFlags.

func (*Extension[T]) GetCurrentPresets

func (o *Extension[T]) GetCurrentPresets() []EditorExportPreset.Instance

GetCurrentPresets is promoted from EditorExportPlatform.Instance.GetCurrentPresets.

func (*Extension[T]) GetInternalExportFiles

func (o *Extension[T]) GetInternalExportFiles(preset EditorExportPreset.Instance, debug bool) map[string][]uint8

GetInternalExportFiles is promoted from EditorExportPlatform.Instance.GetInternalExportFiles.

func (*Extension[T]) GetMessageCategory

func (o *Extension[T]) GetMessageCategory(index int) string

GetMessageCategory is promoted from EditorExportPlatform.Instance.GetMessageCategory.

func (*Extension[T]) GetMessageCount

func (o *Extension[T]) GetMessageCount() int

GetMessageCount is promoted from EditorExportPlatform.Instance.GetMessageCount.

func (*Extension[T]) GetMessageText

func (o *Extension[T]) GetMessageText(index int) string

GetMessageText is promoted from EditorExportPlatform.Instance.GetMessageText.

func (*Extension[T]) GetMessageType

func (o *Extension[T]) GetMessageType(index int) EditorExportPlatform.ExportMessageType

GetMessageType is promoted from EditorExportPlatform.Instance.GetMessageType.

func (*Extension[T]) GetOsName

func (o *Extension[T]) GetOsName() string

GetOsName is promoted from EditorExportPlatform.Instance.GetOsName.

func (*Extension[T]) GetWorstMessageType

func (o *Extension[T]) GetWorstMessageType() EditorExportPlatform.ExportMessageType

GetWorstMessageType is promoted from EditorExportPlatform.Instance.GetWorstMessageType.

func (*Extension[T]) SavePackPatch

func (o *Extension[T]) SavePackPatch(preset EditorExportPreset.Instance, debug bool, path string) EditorExportPlatform.Report

SavePackPatch is promoted from EditorExportPlatform.Instance.SavePackPatch.

func (*Extension[T]) SaveZip

func (o *Extension[T]) SaveZip(preset EditorExportPreset.Instance, debug bool, path string) EditorExportPlatform.Report

SaveZip is promoted from EditorExportPlatform.Instance.SaveZip.

func (*Extension[T]) SaveZipPatch

func (o *Extension[T]) SaveZipPatch(preset EditorExportPreset.Instance, debug bool, path string) EditorExportPlatform.Report

SaveZipPatch is promoted from EditorExportPlatform.Instance.SaveZipPatch.

func (*Extension[T]) SshPushToRemote

func (o *Extension[T]) SshPushToRemote(host string, port string, scp_args []string, src_file string, dst_file string) error

SshPushToRemote is promoted from EditorExportPlatform.Instance.SshPushToRemote.

type File

type File struct {
	Path         string   `gd:"path"`
	Tags         []string `gd:"tags"`
	TargetFolder string   `gd:"target_folder"`
}

type ID

type ID Object.ID

ID is a typed object ID (reference) to an instance of this class, use it to store references to objects with unknown lifetimes, as an ID will not panic on use if the underlying object has been destroyed.

func (ID) Instance

func (id ID) Instance() (Instance, bool)

type Instance

Instance of the class with convieniently typed arguments and results.

var Nil Instance

Nil is a nil/null instance of the class. Equivalent to the zero value.

func New

func New() Instance

func (Instance) AddMessage

func (self Instance) AddMessage(atype EditorExportPlatform.ExportMessageType, category string, message string)

AddMessage is promoted from EditorExportPlatform.Instance.AddMessage.

func (Instance) AsEditorExportPlatform

func (o Instance) AsEditorExportPlatform() EditorExportPlatform.Instance

func (Instance) AsEditorExportPlatformAndroid

func (o Instance) AsEditorExportPlatformAndroid() Instance

func (Instance) AsObject

func (o Instance) AsObject() [1]gdreference.Object

func (Instance) AsRefCounted

func (o Instance) AsRefCounted() ie.RC

func (Instance) ClearMessages

func (self Instance) ClearMessages()

ClearMessages is promoted from EditorExportPlatform.Instance.ClearMessages.

func (Instance) CreatePreset

func (self Instance) CreatePreset() EditorExportPreset.Instance

CreatePreset is promoted from EditorExportPlatform.Instance.CreatePreset.

func (Instance) FindExportTemplate

func (self Instance) FindExportTemplate(template_file_name string) EditorExportPlatform.Template

FindExportTemplate is promoted from EditorExportPlatform.Instance.FindExportTemplate.

func (Instance) GenExportFlags

func (self Instance) GenExportFlags(flags EditorExportPlatform.DebugFlags) []string

GenExportFlags is promoted from EditorExportPlatform.Instance.GenExportFlags.

func (Instance) GetCurrentPresets

func (self Instance) GetCurrentPresets() []EditorExportPreset.Instance

GetCurrentPresets is promoted from EditorExportPlatform.Instance.GetCurrentPresets.

func (Instance) GetInternalExportFiles

func (self Instance) GetInternalExportFiles(preset EditorExportPreset.Instance, debug bool) map[string][]uint8

GetInternalExportFiles is promoted from EditorExportPlatform.Instance.GetInternalExportFiles.

func (Instance) GetMessageCategory

func (self Instance) GetMessageCategory(index int) string

GetMessageCategory is promoted from EditorExportPlatform.Instance.GetMessageCategory.

func (Instance) GetMessageCount

func (self Instance) GetMessageCount() int

GetMessageCount is promoted from EditorExportPlatform.Instance.GetMessageCount.

func (Instance) GetMessageText

func (self Instance) GetMessageText(index int) string

GetMessageText is promoted from EditorExportPlatform.Instance.GetMessageText.

func (Instance) GetMessageType

func (self Instance) GetMessageType(index int) EditorExportPlatform.ExportMessageType

GetMessageType is promoted from EditorExportPlatform.Instance.GetMessageType.

func (Instance) GetOsName

func (self Instance) GetOsName() string

GetOsName is promoted from EditorExportPlatform.Instance.GetOsName.

func (Instance) GetWorstMessageType

func (self Instance) GetWorstMessageType() EditorExportPlatform.ExportMessageType

GetWorstMessageType is promoted from EditorExportPlatform.Instance.GetWorstMessageType.

func (Instance) ID

func (self Instance) ID() ID

func (Instance) SavePackPatch

func (self Instance) SavePackPatch(preset EditorExportPreset.Instance, debug bool, path string) EditorExportPlatform.Report

SavePackPatch is promoted from EditorExportPlatform.Instance.SavePackPatch.

func (Instance) SaveZip

func (self Instance) SaveZip(preset EditorExportPreset.Instance, debug bool, path string) EditorExportPlatform.Report

SaveZip is promoted from EditorExportPlatform.Instance.SaveZip.

func (Instance) SaveZipPatch

func (self Instance) SaveZipPatch(preset EditorExportPreset.Instance, debug bool, path string) EditorExportPlatform.Report

SaveZipPatch is promoted from EditorExportPlatform.Instance.SaveZipPatch.

func (*Instance) SetObject

func (self *Instance) SetObject(obj [1]gdreference.Object) bool

func (Instance) SshPushToRemote

func (self Instance) SshPushToRemote(host string, port string, scp_args []string, src_file string, dst_file string) error

SshPushToRemote is promoted from EditorExportPlatform.Instance.SshPushToRemote.

func (Instance) Virtual

func (self Instance) Virtual(name string) reflect.Value

type Report

type Report struct {
	Error         Error.Code `gd:"result"`
	Files         []File     `gd:"so_files"`
	EmbeddedStart int        `gd:"embedded_start"`
	EmbeddedSize  int        `gd:"embedded_size"`
}

type Singleton

type Singleton[T gdclass.Interface] = Extension[T]

Singleton can be embedded in a new struct to create a Go singleton extension of the class.

It will become available as a global inside scripts and any any other Go Extension types will have any *T typed fields filled in to point at this singleton once they have been instantiated.

T must be a type that is embedding this Singleton as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.

type Template

type Template struct {
	Path  string `gd:"path"`
	Error string `gd:"error"`
}

Jump to