EditorInterface

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 24, 2026 License: MIT Imports: 49 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AddRootNode

func AddRootNode(node Node.Instance)

func Advanced

func Advanced() class

Advanced exposes a 1:1 low-level instance of the class, undocumented, for those who know what they are doing.

func CloseScene

func CloseScene() error

func DistractionFreeMode

func DistractionFreeMode() bool

func EditNode

func EditNode(node Node.Instance)

func EditResource

func EditResource(resource Resource.Instance)

func EditScript

func EditScript(script Script.Instance, column int)

func EditScriptOptions

func EditScriptOptions(script Script.Instance, line int, column int, grab_focus bool)

func GetBaseControl

func GetBaseControl() Control.Instance

func GetCommandPalette

func GetCommandPalette() EditorCommandPalette.Instance

func GetCurrentDirectory

func GetCurrentDirectory() string

func GetCurrentFeatureProfile

func GetCurrentFeatureProfile() string

func GetCurrentPath

func GetCurrentPath() string

func GetEditedSceneRoot

func GetEditedSceneRoot() Node.Instance

func GetEditorLanguage

func GetEditorLanguage() string

func GetEditorMainScreen

func GetEditorMainScreen() VBoxContainer.Instance

func GetEditorPaths

func GetEditorPaths() EditorPaths.Instance

func GetEditorScale

func GetEditorScale() Float.X

func GetEditorSettings

func GetEditorSettings() EditorSettings.Instance

func GetEditorTheme

func GetEditorTheme() Theme.Instance

func GetEditorToaster

func GetEditorToaster() EditorToaster.Instance

func GetEditorUndoRedo

func GetEditorUndoRedo() EditorUndoRedoManager.Instance

func GetEditorViewport2d

func GetEditorViewport2d() SubViewport.Instance

func GetEditorViewport3d

func GetEditorViewport3d(idx int) SubViewport.Instance

func GetFileSystemDock

func GetFileSystemDock() FileSystemDock.Instance

func GetInspector

func GetInspector() EditorInspector.Instance

func GetNode3dRotateSnap

func GetNode3dRotateSnap() Float.X

func GetNode3dScaleSnap

func GetNode3dScaleSnap() Float.X

func GetNode3dTranslateSnap

func GetNode3dTranslateSnap() Float.X

func GetOpenSceneRoots

func GetOpenSceneRoots() []Node.Instance

func GetOpenScenes

func GetOpenScenes() []string

func GetPlayingScene

func GetPlayingScene() string

func GetResourceFilesystem

func GetResourceFilesystem() EditorFileSystem.Instance

func GetResourcePreviewer

func GetResourcePreviewer() EditorResourcePreview.Instance

func GetScriptEditor

func GetScriptEditor() ScriptEditor.Instance

func GetSelectedPaths

func GetSelectedPaths() []string

func GetSelection

func GetSelection() EditorSelection.Instance

func InspectObject

func InspectObject(obj Object.Instance, for_property string, inspector_only bool)

func IsMultiWindowEnabled

func IsMultiWindowEnabled() bool

func IsNode3dSnapEnabled

func IsNode3dSnapEnabled() bool

func IsObjectEdited

func IsObjectEdited(obj Object.Instance) bool

func IsPlayingScene

func IsPlayingScene() bool

func IsPluginEnabled

func IsPluginEnabled(plugin string) bool

func MakeMeshPreviews

func MakeMeshPreviews(meshes []Mesh.Instance, preview_size int) []Texture2D.Instance

func MarkSceneAsUnsaved

func MarkSceneAsUnsaved()

func MovieMakerEnabled

func MovieMakerEnabled() bool

func OpenSceneFromPath

func OpenSceneFromPath(scene_filepath string, set_inherited bool)

func PlayCurrentScene

func PlayCurrentScene()

func PlayCustomScene

func PlayCustomScene(scene_filepath string)

func PlayMainScene

func PlayMainScene()

func PopupCreateDialog

func PopupCreateDialog(callback func(selected string), base_type string, current_type string, dialog_title string, type_blocklist []string)

func PopupDialog

func PopupDialog(dialog Window.Instance, rect Rect2i.PositionSize)

func PopupDialogCentered

func PopupDialogCentered(dialog Window.Instance, minsize Vector2i.XY)

func PopupDialogCenteredClamped

func PopupDialogCenteredClamped(dialog Window.Instance, minsize Vector2i.XY)

func PopupDialogCenteredClampedOptions

func PopupDialogCenteredClampedOptions(dialog Window.Instance, minsize Vector2i.XY, fallback_ratio Float.X)

func PopupDialogCenteredRatio

func PopupDialogCenteredRatio(dialog Window.Instance)

func PopupDialogCenteredRatioOptions

func PopupDialogCenteredRatioOptions(dialog Window.Instance, ratio Float.X)

func PopupMethodSelector

func PopupMethodSelector(obj Object.Instance, callback func(selected string), current_value string)

func PopupNodeSelector

func PopupNodeSelector(callback func(selected string), valid_types []string, current_value Node.Instance)

func PopupPropertySelector

func PopupPropertySelector(obj Object.Instance, callback func(selected string), type_filter []int32, current_value string)

func PopupQuickOpen

func PopupQuickOpen(callback func(selected string), base_types []string)

func ReloadSceneFromPath

func ReloadSceneFromPath(scene_filepath string)

func RestartEditor

func RestartEditor()

func RestartEditorOptions

func RestartEditorOptions(save bool)

func SaveAllScenes

func SaveAllScenes()

func SaveScene

func SaveScene() error

func SaveSceneAs

func SaveSceneAs(path string)

func SaveSceneAsOptions

func SaveSceneAsOptions(path string, with_preview bool)

func SelectFile

func SelectFile(file string)

func SetCurrentFeatureProfile

func SetCurrentFeatureProfile(profile_name string)

func SetDistractionFreeMode

func SetDistractionFreeMode(value bool)

SetDistractionFreeMode sets the property returned by [IsDistractionFreeModeEnabled].

func SetMainScreenEditor

func SetMainScreenEditor(name string)

func SetMovieMakerEnabled

func SetMovieMakerEnabled(value bool)

SetMovieMakerEnabled sets the property returned by [IsMovieMakerEnabled].

func SetObjectEdited

func SetObjectEdited(obj Object.Instance, edited bool)

func SetPluginEnabled

func SetPluginEnabled(plugin string, enabled bool)

func StopPlayingScene

func StopPlayingScene()

Types

type Extension

type Extension[T gdclass.Interface] struct{ gdclass.Extension[T, Instance] }

Extension can be embedded in a new struct to create a Go extension of this class.

T must be a type that is embedding this Extension as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.

func (*Extension[T]) AsObject

func (o *Extension[T]) AsObject() [1]gdreference.Object

type ID

type ID Object.ID

ID is a typed object ID (reference) to an instance of this class, use it to store references to objects with unknown lifetimes, as an ID will not panic on use if the underlying object has been destroyed.

func (ID) Instance

func (id ID) Instance() (Instance, bool)

type Instance

type Instance [1]gdclass.EditorInterface

Instance of the class with convieniently typed arguments and results.

func (Instance) AsObject

func (o Instance) AsObject() [1]gdreference.Object

func (Instance) ID

func (self Instance) ID() ID

func (*Instance) SetObject

func (self *Instance) SetObject(obj [1]gdreference.Object) bool

func (Instance) Virtual

func (self Instance) Virtual(name string) reflect.Value

type Singleton

type Singleton[T gdclass.Interface] = Extension[T]

Singleton can be embedded in a new struct to create a Go singleton extension of the class.

It will become available as a global inside scripts and any any other Go Extension types will have any *T typed fields filled in to point at this singleton once they have been instantiated.

T must be a type that is embedding this Singleton as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.

Jump to