EditorScenePostImportPlugin

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 24, 2026 License: MIT Imports: 28 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Advanced

type Advanced = class

Advanced exposes a 1:1 low-level instance of the class, undocumented, for those who know what they are doing.

type Any

type Any interface {
	gd.IsClass
	AsEditorScenePostImportPlugin() Instance
}

type Expanded

type Expanded = MoreArgs

type Extension

type Extension[T gdclass.Interface] struct{ gdclass.Extension[T, Instance] }

Extension can be embedded in a new struct to create a Go extension of this class.

T must be a type that is embedding this Extension as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way. See Interface for methods that can be overridden by T.

func (*Extension[T]) AddImportOption

func (o *Extension[T]) AddImportOption(name string, value any)

func (*Extension[T]) AsEditorScenePostImportPlugin

func (o *Extension[T]) AsEditorScenePostImportPlugin() Instance

func (*Extension[T]) AsObject

func (o *Extension[T]) AsObject() [1]gdreference.Object

func (*Extension[T]) AsRefCounted

func (o *Extension[T]) AsRefCounted() ie.RC

func (*Extension[T]) GetOptionValue

func (o *Extension[T]) GetOptionValue(name string) any

type ID

type ID Object.ID

ID is a typed object ID (reference) to an instance of this class, use it to store references to objects with unknown lifetimes, as an ID will not panic on use if the underlying object has been destroyed.

func (ID) Instance

func (id ID) Instance() (Instance, bool)

type Implementation

type Implementation = implementation

Implementation implements Interface with empty methods.

type Instance

Instance of the class with convieniently typed arguments and results.

var Nil Instance

Nil is a nil/null instance of the class. Equivalent to the zero value.

func New

func New() Instance

func (Instance) AddImportOption

func (self Instance) AddImportOption(name string, value any)

func (Instance) AddImportOptionAdvanced

func (self Instance) AddImportOptionAdvanced(atype variant.Type, name string, default_value any)

func (Instance) AsEditorScenePostImportPlugin

func (o Instance) AsEditorScenePostImportPlugin() Instance

func (Instance) AsObject

func (o Instance) AsObject() [1]gdreference.Object

func (Instance) AsRefCounted

func (o Instance) AsRefCounted() ie.RC

func (Instance) GetOptionValue

func (self Instance) GetOptionValue(name string) any

func (Instance) ID

func (self Instance) ID() ID

func (Instance) MoreArgs

func (self Instance) MoreArgs() MoreArgs

MoreArgs enables certain functions to be called with additional 'optional' arguments.

func (*Instance) SetObject

func (self *Instance) SetObject(obj [1]gdreference.Object) bool

func (Instance) Virtual

func (self Instance) Virtual(name string) reflect.Value

type Interface

type Interface interface {
	GetInternalImportOptions(category int)
	GetInternalOptionVisibility(category int, for_animation bool, option string) any
	GetInternalOptionUpdateViewRequired(category int, option string) any
	InternalProcess(category int, base_node Node.Instance, node Node.Instance, resource Resource.Instance)
	GetImportOptions(path string)
	GetOptionVisibility(path string, for_animation bool, option string) any
	PreProcess(scene Node.Instance)
	PostProcess(scene Node.Instance)
}

type InternalImportCategory

type InternalImportCategory int64 //gd:EditorScenePostImportPlugin.InternalImportCategory
const (
	InternalImportCategoryNode           InternalImportCategory = 0
	InternalImportCategoryMesh3dNode     InternalImportCategory = 1
	InternalImportCategoryMesh           InternalImportCategory = 2
	InternalImportCategoryMaterial       InternalImportCategory = 3
	InternalImportCategoryAnimation      InternalImportCategory = 4
	InternalImportCategoryAnimationNode  InternalImportCategory = 5
	InternalImportCategorySkeleton3dNode InternalImportCategory = 6
	InternalImportCategoryMax            InternalImportCategory = 7
)

type MoreArgs

MoreArgs is a container for Instance functions with additional 'optional' arguments.

func (MoreArgs) AddImportOptionAdvanced

func (self MoreArgs) AddImportOptionAdvanced(atype variant.Type, name string, default_value any, hint ClassDB.PropertyHint, hint_string string, usage_flags int)

type Singleton

type Singleton[T gdclass.Interface] = Extension[T]

Singleton can be embedded in a new struct to create a Go singleton extension of the class.

It will become available as a global inside scripts and any any other Go Extension types will have any *T typed fields filled in to point at this singleton once they have been instantiated.

T must be a type that is embedding this Singleton as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way. See Interface for methods that can be overridden by T.

Jump to