FontFile

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 24, 2026 License: MIT Imports: 33 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Advanced

type Advanced = class

Advanced exposes a 1:1 low-level instance of the class, undocumented, for those who know what they are doing.

type Any

type Any interface {
	gd.IsClass
	AsFontFile() Instance
}

type Extension

type Extension[T gdclass.Interface] struct{ gdclass.Extension[T, Instance] }

Extension can be embedded in a new struct to create a Go extension of this class.

T must be a type that is embedding this Extension as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.

func (*Extension[T]) AllowSystemFallback

func (o *Extension[T]) AllowSystemFallback() bool

func (*Extension[T]) Antialiasing

func (o *Extension[T]) Antialiasing() TextServer.FontAntialiasing

func (*Extension[T]) AsFont

func (o *Extension[T]) AsFont() Font.Instance

func (*Extension[T]) AsFontFile

func (o *Extension[T]) AsFontFile() Instance

func (*Extension[T]) AsObject

func (o *Extension[T]) AsObject() [1]gdreference.Object

func (*Extension[T]) AsRefCounted

func (o *Extension[T]) AsRefCounted() ie.RC

func (*Extension[T]) AsResource

func (o *Extension[T]) AsResource() Resource.Instance

func (*Extension[T]) ClearCache

func (o *Extension[T]) ClearCache()

func (*Extension[T]) ClearGlyphs

func (o *Extension[T]) ClearGlyphs(cache_index int, size Vector2i.XY)

func (*Extension[T]) ClearKerningMap

func (o *Extension[T]) ClearKerningMap(cache_index int, size int)

func (*Extension[T]) ClearSizeCache

func (o *Extension[T]) ClearSizeCache(cache_index int)

func (*Extension[T]) ClearTextures

func (o *Extension[T]) ClearTextures(cache_index int, size Vector2i.XY)

func (*Extension[T]) Data

func (o *Extension[T]) Data() []byte

func (*Extension[T]) DisableEmbeddedBitmaps

func (o *Extension[T]) DisableEmbeddedBitmaps() bool

func (*Extension[T]) EmitChanged

func (o *Extension[T]) EmitChanged()

EmitChanged is promoted from Resource.Instance.EmitChanged.

func (*Extension[T]) Fallbacks

func (o *Extension[T]) Fallbacks() []Font.Instance

func (*Extension[T]) FixedSize

func (o *Extension[T]) FixedSize() int

func (*Extension[T]) FixedSizeScaleMode

func (o *Extension[T]) FixedSizeScaleMode() TextServer.FixedSizeScaleMode

func (*Extension[T]) ForceAutohinter

func (o *Extension[T]) ForceAutohinter() bool

func (*Extension[T]) GenerateMipmaps

func (o *Extension[T]) GenerateMipmaps() bool

func (*Extension[T]) GetCacheAscent

func (o *Extension[T]) GetCacheAscent(cache_index int, size int) Float.X

func (*Extension[T]) GetCacheCount

func (o *Extension[T]) GetCacheCount() int

func (*Extension[T]) GetCacheDescent

func (o *Extension[T]) GetCacheDescent(cache_index int, size int) Float.X

func (*Extension[T]) GetCacheScale

func (o *Extension[T]) GetCacheScale(cache_index int, size int) Float.X

func (*Extension[T]) GetCacheUnderlinePosition

func (o *Extension[T]) GetCacheUnderlinePosition(cache_index int, size int) Float.X

func (*Extension[T]) GetCacheUnderlineThickness

func (o *Extension[T]) GetCacheUnderlineThickness(cache_index int, size int) Float.X

func (*Extension[T]) GetCharFromGlyphIndex

func (o *Extension[T]) GetCharFromGlyphIndex(size int, glyph_index int) int

func (*Extension[T]) GetCharSize

func (o *Extension[T]) GetCharSize(char int, font_size int) Vector2.XY

GetCharSize is promoted from Font.Instance.GetCharSize.

func (*Extension[T]) GetEmbolden

func (o *Extension[T]) GetEmbolden(cache_index int) Float.X

func (*Extension[T]) GetExtraBaselineOffset

func (o *Extension[T]) GetExtraBaselineOffset(cache_index int) Float.X

func (*Extension[T]) GetExtraSpacing

func (o *Extension[T]) GetExtraSpacing(cache_index int, spacing TextServer.SpacingType) int

func (*Extension[T]) GetFaceCount

func (o *Extension[T]) GetFaceCount() int

GetFaceCount is promoted from Font.Instance.GetFaceCount.

func (*Extension[T]) GetFaceIndex

func (o *Extension[T]) GetFaceIndex(cache_index int) int

func (*Extension[T]) GetFontName

func (o *Extension[T]) GetFontName() string

GetFontName is promoted from Font.Instance.GetFontName.

func (*Extension[T]) GetFontStretch

func (o *Extension[T]) GetFontStretch() int

GetFontStretch is promoted from Font.Instance.GetFontStretch.

func (*Extension[T]) GetFontStyle

func (o *Extension[T]) GetFontStyle() TextServer.FontStyle

GetFontStyle is promoted from Font.Instance.GetFontStyle.

func (*Extension[T]) GetFontStyleName

func (o *Extension[T]) GetFontStyleName() string

GetFontStyleName is promoted from Font.Instance.GetFontStyleName.

func (*Extension[T]) GetFontWeight

func (o *Extension[T]) GetFontWeight() int

GetFontWeight is promoted from Font.Instance.GetFontWeight.

func (*Extension[T]) GetGlyphAdvance

func (o *Extension[T]) GetGlyphAdvance(cache_index int, size int, glyph int) Vector2.XY

func (*Extension[T]) GetGlyphIndex

func (o *Extension[T]) GetGlyphIndex(size int, char int, variation_selector int) int

func (*Extension[T]) GetGlyphList

func (o *Extension[T]) GetGlyphList(cache_index int, size Vector2i.XY) []int32

func (*Extension[T]) GetGlyphOffset

func (o *Extension[T]) GetGlyphOffset(cache_index int, size Vector2i.XY, glyph int) Vector2.XY

func (*Extension[T]) GetGlyphSize

func (o *Extension[T]) GetGlyphSize(cache_index int, size Vector2i.XY, glyph int) Vector2.XY

func (*Extension[T]) GetGlyphTextureIdx

func (o *Extension[T]) GetGlyphTextureIdx(cache_index int, size Vector2i.XY, glyph int) int

func (*Extension[T]) GetGlyphUvRect

func (o *Extension[T]) GetGlyphUvRect(cache_index int, size Vector2i.XY, glyph int) Rect2.PositionSize

func (*Extension[T]) GetIdForPath

func (o *Extension[T]) GetIdForPath(path string) string

GetIdForPath is promoted from Resource.Instance.GetIdForPath.

func (*Extension[T]) GetKerning

func (o *Extension[T]) GetKerning(cache_index int, size int, glyph_pair Vector2i.XY) Vector2.XY

func (*Extension[T]) GetKerningList

func (o *Extension[T]) GetKerningList(cache_index int, size int) []Vector2i.XY

func (*Extension[T]) GetLanguageSupportOverride

func (o *Extension[T]) GetLanguageSupportOverride(language string) bool

func (*Extension[T]) GetLanguageSupportOverrides

func (o *Extension[T]) GetLanguageSupportOverrides() []string

func (*Extension[T]) GetOpentypeFeatures

func (o *Extension[T]) GetOpentypeFeatures() map[string][2]string

GetOpentypeFeatures is promoted from Font.Instance.GetOpentypeFeatures.

func (*Extension[T]) GetOtNameStrings

func (o *Extension[T]) GetOtNameStrings() map[string]map[string]string

GetOtNameStrings is promoted from Font.Instance.GetOtNameStrings.

func (*Extension[T]) GetRid

func (o *Extension[T]) GetRid() Resource.ID

GetRid is promoted from Resource.Instance.GetRid.

func (*Extension[T]) GetRids

func (o *Extension[T]) GetRids() []RID.Font

GetRids is promoted from Font.Instance.GetRids.

func (*Extension[T]) GetScriptSupportOverride

func (o *Extension[T]) GetScriptSupportOverride(script string) bool

func (*Extension[T]) GetScriptSupportOverrides

func (o *Extension[T]) GetScriptSupportOverrides() []string

func (*Extension[T]) GetSizeCacheList

func (o *Extension[T]) GetSizeCacheList(cache_index int) []Vector2i.XY

func (*Extension[T]) GetSpacing

func (o *Extension[T]) GetSpacing(spacing TextServer.SpacingType) int

GetSpacing is promoted from Font.Instance.GetSpacing.

func (*Extension[T]) GetSupportedChars

func (o *Extension[T]) GetSupportedChars() string

GetSupportedChars is promoted from Font.Instance.GetSupportedChars.

func (*Extension[T]) GetSupportedFeatureList

func (o *Extension[T]) GetSupportedFeatureList() map[string]Font.OpenTypeFeature

GetSupportedFeatureList is promoted from Font.Instance.GetSupportedFeatureList.

func (*Extension[T]) GetSupportedVariationList

func (o *Extension[T]) GetSupportedVariationList() map[int]struct {
	X int32
	Y int32
	Z int32
}

GetSupportedVariationList is promoted from Font.Instance.GetSupportedVariationList.

func (*Extension[T]) GetTextureCount

func (o *Extension[T]) GetTextureCount(cache_index int, size Vector2i.XY) int

func (*Extension[T]) GetTextureImage

func (o *Extension[T]) GetTextureImage(cache_index int, size Vector2i.XY, texture_index int) Image.Instance

func (*Extension[T]) GetTextureOffsets

func (o *Extension[T]) GetTextureOffsets(cache_index int, size Vector2i.XY, texture_index int) []int32

func (*Extension[T]) GetTransform

func (o *Extension[T]) GetTransform(cache_index int) Transform2D.OriginXY

func (*Extension[T]) GetVariationCoordinates

func (o *Extension[T]) GetVariationCoordinates(cache_index int) map[string]float32

func (*Extension[T]) HasChar

func (o *Extension[T]) HasChar(char int) bool

HasChar is promoted from Font.Instance.HasChar.

func (*Extension[T]) Hinting

func (o *Extension[T]) Hinting() TextServer.Hinting

func (*Extension[T]) IsBuiltIn

func (o *Extension[T]) IsBuiltIn() bool

IsBuiltIn is promoted from Resource.Instance.IsBuiltIn.

func (*Extension[T]) IsLanguageSupported

func (o *Extension[T]) IsLanguageSupported(language string) bool

IsLanguageSupported is promoted from Font.Instance.IsLanguageSupported.

func (*Extension[T]) IsScriptSupported

func (o *Extension[T]) IsScriptSupported(script string) bool

IsScriptSupported is promoted from Font.Instance.IsScriptSupported.

func (*Extension[T]) KeepRoundingRemainders

func (o *Extension[T]) KeepRoundingRemainders() bool

func (*Extension[T]) LoadBitmapFont

func (o *Extension[T]) LoadBitmapFont(path string) error

func (*Extension[T]) LoadDynamicFont

func (o *Extension[T]) LoadDynamicFont(path string) error

func (*Extension[T]) ModulateColorGlyphs

func (o *Extension[T]) ModulateColorGlyphs() bool

func (*Extension[T]) MsdfPixelRange

func (o *Extension[T]) MsdfPixelRange() int

func (*Extension[T]) MsdfSize

func (o *Extension[T]) MsdfSize() int

func (*Extension[T]) MultichannelSignedDistanceField

func (o *Extension[T]) MultichannelSignedDistanceField() bool

func (*Extension[T]) OnChanged

func (o *Extension[T]) OnChanged(cb func(), flags ...Signal.Flags) *Extension[T]

OnChanged is promoted from Resource.Instance.OnChanged.

func (*Extension[T]) OnSetupLocalToSceneRequested

func (o *Extension[T]) OnSetupLocalToSceneRequested(cb func(), flags ...Signal.Flags) *Extension[T]

OnSetupLocalToSceneRequested is promoted from Resource.Instance.OnSetupLocalToSceneRequested.

func (*Extension[T]) OpentypeFeatureOverrides

func (o *Extension[T]) OpentypeFeatureOverrides() map[any]any

func (*Extension[T]) Oversampling

func (o *Extension[T]) Oversampling() Float.X

func (*Extension[T]) RemoveCache

func (o *Extension[T]) RemoveCache(cache_index int)

func (*Extension[T]) RemoveGlyph

func (o *Extension[T]) RemoveGlyph(cache_index int, size Vector2i.XY, glyph int)

func (*Extension[T]) RemoveKerning

func (o *Extension[T]) RemoveKerning(cache_index int, size int, glyph_pair Vector2i.XY)

func (*Extension[T]) RemoveLanguageSupportOverride

func (o *Extension[T]) RemoveLanguageSupportOverride(language string)

func (*Extension[T]) RemoveScriptSupportOverride

func (o *Extension[T]) RemoveScriptSupportOverride(script string)

func (*Extension[T]) RemoveSizeCache

func (o *Extension[T]) RemoveSizeCache(cache_index int, size Vector2i.XY)

func (*Extension[T]) RemoveTexture

func (o *Extension[T]) RemoveTexture(cache_index int, size Vector2i.XY, texture_index int)

func (*Extension[T]) RenderGlyph

func (o *Extension[T]) RenderGlyph(cache_index int, size Vector2i.XY, index int)

func (*Extension[T]) RenderRange

func (o *Extension[T]) RenderRange(cache_index int, size Vector2i.XY, start int, end int)

func (*Extension[T]) ResetState

func (o *Extension[T]) ResetState()

ResetState is promoted from Resource.Instance.ResetState.

func (*Extension[T]) ResourceLocalToScene

func (o *Extension[T]) ResourceLocalToScene() bool

func (*Extension[T]) ResourceName

func (o *Extension[T]) ResourceName() string

func (*Extension[T]) ResourcePath

func (o *Extension[T]) ResourcePath() string

func (*Extension[T]) ResourceSceneUniqueId

func (o *Extension[T]) ResourceSceneUniqueId() string

func (*Extension[T]) SetAllowSystemFallback

func (o *Extension[T]) SetAllowSystemFallback(value bool) *Extension[T]

func (*Extension[T]) SetAntialiasing

func (o *Extension[T]) SetAntialiasing(value TextServer.FontAntialiasing) *Extension[T]

func (*Extension[T]) SetCacheAscent

func (o *Extension[T]) SetCacheAscent(cache_index int, size int, ascent Float.X) *Extension[T]

func (*Extension[T]) SetCacheCapacity

func (o *Extension[T]) SetCacheCapacity(single_line int, multi_line int) *Extension[T]

SetCacheCapacity is promoted from Font.Instance.SetCacheCapacity.

func (*Extension[T]) SetCacheDescent

func (o *Extension[T]) SetCacheDescent(cache_index int, size int, descent Float.X) *Extension[T]

func (*Extension[T]) SetCacheScale

func (o *Extension[T]) SetCacheScale(cache_index int, size int, scale Float.X) *Extension[T]

func (*Extension[T]) SetCacheUnderlinePosition

func (o *Extension[T]) SetCacheUnderlinePosition(cache_index int, size int, underline_position Float.X) *Extension[T]

func (*Extension[T]) SetCacheUnderlineThickness

func (o *Extension[T]) SetCacheUnderlineThickness(cache_index int, size int, underline_thickness Float.X) *Extension[T]

func (*Extension[T]) SetData

func (o *Extension[T]) SetData(value []byte) *Extension[T]

func (*Extension[T]) SetDisableEmbeddedBitmaps

func (o *Extension[T]) SetDisableEmbeddedBitmaps(value bool) *Extension[T]

func (*Extension[T]) SetEmbolden

func (o *Extension[T]) SetEmbolden(cache_index int, strength Float.X) *Extension[T]

func (*Extension[T]) SetExtraBaselineOffset

func (o *Extension[T]) SetExtraBaselineOffset(cache_index int, baseline_offset Float.X) *Extension[T]

func (*Extension[T]) SetExtraSpacing

func (o *Extension[T]) SetExtraSpacing(cache_index int, spacing TextServer.SpacingType, value int) *Extension[T]

func (*Extension[T]) SetFaceIndex

func (o *Extension[T]) SetFaceIndex(cache_index int, face_index int) *Extension[T]

func (*Extension[T]) SetFallbacks

func (o *Extension[T]) SetFallbacks(value []Font.Instance) *Extension[T]

func (*Extension[T]) SetFixedSize

func (o *Extension[T]) SetFixedSize(value int) *Extension[T]

func (*Extension[T]) SetFixedSizeScaleMode

func (o *Extension[T]) SetFixedSizeScaleMode(value TextServer.FixedSizeScaleMode) *Extension[T]

func (*Extension[T]) SetFontName

func (o *Extension[T]) SetFontName(value string) *Extension[T]

func (*Extension[T]) SetFontStretch

func (o *Extension[T]) SetFontStretch(value int) *Extension[T]

func (*Extension[T]) SetFontStyle

func (o *Extension[T]) SetFontStyle(value TextServer.FontStyle) *Extension[T]

func (*Extension[T]) SetFontWeight

func (o *Extension[T]) SetFontWeight(value int) *Extension[T]

func (*Extension[T]) SetForceAutohinter

func (o *Extension[T]) SetForceAutohinter(value bool) *Extension[T]

func (*Extension[T]) SetGenerateMipmaps

func (o *Extension[T]) SetGenerateMipmaps(value bool) *Extension[T]

func (*Extension[T]) SetGlyphAdvance

func (o *Extension[T]) SetGlyphAdvance(cache_index int, size int, glyph int, advance Vector2.XY) *Extension[T]

func (*Extension[T]) SetGlyphOffset

func (o *Extension[T]) SetGlyphOffset(cache_index int, size Vector2i.XY, glyph int, offset Vector2.XY) *Extension[T]

func (*Extension[T]) SetGlyphSize

func (o *Extension[T]) SetGlyphSize(cache_index int, size Vector2i.XY, glyph int, gl_size Vector2.XY) *Extension[T]

func (*Extension[T]) SetGlyphTextureIdx

func (o *Extension[T]) SetGlyphTextureIdx(cache_index int, size Vector2i.XY, glyph int, texture_idx int) *Extension[T]

func (*Extension[T]) SetGlyphUvRect

func (o *Extension[T]) SetGlyphUvRect(cache_index int, size Vector2i.XY, glyph int, uv_rect Rect2.PositionSize) *Extension[T]

func (*Extension[T]) SetHinting

func (o *Extension[T]) SetHinting(value TextServer.Hinting) *Extension[T]

func (*Extension[T]) SetIdForPath

func (o *Extension[T]) SetIdForPath(path string, id string) *Extension[T]

SetIdForPath is promoted from Resource.Instance.SetIdForPath.

func (*Extension[T]) SetKeepRoundingRemainders

func (o *Extension[T]) SetKeepRoundingRemainders(value bool) *Extension[T]

func (*Extension[T]) SetKerning

func (o *Extension[T]) SetKerning(cache_index int, size int, glyph_pair Vector2i.XY, kerning Vector2.XY) *Extension[T]

func (*Extension[T]) SetLanguageSupportOverride

func (o *Extension[T]) SetLanguageSupportOverride(language string, supported bool) *Extension[T]

func (*Extension[T]) SetModulateColorGlyphs

func (o *Extension[T]) SetModulateColorGlyphs(value bool) *Extension[T]

func (*Extension[T]) SetMsdfPixelRange

func (o *Extension[T]) SetMsdfPixelRange(value int) *Extension[T]

func (*Extension[T]) SetMsdfSize

func (o *Extension[T]) SetMsdfSize(value int) *Extension[T]

func (*Extension[T]) SetMultichannelSignedDistanceField

func (o *Extension[T]) SetMultichannelSignedDistanceField(value bool) *Extension[T]

func (*Extension[T]) SetOpentypeFeatureOverrides

func (o *Extension[T]) SetOpentypeFeatureOverrides(value map[any]any) *Extension[T]

func (*Extension[T]) SetOversampling

func (o *Extension[T]) SetOversampling(value Float.X) *Extension[T]

func (*Extension[T]) SetPathCache

func (o *Extension[T]) SetPathCache(path string) *Extension[T]

SetPathCache is promoted from Resource.Instance.SetPathCache.

func (*Extension[T]) SetResourceLocalToScene

func (o *Extension[T]) SetResourceLocalToScene(value bool) *Extension[T]

func (*Extension[T]) SetResourceName

func (o *Extension[T]) SetResourceName(value string) *Extension[T]

func (*Extension[T]) SetResourcePath

func (o *Extension[T]) SetResourcePath(value string) *Extension[T]

func (*Extension[T]) SetResourceSceneUniqueId

func (o *Extension[T]) SetResourceSceneUniqueId(value string) *Extension[T]

func (*Extension[T]) SetScriptSupportOverride

func (o *Extension[T]) SetScriptSupportOverride(script string, supported bool) *Extension[T]

func (*Extension[T]) SetStyleName

func (o *Extension[T]) SetStyleName(value string) *Extension[T]

func (*Extension[T]) SetSubpixelPositioning

func (o *Extension[T]) SetSubpixelPositioning(value TextServer.SubpixelPositioning) *Extension[T]

func (*Extension[T]) SetTextureImage

func (o *Extension[T]) SetTextureImage(cache_index int, size Vector2i.XY, texture_index int, image Image.Instance) *Extension[T]

func (*Extension[T]) SetTextureOffsets

func (o *Extension[T]) SetTextureOffsets(cache_index int, size Vector2i.XY, texture_index int, offset []int32) *Extension[T]

func (*Extension[T]) SetTransform

func (o *Extension[T]) SetTransform(cache_index int, transform Transform2D.OriginXY) *Extension[T]

func (*Extension[T]) SetVariationCoordinates

func (o *Extension[T]) SetVariationCoordinates(cache_index int, variation_coordinates map[string]float32) *Extension[T]

func (*Extension[T]) SetupLocalToScene

func (o *Extension[T]) SetupLocalToScene()

SetupLocalToScene is promoted from Resource.Instance.SetupLocalToScene.

func (*Extension[T]) SubpixelPositioning

func (o *Extension[T]) SubpixelPositioning() TextServer.SubpixelPositioning

func (*Extension[T]) TakeOverPath

func (o *Extension[T]) TakeOverPath(path string)

TakeOverPath is promoted from Resource.Instance.TakeOverPath.

type ID

type ID Object.ID

ID is a typed object ID (reference) to an instance of this class, use it to store references to objects with unknown lifetimes, as an ID will not panic on use if the underlying object has been destroyed.

func (ID) Instance

func (id ID) Instance() (Instance, bool)

type Instance

type Instance [1]gdclass.FontFile

Instance of the class with convieniently typed arguments and results.

var Nil Instance

Nil is a nil/null instance of the class. Equivalent to the zero value.

func New

func New() Instance

func (Instance) AllowSystemFallback

func (self Instance) AllowSystemFallback() bool

func (Instance) Antialiasing

func (self Instance) Antialiasing() TextServer.FontAntialiasing

func (Instance) AsFont

func (o Instance) AsFont() Font.Instance

func (Instance) AsFontFile

func (o Instance) AsFontFile() Instance

func (Instance) AsObject

func (o Instance) AsObject() [1]gdreference.Object

func (Instance) AsRefCounted

func (o Instance) AsRefCounted() ie.RC

func (Instance) AsResource

func (o Instance) AsResource() Resource.Instance

func (Instance) ClearCache

func (self Instance) ClearCache()

func (Instance) ClearGlyphs

func (self Instance) ClearGlyphs(cache_index int, size Vector2i.XY)

func (Instance) ClearKerningMap

func (self Instance) ClearKerningMap(cache_index int, size int)

func (Instance) ClearSizeCache

func (self Instance) ClearSizeCache(cache_index int)

func (Instance) ClearTextures

func (self Instance) ClearTextures(cache_index int, size Vector2i.XY)

func (Instance) Data

func (self Instance) Data() []byte

func (Instance) DisableEmbeddedBitmaps

func (self Instance) DisableEmbeddedBitmaps() bool

func (Instance) EmitChanged

func (self Instance) EmitChanged()

EmitChanged is promoted from Resource.Instance.EmitChanged.

func (Instance) Fallbacks

func (self Instance) Fallbacks() []Font.Instance

Fallbacks is promoted from Font.Instance.Fallbacks.

func (Instance) FixedSize

func (self Instance) FixedSize() int

func (Instance) FixedSizeScaleMode

func (self Instance) FixedSizeScaleMode() TextServer.FixedSizeScaleMode

func (Instance) ForceAutohinter

func (self Instance) ForceAutohinter() bool

func (Instance) GenerateMipmaps

func (self Instance) GenerateMipmaps() bool

func (Instance) GetCacheAscent

func (self Instance) GetCacheAscent(cache_index int, size int) Float.X

func (Instance) GetCacheCount

func (self Instance) GetCacheCount() int

func (Instance) GetCacheDescent

func (self Instance) GetCacheDescent(cache_index int, size int) Float.X

func (Instance) GetCacheScale

func (self Instance) GetCacheScale(cache_index int, size int) Float.X

func (Instance) GetCacheUnderlinePosition

func (self Instance) GetCacheUnderlinePosition(cache_index int, size int) Float.X

func (Instance) GetCacheUnderlineThickness

func (self Instance) GetCacheUnderlineThickness(cache_index int, size int) Float.X

func (Instance) GetCharFromGlyphIndex

func (self Instance) GetCharFromGlyphIndex(size int, glyph_index int) int

func (Instance) GetCharSize

func (self Instance) GetCharSize(char int, font_size int) Vector2.XY

GetCharSize is promoted from Font.Instance.GetCharSize.

func (Instance) GetEmbolden

func (self Instance) GetEmbolden(cache_index int) Float.X

func (Instance) GetExtraBaselineOffset

func (self Instance) GetExtraBaselineOffset(cache_index int) Float.X

func (Instance) GetExtraSpacing

func (self Instance) GetExtraSpacing(cache_index int, spacing TextServer.SpacingType) int

func (Instance) GetFaceCount

func (self Instance) GetFaceCount() int

GetFaceCount is promoted from Font.Instance.GetFaceCount.

func (Instance) GetFaceIndex

func (self Instance) GetFaceIndex(cache_index int) int

func (Instance) GetFontName

func (self Instance) GetFontName() string

GetFontName is promoted from Font.Instance.GetFontName.

func (Instance) GetFontStretch

func (self Instance) GetFontStretch() int

GetFontStretch is promoted from Font.Instance.GetFontStretch.

func (Instance) GetFontStyle

func (self Instance) GetFontStyle() TextServer.FontStyle

GetFontStyle is promoted from Font.Instance.GetFontStyle.

func (Instance) GetFontStyleName

func (self Instance) GetFontStyleName() string

GetFontStyleName is promoted from Font.Instance.GetFontStyleName.

func (Instance) GetFontWeight

func (self Instance) GetFontWeight() int

GetFontWeight is promoted from Font.Instance.GetFontWeight.

func (Instance) GetGlyphAdvance

func (self Instance) GetGlyphAdvance(cache_index int, size int, glyph int) Vector2.XY

func (Instance) GetGlyphIndex

func (self Instance) GetGlyphIndex(size int, char int, variation_selector int) int

func (Instance) GetGlyphList

func (self Instance) GetGlyphList(cache_index int, size Vector2i.XY) []int32

func (Instance) GetGlyphOffset

func (self Instance) GetGlyphOffset(cache_index int, size Vector2i.XY, glyph int) Vector2.XY

func (Instance) GetGlyphSize

func (self Instance) GetGlyphSize(cache_index int, size Vector2i.XY, glyph int) Vector2.XY

func (Instance) GetGlyphTextureIdx

func (self Instance) GetGlyphTextureIdx(cache_index int, size Vector2i.XY, glyph int) int

func (Instance) GetGlyphUvRect

func (self Instance) GetGlyphUvRect(cache_index int, size Vector2i.XY, glyph int) Rect2.PositionSize

func (Instance) GetIdForPath

func (self Instance) GetIdForPath(path string) string

GetIdForPath is promoted from Resource.Instance.GetIdForPath.

func (Instance) GetKerning

func (self Instance) GetKerning(cache_index int, size int, glyph_pair Vector2i.XY) Vector2.XY

func (Instance) GetKerningList

func (self Instance) GetKerningList(cache_index int, size int) []Vector2i.XY

func (Instance) GetLanguageSupportOverride

func (self Instance) GetLanguageSupportOverride(language string) bool

func (Instance) GetLanguageSupportOverrides

func (self Instance) GetLanguageSupportOverrides() []string

func (Instance) GetOpentypeFeatures

func (self Instance) GetOpentypeFeatures() map[string][2]string

GetOpentypeFeatures is promoted from Font.Instance.GetOpentypeFeatures.

func (Instance) GetOtNameStrings

func (self Instance) GetOtNameStrings() map[string]map[string]string

GetOtNameStrings is promoted from Font.Instance.GetOtNameStrings.

func (Instance) GetRid

func (self Instance) GetRid() Resource.ID

GetRid is promoted from Resource.Instance.GetRid.

func (Instance) GetRids

func (self Instance) GetRids() []RID.Font

GetRids is promoted from Font.Instance.GetRids.

func (Instance) GetScriptSupportOverride

func (self Instance) GetScriptSupportOverride(script string) bool

func (Instance) GetScriptSupportOverrides

func (self Instance) GetScriptSupportOverrides() []string

func (Instance) GetSizeCacheList

func (self Instance) GetSizeCacheList(cache_index int) []Vector2i.XY

func (Instance) GetSpacing

func (self Instance) GetSpacing(spacing TextServer.SpacingType) int

GetSpacing is promoted from Font.Instance.GetSpacing.

func (Instance) GetSupportedChars

func (self Instance) GetSupportedChars() string

GetSupportedChars is promoted from Font.Instance.GetSupportedChars.

func (Instance) GetSupportedFeatureList

func (self Instance) GetSupportedFeatureList() map[string]Font.OpenTypeFeature

GetSupportedFeatureList is promoted from Font.Instance.GetSupportedFeatureList.

func (Instance) GetSupportedVariationList

func (self Instance) GetSupportedVariationList() map[int]struct {
	X int32
	Y int32
	Z int32
}

GetSupportedVariationList is promoted from Font.Instance.GetSupportedVariationList.

func (Instance) GetTextureCount

func (self Instance) GetTextureCount(cache_index int, size Vector2i.XY) int

func (Instance) GetTextureImage

func (self Instance) GetTextureImage(cache_index int, size Vector2i.XY, texture_index int) Image.Instance

func (Instance) GetTextureOffsets

func (self Instance) GetTextureOffsets(cache_index int, size Vector2i.XY, texture_index int) []int32

func (Instance) GetTransform

func (self Instance) GetTransform(cache_index int) Transform2D.OriginXY

func (Instance) GetVariationCoordinates

func (self Instance) GetVariationCoordinates(cache_index int) map[string]float32

func (Instance) HasChar

func (self Instance) HasChar(char int) bool

HasChar is promoted from Font.Instance.HasChar.

func (Instance) Hinting

func (self Instance) Hinting() TextServer.Hinting

func (Instance) ID

func (self Instance) ID() ID

func (Instance) IsBuiltIn

func (self Instance) IsBuiltIn() bool

IsBuiltIn is promoted from Resource.Instance.IsBuiltIn.

func (Instance) IsLanguageSupported

func (self Instance) IsLanguageSupported(language string) bool

IsLanguageSupported is promoted from Font.Instance.IsLanguageSupported.

func (Instance) IsScriptSupported

func (self Instance) IsScriptSupported(script string) bool

IsScriptSupported is promoted from Font.Instance.IsScriptSupported.

func (Instance) KeepRoundingRemainders

func (self Instance) KeepRoundingRemainders() bool

func (Instance) LoadBitmapFont

func (self Instance) LoadBitmapFont(path string) error

func (Instance) LoadDynamicFont

func (self Instance) LoadDynamicFont(path string) error

func (Instance) ModulateColorGlyphs

func (self Instance) ModulateColorGlyphs() bool

func (Instance) MsdfPixelRange

func (self Instance) MsdfPixelRange() int

func (Instance) MsdfSize

func (self Instance) MsdfSize() int

func (Instance) MultichannelSignedDistanceField

func (self Instance) MultichannelSignedDistanceField() bool

func (Instance) OnChanged

func (self Instance) OnChanged(cb func(), flags ...Signal.Flags) Instance

OnChanged is promoted from Resource.Instance.OnChanged.

func (Instance) OnSetupLocalToSceneRequested

func (self Instance) OnSetupLocalToSceneRequested(cb func(), flags ...Signal.Flags) Instance

OnSetupLocalToSceneRequested is promoted from Resource.Instance.OnSetupLocalToSceneRequested.

func (Instance) OpentypeFeatureOverrides

func (self Instance) OpentypeFeatureOverrides() map[any]any

func (Instance) Oversampling

func (self Instance) Oversampling() Float.X

func (Instance) RemoveCache

func (self Instance) RemoveCache(cache_index int)

func (Instance) RemoveGlyph

func (self Instance) RemoveGlyph(cache_index int, size Vector2i.XY, glyph int)

func (Instance) RemoveKerning

func (self Instance) RemoveKerning(cache_index int, size int, glyph_pair Vector2i.XY)

func (Instance) RemoveLanguageSupportOverride

func (self Instance) RemoveLanguageSupportOverride(language string)

func (Instance) RemoveScriptSupportOverride

func (self Instance) RemoveScriptSupportOverride(script string)

func (Instance) RemoveSizeCache

func (self Instance) RemoveSizeCache(cache_index int, size Vector2i.XY)

func (Instance) RemoveTexture

func (self Instance) RemoveTexture(cache_index int, size Vector2i.XY, texture_index int)

func (Instance) RenderGlyph

func (self Instance) RenderGlyph(cache_index int, size Vector2i.XY, index int)

func (Instance) RenderRange

func (self Instance) RenderRange(cache_index int, size Vector2i.XY, start int, end int)

func (Instance) ResetState

func (self Instance) ResetState()

ResetState is promoted from Resource.Instance.ResetState.

func (Instance) ResourceLocalToScene

func (self Instance) ResourceLocalToScene() bool

ResourceLocalToScene is promoted from Resource.Instance.ResourceLocalToScene.

func (Instance) ResourceName

func (self Instance) ResourceName() string

ResourceName is promoted from Resource.Instance.ResourceName.

func (Instance) ResourcePath

func (self Instance) ResourcePath() string

ResourcePath is promoted from Resource.Instance.ResourcePath.

func (Instance) ResourceSceneUniqueId

func (self Instance) ResourceSceneUniqueId() string

ResourceSceneUniqueId is promoted from Resource.Instance.ResourceSceneUniqueId.

func (Instance) SetAllowSystemFallback

func (self Instance) SetAllowSystemFallback(value bool) Instance

SetAllowSystemFallback sets the property returned by [IsAllowSystemFallback]. Returns the instance, so that property settings can be chained.

func (Instance) SetAntialiasing

func (self Instance) SetAntialiasing(value TextServer.FontAntialiasing) Instance

SetAntialiasing sets the property returned by [GetAntialiasing]. Returns the instance, so that property settings can be chained.

func (Instance) SetCacheAscent

func (self Instance) SetCacheAscent(cache_index int, size int, ascent Float.X) Instance

func (Instance) SetCacheCapacity

func (self Instance) SetCacheCapacity(single_line int, multi_line int) Instance

SetCacheCapacity is promoted from Font.Instance.SetCacheCapacity.

func (Instance) SetCacheDescent

func (self Instance) SetCacheDescent(cache_index int, size int, descent Float.X) Instance

func (Instance) SetCacheScale

func (self Instance) SetCacheScale(cache_index int, size int, scale Float.X) Instance

func (Instance) SetCacheUnderlinePosition

func (self Instance) SetCacheUnderlinePosition(cache_index int, size int, underline_position Float.X) Instance

func (Instance) SetCacheUnderlineThickness

func (self Instance) SetCacheUnderlineThickness(cache_index int, size int, underline_thickness Float.X) Instance

func (Instance) SetData

func (self Instance) SetData(value []byte) Instance

SetData sets the property returned by [GetData]. Returns the instance, so that property settings can be chained.

func (Instance) SetDisableEmbeddedBitmaps

func (self Instance) SetDisableEmbeddedBitmaps(value bool) Instance

SetDisableEmbeddedBitmaps sets the property returned by [GetDisableEmbeddedBitmaps]. Returns the instance, so that property settings can be chained.

func (Instance) SetEmbolden

func (self Instance) SetEmbolden(cache_index int, strength Float.X) Instance

func (Instance) SetExtraBaselineOffset

func (self Instance) SetExtraBaselineOffset(cache_index int, baseline_offset Float.X) Instance

func (Instance) SetExtraSpacing

func (self Instance) SetExtraSpacing(cache_index int, spacing TextServer.SpacingType, value int) Instance

func (Instance) SetFaceIndex

func (self Instance) SetFaceIndex(cache_index int, face_index int) Instance

func (Instance) SetFallbacks

func (self Instance) SetFallbacks(value []Font.Instance) Instance

SetFallbacks is promoted from Font.Instance.SetFallbacks.

func (Instance) SetFixedSize

func (self Instance) SetFixedSize(value int) Instance

SetFixedSize sets the property returned by [GetFixedSize]. Returns the instance, so that property settings can be chained.

func (Instance) SetFixedSizeScaleMode

func (self Instance) SetFixedSizeScaleMode(value TextServer.FixedSizeScaleMode) Instance

SetFixedSizeScaleMode sets the property returned by [GetFixedSizeScaleMode]. Returns the instance, so that property settings can be chained.

func (Instance) SetFontName

func (self Instance) SetFontName(value string) Instance

func (Instance) SetFontStretch

func (self Instance) SetFontStretch(value int) Instance

func (Instance) SetFontStyle

func (self Instance) SetFontStyle(value TextServer.FontStyle) Instance

func (Instance) SetFontWeight

func (self Instance) SetFontWeight(value int) Instance

func (Instance) SetForceAutohinter

func (self Instance) SetForceAutohinter(value bool) Instance

SetForceAutohinter sets the property returned by [IsForceAutohinter]. Returns the instance, so that property settings can be chained.

func (Instance) SetGenerateMipmaps

func (self Instance) SetGenerateMipmaps(value bool) Instance

SetGenerateMipmaps sets the property returned by [GetGenerateMipmaps]. Returns the instance, so that property settings can be chained.

func (Instance) SetGlyphAdvance

func (self Instance) SetGlyphAdvance(cache_index int, size int, glyph int, advance Vector2.XY) Instance

func (Instance) SetGlyphOffset

func (self Instance) SetGlyphOffset(cache_index int, size Vector2i.XY, glyph int, offset Vector2.XY) Instance

func (Instance) SetGlyphSize

func (self Instance) SetGlyphSize(cache_index int, size Vector2i.XY, glyph int, gl_size Vector2.XY) Instance

func (Instance) SetGlyphTextureIdx

func (self Instance) SetGlyphTextureIdx(cache_index int, size Vector2i.XY, glyph int, texture_idx int) Instance

func (Instance) SetGlyphUvRect

func (self Instance) SetGlyphUvRect(cache_index int, size Vector2i.XY, glyph int, uv_rect Rect2.PositionSize) Instance

func (Instance) SetHinting

func (self Instance) SetHinting(value TextServer.Hinting) Instance

SetHinting sets the property returned by [GetHinting]. Returns the instance, so that property settings can be chained.

func (Instance) SetIdForPath

func (self Instance) SetIdForPath(path string, id string) Instance

SetIdForPath is promoted from Resource.Instance.SetIdForPath.

func (Instance) SetKeepRoundingRemainders

func (self Instance) SetKeepRoundingRemainders(value bool) Instance

SetKeepRoundingRemainders sets the property returned by [GetKeepRoundingRemainders]. Returns the instance, so that property settings can be chained.

func (Instance) SetKerning

func (self Instance) SetKerning(cache_index int, size int, glyph_pair Vector2i.XY, kerning Vector2.XY) Instance

func (Instance) SetLanguageSupportOverride

func (self Instance) SetLanguageSupportOverride(language string, supported bool) Instance

func (Instance) SetModulateColorGlyphs

func (self Instance) SetModulateColorGlyphs(value bool) Instance

SetModulateColorGlyphs sets the property returned by [IsModulateColorGlyphs]. Returns the instance, so that property settings can be chained.

func (Instance) SetMsdfPixelRange

func (self Instance) SetMsdfPixelRange(value int) Instance

SetMsdfPixelRange sets the property returned by [GetMsdfPixelRange]. Returns the instance, so that property settings can be chained.

func (Instance) SetMsdfSize

func (self Instance) SetMsdfSize(value int) Instance

SetMsdfSize sets the property returned by [GetMsdfSize]. Returns the instance, so that property settings can be chained.

func (Instance) SetMultichannelSignedDistanceField

func (self Instance) SetMultichannelSignedDistanceField(value bool) Instance

SetMultichannelSignedDistanceField sets the property returned by [IsMultichannelSignedDistanceField]. Returns the instance, so that property settings can be chained.

func (*Instance) SetObject

func (self *Instance) SetObject(obj [1]gdreference.Object) bool

func (Instance) SetOpentypeFeatureOverrides

func (self Instance) SetOpentypeFeatureOverrides(value map[any]any) Instance

SetOpentypeFeatureOverrides sets the property returned by [GetOpentypeFeatureOverrides]. Returns the instance, so that property settings can be chained.

func (Instance) SetOversampling

func (self Instance) SetOversampling(value Float.X) Instance

SetOversampling sets the property returned by [GetOversampling]. Returns the instance, so that property settings can be chained.

func (Instance) SetPathCache

func (self Instance) SetPathCache(path string) Instance

SetPathCache is promoted from Resource.Instance.SetPathCache.

func (Instance) SetResourceLocalToScene

func (self Instance) SetResourceLocalToScene(value bool) Instance

SetResourceLocalToScene is promoted from Resource.Instance.SetResourceLocalToScene.

func (Instance) SetResourceName

func (self Instance) SetResourceName(value string) Instance

SetResourceName is promoted from Resource.Instance.SetResourceName.

func (Instance) SetResourcePath

func (self Instance) SetResourcePath(value string) Instance

SetResourcePath is promoted from Resource.Instance.SetResourcePath.

func (Instance) SetResourceSceneUniqueId

func (self Instance) SetResourceSceneUniqueId(value string) Instance

SetResourceSceneUniqueId is promoted from Resource.Instance.SetResourceSceneUniqueId.

func (Instance) SetScriptSupportOverride

func (self Instance) SetScriptSupportOverride(script string, supported bool) Instance

func (Instance) SetStyleName

func (self Instance) SetStyleName(value string) Instance

func (Instance) SetSubpixelPositioning

func (self Instance) SetSubpixelPositioning(value TextServer.SubpixelPositioning) Instance

SetSubpixelPositioning sets the property returned by [GetSubpixelPositioning]. Returns the instance, so that property settings can be chained.

func (Instance) SetTextureImage

func (self Instance) SetTextureImage(cache_index int, size Vector2i.XY, texture_index int, image Image.Instance) Instance

func (Instance) SetTextureOffsets

func (self Instance) SetTextureOffsets(cache_index int, size Vector2i.XY, texture_index int, offset []int32) Instance

func (Instance) SetTransform

func (self Instance) SetTransform(cache_index int, transform Transform2D.OriginXY) Instance

func (Instance) SetVariationCoordinates

func (self Instance) SetVariationCoordinates(cache_index int, variation_coordinates map[string]float32) Instance

func (Instance) SetupLocalToScene

func (self Instance) SetupLocalToScene()

SetupLocalToScene is promoted from Resource.Instance.SetupLocalToScene.

func (Instance) SubpixelPositioning

func (self Instance) SubpixelPositioning() TextServer.SubpixelPositioning

func (Instance) TakeOverPath

func (self Instance) TakeOverPath(path string)

TakeOverPath is promoted from Resource.Instance.TakeOverPath.

func (Instance) Virtual

func (self Instance) Virtual(name string) reflect.Value

type OpenTypeFeature

type OpenTypeFeature struct {
	Label  string       `gd:"label"`
	Type   reflect.Type `gd:"type"`
	Hidden bool         `gd:"hidden"`
}

type Singleton

type Singleton[T gdclass.Interface] = Extension[T]

Singleton can be embedded in a new struct to create a Go singleton extension of the class.

It will become available as a global inside scripts and any any other Go Extension types will have any *T typed fields filled in to point at this singleton once they have been instantiated.

T must be a type that is embedding this Singleton as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.

Jump to