HTTPRequest

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 24, 2026 License: MIT Imports: 30 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Advanced

type Advanced = class

Advanced exposes a 1:1 low-level instance of the class, undocumented, for those who know what they are doing.

type Any

type Any interface {
	gd.IsClass
	AsHTTPRequest() Instance
}

type Expanded

type Expanded = MoreArgs

type Extension

type Extension[T gdclass.Interface] struct{ gdclass.Extension[T, Instance] }

Extension can be embedded in a new struct to create a Go extension of this class.

T must be a type that is embedding this Extension as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.

func (*Extension[T]) AcceptGzip

func (o *Extension[T]) AcceptGzip() bool

func (*Extension[T]) AsHTTPRequest

func (o *Extension[T]) AsHTTPRequest() Instance

func (*Extension[T]) AsNode

func (o *Extension[T]) AsNode() Node.Instance

func (*Extension[T]) AsObject

func (o *Extension[T]) AsObject() [1]gdreference.Object

func (*Extension[T]) AutoTranslateMode

func (o *Extension[T]) AutoTranslateMode() Node.AutoTranslateMode

func (*Extension[T]) BodySizeLimit

func (o *Extension[T]) BodySizeLimit() int

func (*Extension[T]) CanAutoTranslate

func (o *Extension[T]) CanAutoTranslate() bool

CanAutoTranslate is promoted from Node.Instance.CanAutoTranslate.

func (*Extension[T]) CanProcess

func (o *Extension[T]) CanProcess() bool

CanProcess is promoted from Node.Instance.CanProcess.

func (*Extension[T]) CancelRequest

func (o *Extension[T]) CancelRequest()

func (*Extension[T]) CreateTween

func (o *Extension[T]) CreateTween() Tween.Instance

CreateTween is promoted from Node.Instance.CreateTween.

func (*Extension[T]) DownloadChunkSize

func (o *Extension[T]) DownloadChunkSize() int

func (*Extension[T]) DownloadFile

func (o *Extension[T]) DownloadFile() string

func (*Extension[T]) EditorDescription

func (o *Extension[T]) EditorDescription() string

func (*Extension[T]) FindParent

func (o *Extension[T]) FindParent(pattern string) Node.Instance

FindParent is promoted from Node.Instance.FindParent.

func (*Extension[T]) GetAccessibilityElement

func (o *Extension[T]) GetAccessibilityElement() RID.AccessibilityElement

GetAccessibilityElement is promoted from Node.Instance.GetAccessibilityElement.

func (*Extension[T]) GetBodySize

func (o *Extension[T]) GetBodySize() int

func (*Extension[T]) GetDownloadedBytes

func (o *Extension[T]) GetDownloadedBytes() int

func (*Extension[T]) GetGroups

func (o *Extension[T]) GetGroups() []string

GetGroups is promoted from Node.Instance.GetGroups.

func (*Extension[T]) GetHttpClientStatus

func (o *Extension[T]) GetHttpClientStatus() HTTPClient.Status

func (*Extension[T]) GetMultiplayerAuthority

func (o *Extension[T]) GetMultiplayerAuthority() int

GetMultiplayerAuthority is promoted from Node.Instance.GetMultiplayerAuthority.

func (*Extension[T]) GetNode

func (o *Extension[T]) GetNode(path string) Node.Instance

GetNode is promoted from Node.Instance.GetNode.

func (*Extension[T]) GetNodeOrNull

func (o *Extension[T]) GetNodeOrNull(path string) Node.Instance

GetNodeOrNull is promoted from Node.Instance.GetNodeOrNull.

func (*Extension[T]) GetNodeRpcConfig

func (o *Extension[T]) GetNodeRpcConfig() any

GetNodeRpcConfig is promoted from Node.Instance.GetNodeRpcConfig.

func (*Extension[T]) GetParent

func (o *Extension[T]) GetParent() Node.Instance

GetParent is promoted from Node.Instance.GetParent.

func (*Extension[T]) GetPath

func (o *Extension[T]) GetPath() string

GetPath is promoted from Node.Instance.GetPath.

func (*Extension[T]) GetPhysicsProcessDeltaTime

func (o *Extension[T]) GetPhysicsProcessDeltaTime() Float.X

GetPhysicsProcessDeltaTime is promoted from Node.Instance.GetPhysicsProcessDeltaTime.

func (*Extension[T]) GetProcessDeltaTime

func (o *Extension[T]) GetProcessDeltaTime() Float.X

GetProcessDeltaTime is promoted from Node.Instance.GetProcessDeltaTime.

func (*Extension[T]) GetSceneInstanceLoadPlaceholder

func (o *Extension[T]) GetSceneInstanceLoadPlaceholder() bool

GetSceneInstanceLoadPlaceholder is promoted from Node.Instance.GetSceneInstanceLoadPlaceholder.

func (*Extension[T]) GetTreeString

func (o *Extension[T]) GetTreeString() string

GetTreeString is promoted from Node.Instance.GetTreeString.

func (*Extension[T]) GetTreeStringPretty

func (o *Extension[T]) GetTreeStringPretty() string

GetTreeStringPretty is promoted from Node.Instance.GetTreeStringPretty.

func (*Extension[T]) HasNode

func (o *Extension[T]) HasNode(path string) bool

HasNode is promoted from Node.Instance.HasNode.

func (*Extension[T]) HasNodeAndResource

func (o *Extension[T]) HasNodeAndResource(path string) bool

HasNodeAndResource is promoted from Node.Instance.HasNodeAndResource.

func (*Extension[T]) IsAncestorOf

func (o *Extension[T]) IsAncestorOf(node Node.Instance) bool

IsAncestorOf is promoted from Node.Instance.IsAncestorOf.

func (*Extension[T]) IsDisplayedFolded

func (o *Extension[T]) IsDisplayedFolded() bool

IsDisplayedFolded is promoted from Node.Instance.IsDisplayedFolded.

func (*Extension[T]) IsEditableInstance

func (o *Extension[T]) IsEditableInstance(node Node.Instance) bool

IsEditableInstance is promoted from Node.Instance.IsEditableInstance.

func (*Extension[T]) IsGreaterThan

func (o *Extension[T]) IsGreaterThan(node Node.Instance) bool

IsGreaterThan is promoted from Node.Instance.IsGreaterThan.

func (*Extension[T]) IsInGroup

func (o *Extension[T]) IsInGroup(group string) bool

IsInGroup is promoted from Node.Instance.IsInGroup.

func (*Extension[T]) IsInsideTree

func (o *Extension[T]) IsInsideTree() bool

IsInsideTree is promoted from Node.Instance.IsInsideTree.

func (*Extension[T]) IsMultiplayerAuthority

func (o *Extension[T]) IsMultiplayerAuthority() bool

IsMultiplayerAuthority is promoted from Node.Instance.IsMultiplayerAuthority.

func (*Extension[T]) IsNodeReady

func (o *Extension[T]) IsNodeReady() bool

IsNodeReady is promoted from Node.Instance.IsNodeReady.

func (*Extension[T]) IsPartOfEditedScene

func (o *Extension[T]) IsPartOfEditedScene() bool

IsPartOfEditedScene is promoted from Node.Instance.IsPartOfEditedScene.

func (*Extension[T]) IsPhysicsInterpolated

func (o *Extension[T]) IsPhysicsInterpolated() bool

IsPhysicsInterpolated is promoted from Node.Instance.IsPhysicsInterpolated.

func (*Extension[T]) IsPhysicsInterpolatedAndEnabled

func (o *Extension[T]) IsPhysicsInterpolatedAndEnabled() bool

IsPhysicsInterpolatedAndEnabled is promoted from Node.Instance.IsPhysicsInterpolatedAndEnabled.

func (*Extension[T]) IsPhysicsProcessing

func (o *Extension[T]) IsPhysicsProcessing() bool

IsPhysicsProcessing is promoted from Node.Instance.IsPhysicsProcessing.

func (*Extension[T]) IsPhysicsProcessingInternal

func (o *Extension[T]) IsPhysicsProcessingInternal() bool

IsPhysicsProcessingInternal is promoted from Node.Instance.IsPhysicsProcessingInternal.

func (*Extension[T]) IsProcessing

func (o *Extension[T]) IsProcessing() bool

IsProcessing is promoted from Node.Instance.IsProcessing.

func (*Extension[T]) IsProcessingInput

func (o *Extension[T]) IsProcessingInput() bool

IsProcessingInput is promoted from Node.Instance.IsProcessingInput.

func (*Extension[T]) IsProcessingInternal

func (o *Extension[T]) IsProcessingInternal() bool

IsProcessingInternal is promoted from Node.Instance.IsProcessingInternal.

func (*Extension[T]) IsProcessingShortcutInput

func (o *Extension[T]) IsProcessingShortcutInput() bool

IsProcessingShortcutInput is promoted from Node.Instance.IsProcessingShortcutInput.

func (*Extension[T]) IsProcessingUnhandledInput

func (o *Extension[T]) IsProcessingUnhandledInput() bool

IsProcessingUnhandledInput is promoted from Node.Instance.IsProcessingUnhandledInput.

func (*Extension[T]) IsProcessingUnhandledKeyInput

func (o *Extension[T]) IsProcessingUnhandledKeyInput() bool

IsProcessingUnhandledKeyInput is promoted from Node.Instance.IsProcessingUnhandledKeyInput.

func (*Extension[T]) MaxRedirects

func (o *Extension[T]) MaxRedirects() int

func (*Extension[T]) MoveChild

func (o *Extension[T]) MoveChild(child_node Node.Instance, to_index int)

MoveChild is promoted from Node.Instance.MoveChild.

func (*Extension[T]) Multiplayer

func (o *Extension[T]) Multiplayer() MultiplayerAPI.Instance

func (*Extension[T]) Name

func (o *Extension[T]) Name() string

func (*Extension[T]) NotifyDeferredThreadGroup

func (o *Extension[T]) NotifyDeferredThreadGroup(what int)

NotifyDeferredThreadGroup is promoted from Node.Instance.NotifyDeferredThreadGroup.

func (*Extension[T]) NotifyThreadSafe

func (o *Extension[T]) NotifyThreadSafe(what int)

NotifyThreadSafe is promoted from Node.Instance.NotifyThreadSafe.

func (*Extension[T]) OnChildEnteredTree

func (o *Extension[T]) OnChildEnteredTree(cb func(node Node.Instance), flags ...Signal.Flags) *Extension[T]

OnChildEnteredTree is promoted from Node.Instance.OnChildEnteredTree.

func (*Extension[T]) OnChildExitingTree

func (o *Extension[T]) OnChildExitingTree(cb func(node Node.Instance), flags ...Signal.Flags) *Extension[T]

OnChildExitingTree is promoted from Node.Instance.OnChildExitingTree.

func (*Extension[T]) OnChildOrderChanged

func (o *Extension[T]) OnChildOrderChanged(cb func(), flags ...Signal.Flags) *Extension[T]

OnChildOrderChanged is promoted from Node.Instance.OnChildOrderChanged.

func (*Extension[T]) OnEditorDescriptionChanged

func (o *Extension[T]) OnEditorDescriptionChanged(cb func(node Node.Instance), flags ...Signal.Flags) *Extension[T]

OnEditorDescriptionChanged is promoted from Node.Instance.OnEditorDescriptionChanged.

func (*Extension[T]) OnEditorStateChanged

func (o *Extension[T]) OnEditorStateChanged(cb func(), flags ...Signal.Flags) *Extension[T]

OnEditorStateChanged is promoted from Node.Instance.OnEditorStateChanged.

func (*Extension[T]) OnReady

func (o *Extension[T]) OnReady(cb func(), flags ...Signal.Flags) *Extension[T]

OnReady is promoted from Node.Instance.OnReady.

func (*Extension[T]) OnRenamed

func (o *Extension[T]) OnRenamed(cb func(), flags ...Signal.Flags) *Extension[T]

OnRenamed is promoted from Node.Instance.OnRenamed.

func (*Extension[T]) OnReplacingBy

func (o *Extension[T]) OnReplacingBy(cb func(node Node.Instance), flags ...Signal.Flags) *Extension[T]

OnReplacingBy is promoted from Node.Instance.OnReplacingBy.

func (*Extension[T]) OnRequestCompleted

func (o *Extension[T]) OnRequestCompleted(cb func(result Result, response_code int, headers []string, body []byte), flags ...Signal.Flags) *Extension[T]

func (*Extension[T]) OnTreeEntered

func (o *Extension[T]) OnTreeEntered(cb func(), flags ...Signal.Flags) *Extension[T]

OnTreeEntered is promoted from Node.Instance.OnTreeEntered.

func (*Extension[T]) OnTreeExited

func (o *Extension[T]) OnTreeExited(cb func(), flags ...Signal.Flags) *Extension[T]

OnTreeExited is promoted from Node.Instance.OnTreeExited.

func (*Extension[T]) OnTreeExiting

func (o *Extension[T]) OnTreeExiting(cb func(), flags ...Signal.Flags) *Extension[T]

OnTreeExiting is promoted from Node.Instance.OnTreeExiting.

func (*Extension[T]) Owner

func (o *Extension[T]) Owner() Node.Instance

func (*Extension[T]) PhysicsInterpolationMode

func (o *Extension[T]) PhysicsInterpolationMode() Node.PhysicsInterpolationMode

func (*Extension[T]) PrintTree

func (o *Extension[T]) PrintTree()

PrintTree is promoted from Node.Instance.PrintTree.

func (*Extension[T]) PrintTreePretty

func (o *Extension[T]) PrintTreePretty()

PrintTreePretty is promoted from Node.Instance.PrintTreePretty.

func (*Extension[T]) ProcessMode

func (o *Extension[T]) ProcessMode() Node.ProcessMode

func (*Extension[T]) ProcessPhysicsPriority

func (o *Extension[T]) ProcessPhysicsPriority() int

func (*Extension[T]) ProcessPriority

func (o *Extension[T]) ProcessPriority() int

func (*Extension[T]) ProcessThreadGroup

func (o *Extension[T]) ProcessThreadGroup() Node.ProcessThreadGroup

func (*Extension[T]) ProcessThreadGroupOrder

func (o *Extension[T]) ProcessThreadGroupOrder() int

func (*Extension[T]) ProcessThreadMessages

func (o *Extension[T]) ProcessThreadMessages() Node.ProcessThreadMessages

func (*Extension[T]) PropagateNotification

func (o *Extension[T]) PropagateNotification(what int)

PropagateNotification is promoted from Node.Instance.PropagateNotification.

func (*Extension[T]) QueueAccessibilityUpdate

func (o *Extension[T]) QueueAccessibilityUpdate()

QueueAccessibilityUpdate is promoted from Node.Instance.QueueAccessibilityUpdate.

func (*Extension[T]) QueueFree

func (o *Extension[T]) QueueFree()

QueueFree is promoted from Node.Instance.QueueFree.

func (*Extension[T]) RemoveChild

func (o *Extension[T]) RemoveChild(node Node.Instance)

RemoveChild is promoted from Node.Instance.RemoveChild.

func (*Extension[T]) RemoveFromGroup

func (o *Extension[T]) RemoveFromGroup(group string)

RemoveFromGroup is promoted from Node.Instance.RemoveFromGroup.

func (*Extension[T]) RequestReady

func (o *Extension[T]) RequestReady()

RequestReady is promoted from Node.Instance.RequestReady.

func (*Extension[T]) ResetPhysicsInterpolation

func (o *Extension[T]) ResetPhysicsInterpolation()

ResetPhysicsInterpolation is promoted from Node.Instance.ResetPhysicsInterpolation.

func (*Extension[T]) RpcConfig

func (o *Extension[T]) RpcConfig(method string, config any)

RpcConfig is promoted from Node.Instance.RpcConfig.

func (*Extension[T]) SceneFilePath

func (o *Extension[T]) SceneFilePath() string

func (*Extension[T]) SetAcceptGzip

func (o *Extension[T]) SetAcceptGzip(value bool) *Extension[T]

func (*Extension[T]) SetAutoTranslateMode

func (o *Extension[T]) SetAutoTranslateMode(value Node.AutoTranslateMode) *Extension[T]

func (*Extension[T]) SetBodySizeLimit

func (o *Extension[T]) SetBodySizeLimit(value int) *Extension[T]

func (*Extension[T]) SetDeferredThreadGroup

func (o *Extension[T]) SetDeferredThreadGroup(property string, value any) *Extension[T]

SetDeferredThreadGroup is promoted from Node.Instance.SetDeferredThreadGroup.

func (*Extension[T]) SetDisplayFolded

func (o *Extension[T]) SetDisplayFolded(fold bool) *Extension[T]

SetDisplayFolded is promoted from Node.Instance.SetDisplayFolded.

func (*Extension[T]) SetDownloadChunkSize

func (o *Extension[T]) SetDownloadChunkSize(value int) *Extension[T]

func (*Extension[T]) SetDownloadFile

func (o *Extension[T]) SetDownloadFile(value string) *Extension[T]

func (*Extension[T]) SetEditableInstance

func (o *Extension[T]) SetEditableInstance(node Node.Instance, is_editable bool) *Extension[T]

SetEditableInstance is promoted from Node.Instance.SetEditableInstance.

func (*Extension[T]) SetEditorDescription

func (o *Extension[T]) SetEditorDescription(value string) *Extension[T]

func (*Extension[T]) SetHttpProxy

func (o *Extension[T]) SetHttpProxy(host string, port int) *Extension[T]

func (*Extension[T]) SetHttpsProxy

func (o *Extension[T]) SetHttpsProxy(host string, port int) *Extension[T]

func (*Extension[T]) SetMaxRedirects

func (o *Extension[T]) SetMaxRedirects(value int) *Extension[T]

func (*Extension[T]) SetName

func (o *Extension[T]) SetName(value string) *Extension[T]

func (*Extension[T]) SetOwner

func (o *Extension[T]) SetOwner(value Node.Instance) *Extension[T]

func (*Extension[T]) SetPhysicsInterpolationMode

func (o *Extension[T]) SetPhysicsInterpolationMode(value Node.PhysicsInterpolationMode) *Extension[T]

func (*Extension[T]) SetPhysicsProcess

func (o *Extension[T]) SetPhysicsProcess(enable bool) *Extension[T]

SetPhysicsProcess is promoted from Node.Instance.SetPhysicsProcess.

func (*Extension[T]) SetPhysicsProcessInternal

func (o *Extension[T]) SetPhysicsProcessInternal(enable bool) *Extension[T]

SetPhysicsProcessInternal is promoted from Node.Instance.SetPhysicsProcessInternal.

func (*Extension[T]) SetProcess

func (o *Extension[T]) SetProcess(enable bool) *Extension[T]

SetProcess is promoted from Node.Instance.SetProcess.

func (*Extension[T]) SetProcessInput

func (o *Extension[T]) SetProcessInput(enable bool) *Extension[T]

SetProcessInput is promoted from Node.Instance.SetProcessInput.

func (*Extension[T]) SetProcessInternal

func (o *Extension[T]) SetProcessInternal(enable bool) *Extension[T]

SetProcessInternal is promoted from Node.Instance.SetProcessInternal.

func (*Extension[T]) SetProcessMode

func (o *Extension[T]) SetProcessMode(value Node.ProcessMode) *Extension[T]

func (*Extension[T]) SetProcessPhysicsPriority

func (o *Extension[T]) SetProcessPhysicsPriority(value int) *Extension[T]

func (*Extension[T]) SetProcessPriority

func (o *Extension[T]) SetProcessPriority(value int) *Extension[T]

func (*Extension[T]) SetProcessShortcutInput

func (o *Extension[T]) SetProcessShortcutInput(enable bool) *Extension[T]

SetProcessShortcutInput is promoted from Node.Instance.SetProcessShortcutInput.

func (*Extension[T]) SetProcessThreadGroup

func (o *Extension[T]) SetProcessThreadGroup(value Node.ProcessThreadGroup) *Extension[T]

func (*Extension[T]) SetProcessThreadGroupOrder

func (o *Extension[T]) SetProcessThreadGroupOrder(value int) *Extension[T]

func (*Extension[T]) SetProcessThreadMessages

func (o *Extension[T]) SetProcessThreadMessages(value Node.ProcessThreadMessages) *Extension[T]

func (*Extension[T]) SetProcessUnhandledInput

func (o *Extension[T]) SetProcessUnhandledInput(enable bool) *Extension[T]

SetProcessUnhandledInput is promoted from Node.Instance.SetProcessUnhandledInput.

func (*Extension[T]) SetProcessUnhandledKeyInput

func (o *Extension[T]) SetProcessUnhandledKeyInput(enable bool) *Extension[T]

SetProcessUnhandledKeyInput is promoted from Node.Instance.SetProcessUnhandledKeyInput.

func (*Extension[T]) SetSceneFilePath

func (o *Extension[T]) SetSceneFilePath(value string) *Extension[T]

func (*Extension[T]) SetSceneInstanceLoadPlaceholder

func (o *Extension[T]) SetSceneInstanceLoadPlaceholder(load_placeholder bool) *Extension[T]

SetSceneInstanceLoadPlaceholder is promoted from Node.Instance.SetSceneInstanceLoadPlaceholder.

func (*Extension[T]) SetThreadSafe

func (o *Extension[T]) SetThreadSafe(property string, value any) *Extension[T]

SetThreadSafe is promoted from Node.Instance.SetThreadSafe.

func (*Extension[T]) SetTimeout

func (o *Extension[T]) SetTimeout(value Float.X) *Extension[T]

func (*Extension[T]) SetTlsOptions

func (o *Extension[T]) SetTlsOptions(client_options TLSOptions.Instance) *Extension[T]

func (*Extension[T]) SetTranslationDomainInherited

func (o *Extension[T]) SetTranslationDomainInherited() *Extension[T]

SetTranslationDomainInherited is promoted from Node.Instance.SetTranslationDomainInherited.

func (*Extension[T]) SetUniqueNameInOwner

func (o *Extension[T]) SetUniqueNameInOwner(value bool) *Extension[T]

func (*Extension[T]) SetUseThreads

func (o *Extension[T]) SetUseThreads(value bool) *Extension[T]

func (*Extension[T]) Timeout

func (o *Extension[T]) Timeout() Float.X

func (*Extension[T]) UniqueNameInOwner

func (o *Extension[T]) UniqueNameInOwner() bool

func (*Extension[T]) UpdateConfigurationWarnings

func (o *Extension[T]) UpdateConfigurationWarnings()

UpdateConfigurationWarnings is promoted from Node.Instance.UpdateConfigurationWarnings.

func (*Extension[T]) UseThreads

func (o *Extension[T]) UseThreads() bool

type ID

type ID Object.ID

ID is a typed object ID (reference) to an instance of this class, use it to store references to objects with unknown lifetimes, as an ID will not panic on use if the underlying object has been destroyed.

func (ID) Instance

func (id ID) Instance() (Instance, bool)

type Instance

type Instance [1]gdclass.HTTPRequest

Instance of the class with convieniently typed arguments and results.

var Nil Instance

Nil is a nil/null instance of the class. Equivalent to the zero value.

func New

func New() Instance

func (Instance) AcceptGzip

func (self Instance) AcceptGzip() bool

func (Instance) AsHTTPRequest

func (o Instance) AsHTTPRequest() Instance

func (Instance) AsNode

func (o Instance) AsNode() Node.Instance

func (Instance) AsObject

func (o Instance) AsObject() [1]gdreference.Object

func (Instance) AutoTranslateMode

func (self Instance) AutoTranslateMode() Node.AutoTranslateMode

AutoTranslateMode is promoted from Node.Instance.AutoTranslateMode.

func (Instance) BodySizeLimit

func (self Instance) BodySizeLimit() int

func (Instance) CanAutoTranslate

func (self Instance) CanAutoTranslate() bool

CanAutoTranslate is promoted from Node.Instance.CanAutoTranslate.

func (Instance) CanProcess

func (self Instance) CanProcess() bool

CanProcess is promoted from Node.Instance.CanProcess.

func (Instance) CancelRequest

func (self Instance) CancelRequest()

func (Instance) CreateTween

func (self Instance) CreateTween() Tween.Instance

CreateTween is promoted from Node.Instance.CreateTween.

func (Instance) DownloadChunkSize

func (self Instance) DownloadChunkSize() int

func (Instance) DownloadFile

func (self Instance) DownloadFile() string

func (Instance) EditorDescription

func (self Instance) EditorDescription() string

EditorDescription is promoted from Node.Instance.EditorDescription.

func (Instance) FindParent

func (self Instance) FindParent(pattern string) Node.Instance

FindParent is promoted from Node.Instance.FindParent.

func (Instance) GetAccessibilityElement

func (self Instance) GetAccessibilityElement() RID.AccessibilityElement

GetAccessibilityElement is promoted from Node.Instance.GetAccessibilityElement.

func (Instance) GetBodySize

func (self Instance) GetBodySize() int

func (Instance) GetDownloadedBytes

func (self Instance) GetDownloadedBytes() int

func (Instance) GetGroups

func (self Instance) GetGroups() []string

GetGroups is promoted from Node.Instance.GetGroups.

func (Instance) GetHttpClientStatus

func (self Instance) GetHttpClientStatus() HTTPClient.Status

func (Instance) GetMultiplayerAuthority

func (self Instance) GetMultiplayerAuthority() int

GetMultiplayerAuthority is promoted from Node.Instance.GetMultiplayerAuthority.

func (Instance) GetNode

func (self Instance) GetNode(path string) Node.Instance

GetNode is promoted from Node.Instance.GetNode.

func (Instance) GetNodeOrNull

func (self Instance) GetNodeOrNull(path string) Node.Instance

GetNodeOrNull is promoted from Node.Instance.GetNodeOrNull.

func (Instance) GetNodeRpcConfig

func (self Instance) GetNodeRpcConfig() any

GetNodeRpcConfig is promoted from Node.Instance.GetNodeRpcConfig.

func (Instance) GetParent

func (self Instance) GetParent() Node.Instance

GetParent is promoted from Node.Instance.GetParent.

func (Instance) GetPath

func (self Instance) GetPath() string

GetPath is promoted from Node.Instance.GetPath.

func (Instance) GetPhysicsProcessDeltaTime

func (self Instance) GetPhysicsProcessDeltaTime() Float.X

GetPhysicsProcessDeltaTime is promoted from Node.Instance.GetPhysicsProcessDeltaTime.

func (Instance) GetProcessDeltaTime

func (self Instance) GetProcessDeltaTime() Float.X

GetProcessDeltaTime is promoted from Node.Instance.GetProcessDeltaTime.

func (Instance) GetSceneInstanceLoadPlaceholder

func (self Instance) GetSceneInstanceLoadPlaceholder() bool

GetSceneInstanceLoadPlaceholder is promoted from Node.Instance.GetSceneInstanceLoadPlaceholder.

func (Instance) GetTreeString

func (self Instance) GetTreeString() string

GetTreeString is promoted from Node.Instance.GetTreeString.

func (Instance) GetTreeStringPretty

func (self Instance) GetTreeStringPretty() string

GetTreeStringPretty is promoted from Node.Instance.GetTreeStringPretty.

func (Instance) HasNode

func (self Instance) HasNode(path string) bool

HasNode is promoted from Node.Instance.HasNode.

func (Instance) HasNodeAndResource

func (self Instance) HasNodeAndResource(path string) bool

HasNodeAndResource is promoted from Node.Instance.HasNodeAndResource.

func (Instance) ID

func (self Instance) ID() ID

func (Instance) IsAncestorOf

func (self Instance) IsAncestorOf(node Node.Instance) bool

IsAncestorOf is promoted from Node.Instance.IsAncestorOf.

func (Instance) IsDisplayedFolded

func (self Instance) IsDisplayedFolded() bool

IsDisplayedFolded is promoted from Node.Instance.IsDisplayedFolded.

func (Instance) IsEditableInstance

func (self Instance) IsEditableInstance(node Node.Instance) bool

IsEditableInstance is promoted from Node.Instance.IsEditableInstance.

func (Instance) IsGreaterThan

func (self Instance) IsGreaterThan(node Node.Instance) bool

IsGreaterThan is promoted from Node.Instance.IsGreaterThan.

func (Instance) IsInGroup

func (self Instance) IsInGroup(group string) bool

IsInGroup is promoted from Node.Instance.IsInGroup.

func (Instance) IsInsideTree

func (self Instance) IsInsideTree() bool

IsInsideTree is promoted from Node.Instance.IsInsideTree.

func (Instance) IsMultiplayerAuthority

func (self Instance) IsMultiplayerAuthority() bool

IsMultiplayerAuthority is promoted from Node.Instance.IsMultiplayerAuthority.

func (Instance) IsNodeReady

func (self Instance) IsNodeReady() bool

IsNodeReady is promoted from Node.Instance.IsNodeReady.

func (Instance) IsPartOfEditedScene

func (self Instance) IsPartOfEditedScene() bool

IsPartOfEditedScene is promoted from Node.Instance.IsPartOfEditedScene.

func (Instance) IsPhysicsInterpolated

func (self Instance) IsPhysicsInterpolated() bool

IsPhysicsInterpolated is promoted from Node.Instance.IsPhysicsInterpolated.

func (Instance) IsPhysicsInterpolatedAndEnabled

func (self Instance) IsPhysicsInterpolatedAndEnabled() bool

IsPhysicsInterpolatedAndEnabled is promoted from Node.Instance.IsPhysicsInterpolatedAndEnabled.

func (Instance) IsPhysicsProcessing

func (self Instance) IsPhysicsProcessing() bool

IsPhysicsProcessing is promoted from Node.Instance.IsPhysicsProcessing.

func (Instance) IsPhysicsProcessingInternal

func (self Instance) IsPhysicsProcessingInternal() bool

IsPhysicsProcessingInternal is promoted from Node.Instance.IsPhysicsProcessingInternal.

func (Instance) IsProcessing

func (self Instance) IsProcessing() bool

IsProcessing is promoted from Node.Instance.IsProcessing.

func (Instance) IsProcessingInput

func (self Instance) IsProcessingInput() bool

IsProcessingInput is promoted from Node.Instance.IsProcessingInput.

func (Instance) IsProcessingInternal

func (self Instance) IsProcessingInternal() bool

IsProcessingInternal is promoted from Node.Instance.IsProcessingInternal.

func (Instance) IsProcessingShortcutInput

func (self Instance) IsProcessingShortcutInput() bool

IsProcessingShortcutInput is promoted from Node.Instance.IsProcessingShortcutInput.

func (Instance) IsProcessingUnhandledInput

func (self Instance) IsProcessingUnhandledInput() bool

IsProcessingUnhandledInput is promoted from Node.Instance.IsProcessingUnhandledInput.

func (Instance) IsProcessingUnhandledKeyInput

func (self Instance) IsProcessingUnhandledKeyInput() bool

IsProcessingUnhandledKeyInput is promoted from Node.Instance.IsProcessingUnhandledKeyInput.

func (Instance) MaxRedirects

func (self Instance) MaxRedirects() int

func (Instance) MoreArgs

func (self Instance) MoreArgs() MoreArgs

MoreArgs enables certain functions to be called with additional 'optional' arguments.

func (Instance) MoveChild

func (self Instance) MoveChild(child_node Node.Instance, to_index int)

MoveChild is promoted from Node.Instance.MoveChild.

func (Instance) Multiplayer

func (self Instance) Multiplayer() MultiplayerAPI.Instance

Multiplayer is promoted from Node.Instance.Multiplayer.

func (Instance) Name

func (self Instance) Name() string

Name is promoted from Node.Instance.Name.

func (Instance) NotifyDeferredThreadGroup

func (self Instance) NotifyDeferredThreadGroup(what int)

NotifyDeferredThreadGroup is promoted from Node.Instance.NotifyDeferredThreadGroup.

func (Instance) NotifyThreadSafe

func (self Instance) NotifyThreadSafe(what int)

NotifyThreadSafe is promoted from Node.Instance.NotifyThreadSafe.

func (Instance) OnChildEnteredTree

func (self Instance) OnChildEnteredTree(cb func(node Node.Instance), flags ...Signal.Flags) Instance

OnChildEnteredTree is promoted from Node.Instance.OnChildEnteredTree.

func (Instance) OnChildExitingTree

func (self Instance) OnChildExitingTree(cb func(node Node.Instance), flags ...Signal.Flags) Instance

OnChildExitingTree is promoted from Node.Instance.OnChildExitingTree.

func (Instance) OnChildOrderChanged

func (self Instance) OnChildOrderChanged(cb func(), flags ...Signal.Flags) Instance

OnChildOrderChanged is promoted from Node.Instance.OnChildOrderChanged.

func (Instance) OnEditorDescriptionChanged

func (self Instance) OnEditorDescriptionChanged(cb func(node Node.Instance), flags ...Signal.Flags) Instance

OnEditorDescriptionChanged is promoted from Node.Instance.OnEditorDescriptionChanged.

func (Instance) OnEditorStateChanged

func (self Instance) OnEditorStateChanged(cb func(), flags ...Signal.Flags) Instance

OnEditorStateChanged is promoted from Node.Instance.OnEditorStateChanged.

func (Instance) OnReady

func (self Instance) OnReady(cb func(), flags ...Signal.Flags) Instance

OnReady is promoted from Node.Instance.OnReady.

func (Instance) OnRenamed

func (self Instance) OnRenamed(cb func(), flags ...Signal.Flags) Instance

OnRenamed is promoted from Node.Instance.OnRenamed.

func (Instance) OnReplacingBy

func (self Instance) OnReplacingBy(cb func(node Node.Instance), flags ...Signal.Flags) Instance

OnReplacingBy is promoted from Node.Instance.OnReplacingBy.

func (Instance) OnRequestCompleted

func (self Instance) OnRequestCompleted(cb func(result Result, response_code int, headers []string, body []byte), flags ...Signal.Flags) Instance

func (Instance) OnTreeEntered

func (self Instance) OnTreeEntered(cb func(), flags ...Signal.Flags) Instance

OnTreeEntered is promoted from Node.Instance.OnTreeEntered.

func (Instance) OnTreeExited

func (self Instance) OnTreeExited(cb func(), flags ...Signal.Flags) Instance

OnTreeExited is promoted from Node.Instance.OnTreeExited.

func (Instance) OnTreeExiting

func (self Instance) OnTreeExiting(cb func(), flags ...Signal.Flags) Instance

OnTreeExiting is promoted from Node.Instance.OnTreeExiting.

func (Instance) Owner

func (self Instance) Owner() Node.Instance

Owner is promoted from Node.Instance.Owner.

func (Instance) PhysicsInterpolationMode

func (self Instance) PhysicsInterpolationMode() Node.PhysicsInterpolationMode

PhysicsInterpolationMode is promoted from Node.Instance.PhysicsInterpolationMode.

func (Instance) PrintTree

func (self Instance) PrintTree()

PrintTree is promoted from Node.Instance.PrintTree.

func (Instance) PrintTreePretty

func (self Instance) PrintTreePretty()

PrintTreePretty is promoted from Node.Instance.PrintTreePretty.

func (Instance) ProcessMode

func (self Instance) ProcessMode() Node.ProcessMode

ProcessMode is promoted from Node.Instance.ProcessMode.

func (Instance) ProcessPhysicsPriority

func (self Instance) ProcessPhysicsPriority() int

ProcessPhysicsPriority is promoted from Node.Instance.ProcessPhysicsPriority.

func (Instance) ProcessPriority

func (self Instance) ProcessPriority() int

ProcessPriority is promoted from Node.Instance.ProcessPriority.

func (Instance) ProcessThreadGroup

func (self Instance) ProcessThreadGroup() Node.ProcessThreadGroup

ProcessThreadGroup is promoted from Node.Instance.ProcessThreadGroup.

func (Instance) ProcessThreadGroupOrder

func (self Instance) ProcessThreadGroupOrder() int

ProcessThreadGroupOrder is promoted from Node.Instance.ProcessThreadGroupOrder.

func (Instance) ProcessThreadMessages

func (self Instance) ProcessThreadMessages() Node.ProcessThreadMessages

ProcessThreadMessages is promoted from Node.Instance.ProcessThreadMessages.

func (Instance) PropagateNotification

func (self Instance) PropagateNotification(what int)

PropagateNotification is promoted from Node.Instance.PropagateNotification.

func (Instance) QueueAccessibilityUpdate

func (self Instance) QueueAccessibilityUpdate()

QueueAccessibilityUpdate is promoted from Node.Instance.QueueAccessibilityUpdate.

func (Instance) QueueFree

func (self Instance) QueueFree()

QueueFree is promoted from Node.Instance.QueueFree.

func (Instance) RemoveChild

func (self Instance) RemoveChild(node Node.Instance)

RemoveChild is promoted from Node.Instance.RemoveChild.

func (Instance) RemoveFromGroup

func (self Instance) RemoveFromGroup(group string)

RemoveFromGroup is promoted from Node.Instance.RemoveFromGroup.

func (Instance) Request

func (self Instance) Request(url string) error

func (Instance) RequestRaw

func (self Instance) RequestRaw(url string) error

func (Instance) RequestReady

func (self Instance) RequestReady()

RequestReady is promoted from Node.Instance.RequestReady.

func (Instance) ResetPhysicsInterpolation

func (self Instance) ResetPhysicsInterpolation()

ResetPhysicsInterpolation is promoted from Node.Instance.ResetPhysicsInterpolation.

func (Instance) RpcConfig

func (self Instance) RpcConfig(method string, config any)

RpcConfig is promoted from Node.Instance.RpcConfig.

func (Instance) SceneFilePath

func (self Instance) SceneFilePath() string

SceneFilePath is promoted from Node.Instance.SceneFilePath.

func (Instance) SetAcceptGzip

func (self Instance) SetAcceptGzip(value bool) Instance

SetAcceptGzip sets the property returned by [IsAcceptingGzip]. Returns the instance, so that property settings can be chained.

func (Instance) SetAutoTranslateMode

func (self Instance) SetAutoTranslateMode(value Node.AutoTranslateMode) Instance

SetAutoTranslateMode is promoted from Node.Instance.SetAutoTranslateMode.

func (Instance) SetBodySizeLimit

func (self Instance) SetBodySizeLimit(value int) Instance

SetBodySizeLimit sets the property returned by [GetBodySizeLimit]. Returns the instance, so that property settings can be chained.

func (Instance) SetDeferredThreadGroup

func (self Instance) SetDeferredThreadGroup(property string, value any) Instance

SetDeferredThreadGroup is promoted from Node.Instance.SetDeferredThreadGroup.

func (Instance) SetDisplayFolded

func (self Instance) SetDisplayFolded(fold bool) Instance

SetDisplayFolded is promoted from Node.Instance.SetDisplayFolded.

func (Instance) SetDownloadChunkSize

func (self Instance) SetDownloadChunkSize(value int) Instance

SetDownloadChunkSize sets the property returned by [GetDownloadChunkSize]. Returns the instance, so that property settings can be chained.

func (Instance) SetDownloadFile

func (self Instance) SetDownloadFile(value string) Instance

SetDownloadFile sets the property returned by [GetDownloadFile]. Returns the instance, so that property settings can be chained.

func (Instance) SetEditableInstance

func (self Instance) SetEditableInstance(node Node.Instance, is_editable bool) Instance

SetEditableInstance is promoted from Node.Instance.SetEditableInstance.

func (Instance) SetEditorDescription

func (self Instance) SetEditorDescription(value string) Instance

SetEditorDescription is promoted from Node.Instance.SetEditorDescription.

func (Instance) SetHttpProxy

func (self Instance) SetHttpProxy(host string, port int) Instance

func (Instance) SetHttpsProxy

func (self Instance) SetHttpsProxy(host string, port int) Instance

func (Instance) SetMaxRedirects

func (self Instance) SetMaxRedirects(value int) Instance

SetMaxRedirects sets the property returned by [GetMaxRedirects]. Returns the instance, so that property settings can be chained.

func (Instance) SetName

func (self Instance) SetName(value string) Instance

SetName is promoted from Node.Instance.SetName.

func (*Instance) SetObject

func (self *Instance) SetObject(obj [1]gdreference.Object) bool

func (Instance) SetOwner

func (self Instance) SetOwner(value Node.Instance) Instance

SetOwner is promoted from Node.Instance.SetOwner.

func (Instance) SetPhysicsInterpolationMode

func (self Instance) SetPhysicsInterpolationMode(value Node.PhysicsInterpolationMode) Instance

SetPhysicsInterpolationMode is promoted from Node.Instance.SetPhysicsInterpolationMode.

func (Instance) SetPhysicsProcess

func (self Instance) SetPhysicsProcess(enable bool) Instance

SetPhysicsProcess is promoted from Node.Instance.SetPhysicsProcess.

func (Instance) SetPhysicsProcessInternal

func (self Instance) SetPhysicsProcessInternal(enable bool) Instance

SetPhysicsProcessInternal is promoted from Node.Instance.SetPhysicsProcessInternal.

func (Instance) SetProcess

func (self Instance) SetProcess(enable bool) Instance

SetProcess is promoted from Node.Instance.SetProcess.

func (Instance) SetProcessInput

func (self Instance) SetProcessInput(enable bool) Instance

SetProcessInput is promoted from Node.Instance.SetProcessInput.

func (Instance) SetProcessInternal

func (self Instance) SetProcessInternal(enable bool) Instance

SetProcessInternal is promoted from Node.Instance.SetProcessInternal.

func (Instance) SetProcessMode

func (self Instance) SetProcessMode(value Node.ProcessMode) Instance

SetProcessMode is promoted from Node.Instance.SetProcessMode.

func (Instance) SetProcessPhysicsPriority

func (self Instance) SetProcessPhysicsPriority(value int) Instance

SetProcessPhysicsPriority is promoted from Node.Instance.SetProcessPhysicsPriority.

func (Instance) SetProcessPriority

func (self Instance) SetProcessPriority(value int) Instance

SetProcessPriority is promoted from Node.Instance.SetProcessPriority.

func (Instance) SetProcessShortcutInput

func (self Instance) SetProcessShortcutInput(enable bool) Instance

SetProcessShortcutInput is promoted from Node.Instance.SetProcessShortcutInput.

func (Instance) SetProcessThreadGroup

func (self Instance) SetProcessThreadGroup(value Node.ProcessThreadGroup) Instance

SetProcessThreadGroup is promoted from Node.Instance.SetProcessThreadGroup.

func (Instance) SetProcessThreadGroupOrder

func (self Instance) SetProcessThreadGroupOrder(value int) Instance

SetProcessThreadGroupOrder is promoted from Node.Instance.SetProcessThreadGroupOrder.

func (Instance) SetProcessThreadMessages

func (self Instance) SetProcessThreadMessages(value Node.ProcessThreadMessages) Instance

SetProcessThreadMessages is promoted from Node.Instance.SetProcessThreadMessages.

func (Instance) SetProcessUnhandledInput

func (self Instance) SetProcessUnhandledInput(enable bool) Instance

SetProcessUnhandledInput is promoted from Node.Instance.SetProcessUnhandledInput.

func (Instance) SetProcessUnhandledKeyInput

func (self Instance) SetProcessUnhandledKeyInput(enable bool) Instance

SetProcessUnhandledKeyInput is promoted from Node.Instance.SetProcessUnhandledKeyInput.

func (Instance) SetSceneFilePath

func (self Instance) SetSceneFilePath(value string) Instance

SetSceneFilePath is promoted from Node.Instance.SetSceneFilePath.

func (Instance) SetSceneInstanceLoadPlaceholder

func (self Instance) SetSceneInstanceLoadPlaceholder(load_placeholder bool) Instance

SetSceneInstanceLoadPlaceholder is promoted from Node.Instance.SetSceneInstanceLoadPlaceholder.

func (Instance) SetThreadSafe

func (self Instance) SetThreadSafe(property string, value any) Instance

SetThreadSafe is promoted from Node.Instance.SetThreadSafe.

func (Instance) SetTimeout

func (self Instance) SetTimeout(value Float.X) Instance

SetTimeout sets the property returned by [GetTimeout]. Returns the instance, so that property settings can be chained.

func (Instance) SetTlsOptions

func (self Instance) SetTlsOptions(client_options TLSOptions.Instance) Instance

func (Instance) SetTranslationDomainInherited

func (self Instance) SetTranslationDomainInherited() Instance

SetTranslationDomainInherited is promoted from Node.Instance.SetTranslationDomainInherited.

func (Instance) SetUniqueNameInOwner

func (self Instance) SetUniqueNameInOwner(value bool) Instance

SetUniqueNameInOwner is promoted from Node.Instance.SetUniqueNameInOwner.

func (Instance) SetUseThreads

func (self Instance) SetUseThreads(value bool) Instance

SetUseThreads sets the property returned by [IsUsingThreads]. Returns the instance, so that property settings can be chained.

func (Instance) Timeout

func (self Instance) Timeout() Float.X

func (Instance) UniqueNameInOwner

func (self Instance) UniqueNameInOwner() bool

UniqueNameInOwner is promoted from Node.Instance.UniqueNameInOwner.

func (Instance) UpdateConfigurationWarnings

func (self Instance) UpdateConfigurationWarnings()

UpdateConfigurationWarnings is promoted from Node.Instance.UpdateConfigurationWarnings.

func (Instance) UseThreads

func (self Instance) UseThreads() bool

func (Instance) Virtual

func (self Instance) Virtual(name string) reflect.Value

type MoreArgs

type MoreArgs [1]gdclass.HTTPRequest

MoreArgs is a container for Instance functions with additional 'optional' arguments.

func (MoreArgs) Request

func (self MoreArgs) Request(url string, custom_headers []string, method HTTPClient.Method, request_data string) error

func (MoreArgs) RequestRaw

func (self MoreArgs) RequestRaw(url string, custom_headers []string, method HTTPClient.Method, request_data_raw []byte) error

type Result

type Result int64 //gd:HTTPRequest.Result
const (
	ResultSuccess                 Result = 0
	ResultChunkedBodySizeMismatch Result = 1
	ResultCantConnect             Result = 2
	ResultCantResolve             Result = 3
	ResultConnectionError         Result = 4
	ResultTlsHandshakeError       Result = 5
	ResultNoResponse              Result = 6
	ResultBodySizeLimitExceeded   Result = 7
	ResultBodyDecompressFailed    Result = 8
	ResultRequestFailed           Result = 9
	ResultDownloadFileCantOpen    Result = 10
	ResultDownloadFileWriteError  Result = 11
	ResultRedirectLimitReached    Result = 12
	ResultTimeout                 Result = 13
)

type Singleton

type Singleton[T gdclass.Interface] = Extension[T]

Singleton can be embedded in a new struct to create a Go singleton extension of the class.

It will become available as a global inside scripts and any any other Go Extension types will have any *T typed fields filled in to point at this singleton once they have been instantiated.

T must be a type that is embedding this Singleton as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.

Jump to