JSON

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 24, 2026 License: MIT Imports: 26 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func FromNative

func FromNative(v any, full_objects bool) any

func ParseString

func ParseString(json_string string) any

func Stringify

func Stringify(data any, indent string, full_precision bool) string

func StringifyOptions

func StringifyOptions(data any, indent string, sort_keys bool, full_precision bool) string

func ToNative

func ToNative(json any, allow_objects bool) any

Types

type Advanced

type Advanced = class

Advanced exposes a 1:1 low-level instance of the class, undocumented, for those who know what they are doing.

type Any

type Any interface {
	gd.IsClass
	AsJSON() Instance
}

type Expanded

type Expanded = MoreArgs

type Extension

type Extension[T gdclass.Interface] struct{ gdclass.Extension[T, Instance] }

Extension can be embedded in a new struct to create a Go extension of this class.

T must be a type that is embedding this Extension as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.

func (*Extension[T]) AsJSON

func (o *Extension[T]) AsJSON() Instance

func (*Extension[T]) AsObject

func (o *Extension[T]) AsObject() [1]gdreference.Object

func (*Extension[T]) AsRefCounted

func (o *Extension[T]) AsRefCounted() ie.RC

func (*Extension[T]) AsResource

func (o *Extension[T]) AsResource() Resource.Instance

func (*Extension[T]) Data

func (o *Extension[T]) Data() any

func (*Extension[T]) EmitChanged

func (o *Extension[T]) EmitChanged()

EmitChanged is promoted from Resource.Instance.EmitChanged.

func (*Extension[T]) GetErrorLine

func (o *Extension[T]) GetErrorLine() int

func (*Extension[T]) GetErrorMessage

func (o *Extension[T]) GetErrorMessage() string

func (*Extension[T]) GetIdForPath

func (o *Extension[T]) GetIdForPath(path string) string

GetIdForPath is promoted from Resource.Instance.GetIdForPath.

func (*Extension[T]) GetParsedText

func (o *Extension[T]) GetParsedText() string

func (*Extension[T]) GetRid

func (o *Extension[T]) GetRid() Resource.ID

GetRid is promoted from Resource.Instance.GetRid.

func (*Extension[T]) IsBuiltIn

func (o *Extension[T]) IsBuiltIn() bool

IsBuiltIn is promoted from Resource.Instance.IsBuiltIn.

func (*Extension[T]) OnChanged

func (o *Extension[T]) OnChanged(cb func(), flags ...Signal.Flags) *Extension[T]

OnChanged is promoted from Resource.Instance.OnChanged.

func (*Extension[T]) OnSetupLocalToSceneRequested

func (o *Extension[T]) OnSetupLocalToSceneRequested(cb func(), flags ...Signal.Flags) *Extension[T]

OnSetupLocalToSceneRequested is promoted from Resource.Instance.OnSetupLocalToSceneRequested.

func (*Extension[T]) ResetState

func (o *Extension[T]) ResetState()

ResetState is promoted from Resource.Instance.ResetState.

func (*Extension[T]) ResourceLocalToScene

func (o *Extension[T]) ResourceLocalToScene() bool

func (*Extension[T]) ResourceName

func (o *Extension[T]) ResourceName() string

func (*Extension[T]) ResourcePath

func (o *Extension[T]) ResourcePath() string

func (*Extension[T]) ResourceSceneUniqueId

func (o *Extension[T]) ResourceSceneUniqueId() string

func (*Extension[T]) SetData

func (o *Extension[T]) SetData(value any) *Extension[T]

func (*Extension[T]) SetIdForPath

func (o *Extension[T]) SetIdForPath(path string, id string) *Extension[T]

SetIdForPath is promoted from Resource.Instance.SetIdForPath.

func (*Extension[T]) SetPathCache

func (o *Extension[T]) SetPathCache(path string) *Extension[T]

SetPathCache is promoted from Resource.Instance.SetPathCache.

func (*Extension[T]) SetResourceLocalToScene

func (o *Extension[T]) SetResourceLocalToScene(value bool) *Extension[T]

func (*Extension[T]) SetResourceName

func (o *Extension[T]) SetResourceName(value string) *Extension[T]

func (*Extension[T]) SetResourcePath

func (o *Extension[T]) SetResourcePath(value string) *Extension[T]

func (*Extension[T]) SetResourceSceneUniqueId

func (o *Extension[T]) SetResourceSceneUniqueId(value string) *Extension[T]

func (*Extension[T]) SetupLocalToScene

func (o *Extension[T]) SetupLocalToScene()

SetupLocalToScene is promoted from Resource.Instance.SetupLocalToScene.

func (*Extension[T]) TakeOverPath

func (o *Extension[T]) TakeOverPath(path string)

TakeOverPath is promoted from Resource.Instance.TakeOverPath.

type ID

type ID Object.ID

ID is a typed object ID (reference) to an instance of this class, use it to store references to objects with unknown lifetimes, as an ID will not panic on use if the underlying object has been destroyed.

func (ID) Instance

func (id ID) Instance() (Instance, bool)

type Instance

type Instance [1]gdclass.JSON

Instance of the class with convieniently typed arguments and results.

var Nil Instance

Nil is a nil/null instance of the class. Equivalent to the zero value.

func New

func New() Instance

func (Instance) AsJSON

func (o Instance) AsJSON() Instance

func (Instance) AsObject

func (o Instance) AsObject() [1]gdreference.Object

func (Instance) AsRefCounted

func (o Instance) AsRefCounted() ie.RC

func (Instance) AsResource

func (o Instance) AsResource() Resource.Instance

func (Instance) Data

func (self Instance) Data() any

func (Instance) EmitChanged

func (self Instance) EmitChanged()

EmitChanged is promoted from Resource.Instance.EmitChanged.

func (Instance) GetErrorLine

func (self Instance) GetErrorLine() int

func (Instance) GetErrorMessage

func (self Instance) GetErrorMessage() string

func (Instance) GetIdForPath

func (self Instance) GetIdForPath(path string) string

GetIdForPath is promoted from Resource.Instance.GetIdForPath.

func (Instance) GetParsedText

func (self Instance) GetParsedText() string

func (Instance) GetRid

func (self Instance) GetRid() Resource.ID

GetRid is promoted from Resource.Instance.GetRid.

func (Instance) ID

func (self Instance) ID() ID

func (Instance) IsBuiltIn

func (self Instance) IsBuiltIn() bool

IsBuiltIn is promoted from Resource.Instance.IsBuiltIn.

func (Instance) MoreArgs

func (self Instance) MoreArgs() MoreArgs

MoreArgs enables certain functions to be called with additional 'optional' arguments.

func (Instance) OnChanged

func (self Instance) OnChanged(cb func(), flags ...Signal.Flags) Instance

OnChanged is promoted from Resource.Instance.OnChanged.

func (Instance) OnSetupLocalToSceneRequested

func (self Instance) OnSetupLocalToSceneRequested(cb func(), flags ...Signal.Flags) Instance

OnSetupLocalToSceneRequested is promoted from Resource.Instance.OnSetupLocalToSceneRequested.

func (Instance) Parse

func (self Instance) Parse(json_text string) error

func (Instance) ResetState

func (self Instance) ResetState()

ResetState is promoted from Resource.Instance.ResetState.

func (Instance) ResourceLocalToScene

func (self Instance) ResourceLocalToScene() bool

ResourceLocalToScene is promoted from Resource.Instance.ResourceLocalToScene.

func (Instance) ResourceName

func (self Instance) ResourceName() string

ResourceName is promoted from Resource.Instance.ResourceName.

func (Instance) ResourcePath

func (self Instance) ResourcePath() string

ResourcePath is promoted from Resource.Instance.ResourcePath.

func (Instance) ResourceSceneUniqueId

func (self Instance) ResourceSceneUniqueId() string

ResourceSceneUniqueId is promoted from Resource.Instance.ResourceSceneUniqueId.

func (Instance) SetData

func (self Instance) SetData(value any) Instance

SetData sets the property returned by [GetData]. Returns the instance, so that property settings can be chained.

func (Instance) SetIdForPath

func (self Instance) SetIdForPath(path string, id string) Instance

SetIdForPath is promoted from Resource.Instance.SetIdForPath.

func (*Instance) SetObject

func (self *Instance) SetObject(obj [1]gdreference.Object) bool

func (Instance) SetPathCache

func (self Instance) SetPathCache(path string) Instance

SetPathCache is promoted from Resource.Instance.SetPathCache.

func (Instance) SetResourceLocalToScene

func (self Instance) SetResourceLocalToScene(value bool) Instance

SetResourceLocalToScene is promoted from Resource.Instance.SetResourceLocalToScene.

func (Instance) SetResourceName

func (self Instance) SetResourceName(value string) Instance

SetResourceName is promoted from Resource.Instance.SetResourceName.

func (Instance) SetResourcePath

func (self Instance) SetResourcePath(value string) Instance

SetResourcePath is promoted from Resource.Instance.SetResourcePath.

func (Instance) SetResourceSceneUniqueId

func (self Instance) SetResourceSceneUniqueId(value string) Instance

SetResourceSceneUniqueId is promoted from Resource.Instance.SetResourceSceneUniqueId.

func (Instance) SetupLocalToScene

func (self Instance) SetupLocalToScene()

SetupLocalToScene is promoted from Resource.Instance.SetupLocalToScene.

func (Instance) TakeOverPath

func (self Instance) TakeOverPath(path string)

TakeOverPath is promoted from Resource.Instance.TakeOverPath.

func (Instance) Virtual

func (self Instance) Virtual(name string) reflect.Value

type MoreArgs

type MoreArgs [1]gdclass.JSON

MoreArgs is a container for Instance functions with additional 'optional' arguments.

func (MoreArgs) Parse

func (self MoreArgs) Parse(json_text string, keep_text bool) error

type Singleton

type Singleton[T gdclass.Interface] = Extension[T]

Singleton can be embedded in a new struct to create a Go singleton extension of the class.

It will become available as a global inside scripts and any any other Go Extension types will have any *T typed fields filled in to point at this singleton once they have been instantiated.

T must be a type that is embedding this Singleton as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.

Jump to