Documentation
¶
Index ¶
- type Advanced
- type Any
- type Extension
- func (o *Extension[T]) AsJavaClass() Instance
- func (o *Extension[T]) AsObject() [1]gdreference.Object
- func (o *Extension[T]) AsRefCounted() ie.RC
- func (o *Extension[T]) GetJavaClassName() string
- func (o *Extension[T]) GetJavaMethodList() []Object.PropertyInfo
- func (o *Extension[T]) GetJavaParentClass() Instance
- func (o *Extension[T]) HasJavaMethod(method string) bool
- type ID
- type Instance
- func (o Instance) AsJavaClass() Instance
- func (o Instance) AsObject() [1]gdreference.Object
- func (o Instance) AsRefCounted() ie.RC
- func (self Instance) GetJavaClassName() string
- func (self Instance) GetJavaMethodList() []Object.PropertyInfo
- func (self Instance) GetJavaParentClass() Instance
- func (self Instance) HasJavaMethod(method string) bool
- func (self Instance) ID() ID
- func (self *Instance) SetObject(obj [1]gdreference.Object) bool
- func (self Instance) Virtual(name string) reflect.Value
- type Singleton
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Advanced ¶
type Advanced = class
Advanced exposes a 1:1 low-level instance of the class, undocumented, for those who know what they are doing.
type Extension ¶
Extension can be embedded in a new struct to create a Go extension of this class.
T must be a type that is embedding this Extension as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.
func (*Extension[T]) AsJavaClass ¶
func (*Extension[T]) AsObject ¶
func (o *Extension[T]) AsObject() [1]gdreference.Object
func (*Extension[T]) AsRefCounted ¶
func (*Extension[T]) GetJavaClassName ¶
func (*Extension[T]) GetJavaMethodList ¶
func (o *Extension[T]) GetJavaMethodList() []Object.PropertyInfo
func (*Extension[T]) GetJavaParentClass ¶
func (*Extension[T]) HasJavaMethod ¶
type ID ¶
ID is a typed object ID (reference) to an instance of this class, use it to store references to objects with unknown lifetimes, as an ID will not panic on use if the underlying object has been destroyed.
type Instance ¶
Instance of the class with convieniently typed arguments and results.
var Nil Instance
Nil is a nil/null instance of the class. Equivalent to the zero value.
func (Instance) AsJavaClass ¶
func (Instance) AsObject ¶
func (o Instance) AsObject() [1]gdreference.Object
func (Instance) AsRefCounted ¶
func (Instance) GetJavaClassName ¶
func (Instance) GetJavaMethodList ¶
func (self Instance) GetJavaMethodList() []Object.PropertyInfo
func (Instance) GetJavaParentClass ¶
func (Instance) HasJavaMethod ¶
type Singleton ¶
Singleton can be embedded in a new struct to create a Go singleton extension of the class.
It will become available as a global inside scripts and any any other Go Extension types will have any *T typed fields filled in to point at this singleton once they have been instantiated.
T must be a type that is embedding this Singleton as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.