NavigationPathQueryParameters2D

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 24, 2026 License: MIT Imports: 26 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Advanced

type Advanced = class

Advanced exposes a 1:1 low-level instance of the class, undocumented, for those who know what they are doing.

type Any

type Any interface {
	gd.IsClass
	AsNavigationPathQueryParameters2D() Instance
}

type Extension

type Extension[T gdclass.Interface] struct{ gdclass.Extension[T, Instance] }

Extension can be embedded in a new struct to create a Go extension of this class.

T must be a type that is embedding this Extension as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.

func (*Extension[T]) AsNavigationPathQueryParameters2D

func (o *Extension[T]) AsNavigationPathQueryParameters2D() Instance

func (*Extension[T]) AsObject

func (o *Extension[T]) AsObject() [1]gdreference.Object

func (*Extension[T]) AsRefCounted

func (o *Extension[T]) AsRefCounted() ie.RC

func (*Extension[T]) ExcludedRegions

func (o *Extension[T]) ExcludedRegions() []RID.Any

func (*Extension[T]) IncludedRegions

func (o *Extension[T]) IncludedRegions() []RID.Any

func (*Extension[T]) Map

func (o *Extension[T]) Map() RID.NavigationMap2D

func (*Extension[T]) MetadataFlags

func (o *Extension[T]) MetadataFlags() PathMetadataFlags

func (*Extension[T]) NavigationLayers

func (o *Extension[T]) NavigationLayers() int

func (*Extension[T]) PathPostprocessing

func (o *Extension[T]) PathPostprocessing() PathPostProcessing

func (*Extension[T]) PathReturnMaxLength

func (o *Extension[T]) PathReturnMaxLength() Float.X

func (*Extension[T]) PathReturnMaxRadius

func (o *Extension[T]) PathReturnMaxRadius() Float.X

func (*Extension[T]) PathSearchMaxDistance

func (o *Extension[T]) PathSearchMaxDistance() Float.X

func (*Extension[T]) PathSearchMaxPolygons

func (o *Extension[T]) PathSearchMaxPolygons() int

func (*Extension[T]) PathfindingAlgorithm

func (o *Extension[T]) PathfindingAlgorithm() PathfindingAlgorithm

func (*Extension[T]) SetExcludedRegions

func (o *Extension[T]) SetExcludedRegions(value []RID.Any) *Extension[T]

func (*Extension[T]) SetIncludedRegions

func (o *Extension[T]) SetIncludedRegions(value []RID.Any) *Extension[T]

func (*Extension[T]) SetMap

func (o *Extension[T]) SetMap(value RID.NavigationMap2D) *Extension[T]

func (*Extension[T]) SetMetadataFlags

func (o *Extension[T]) SetMetadataFlags(value PathMetadataFlags) *Extension[T]

func (*Extension[T]) SetNavigationLayers

func (o *Extension[T]) SetNavigationLayers(value int) *Extension[T]

func (*Extension[T]) SetPathPostprocessing

func (o *Extension[T]) SetPathPostprocessing(value PathPostProcessing) *Extension[T]

func (*Extension[T]) SetPathReturnMaxLength

func (o *Extension[T]) SetPathReturnMaxLength(value Float.X) *Extension[T]

func (*Extension[T]) SetPathReturnMaxRadius

func (o *Extension[T]) SetPathReturnMaxRadius(value Float.X) *Extension[T]

func (*Extension[T]) SetPathSearchMaxDistance

func (o *Extension[T]) SetPathSearchMaxDistance(value Float.X) *Extension[T]

func (*Extension[T]) SetPathSearchMaxPolygons

func (o *Extension[T]) SetPathSearchMaxPolygons(value int) *Extension[T]

func (*Extension[T]) SetPathfindingAlgorithm

func (o *Extension[T]) SetPathfindingAlgorithm(value PathfindingAlgorithm) *Extension[T]

func (*Extension[T]) SetSimplifyEpsilon

func (o *Extension[T]) SetSimplifyEpsilon(value Float.X) *Extension[T]

func (*Extension[T]) SetSimplifyPath

func (o *Extension[T]) SetSimplifyPath(value bool) *Extension[T]

func (*Extension[T]) SetStartPosition

func (o *Extension[T]) SetStartPosition(value Vector2.XY) *Extension[T]

func (*Extension[T]) SetTargetPosition

func (o *Extension[T]) SetTargetPosition(value Vector2.XY) *Extension[T]

func (*Extension[T]) SimplifyEpsilon

func (o *Extension[T]) SimplifyEpsilon() Float.X

func (*Extension[T]) SimplifyPath

func (o *Extension[T]) SimplifyPath() bool

func (*Extension[T]) StartPosition

func (o *Extension[T]) StartPosition() Vector2.XY

func (*Extension[T]) TargetPosition

func (o *Extension[T]) TargetPosition() Vector2.XY

type ID

type ID Object.ID

ID is a typed object ID (reference) to an instance of this class, use it to store references to objects with unknown lifetimes, as an ID will not panic on use if the underlying object has been destroyed.

func (ID) Instance

func (id ID) Instance() (Instance, bool)

type Instance

Instance of the class with convieniently typed arguments and results.

var Nil Instance

Nil is a nil/null instance of the class. Equivalent to the zero value.

func New

func New() Instance

func (Instance) AsNavigationPathQueryParameters2D

func (o Instance) AsNavigationPathQueryParameters2D() Instance

func (Instance) AsObject

func (o Instance) AsObject() [1]gdreference.Object

func (Instance) AsRefCounted

func (o Instance) AsRefCounted() ie.RC

func (Instance) ExcludedRegions

func (self Instance) ExcludedRegions() []RID.Any

func (Instance) ID

func (self Instance) ID() ID

func (Instance) IncludedRegions

func (self Instance) IncludedRegions() []RID.Any

func (Instance) Map

func (self Instance) Map() RID.NavigationMap2D

func (Instance) MetadataFlags

func (self Instance) MetadataFlags() PathMetadataFlags

func (Instance) NavigationLayers

func (self Instance) NavigationLayers() int

func (Instance) PathPostprocessing

func (self Instance) PathPostprocessing() PathPostProcessing

func (Instance) PathReturnMaxLength

func (self Instance) PathReturnMaxLength() Float.X

func (Instance) PathReturnMaxRadius

func (self Instance) PathReturnMaxRadius() Float.X

func (Instance) PathSearchMaxDistance

func (self Instance) PathSearchMaxDistance() Float.X

func (Instance) PathSearchMaxPolygons

func (self Instance) PathSearchMaxPolygons() int

func (Instance) PathfindingAlgorithm

func (self Instance) PathfindingAlgorithm() PathfindingAlgorithm

func (Instance) SetExcludedRegions

func (self Instance) SetExcludedRegions(value []RID.Any) Instance

SetExcludedRegions sets the property returned by [GetExcludedRegions]. Returns the instance, so that property settings can be chained.

func (Instance) SetIncludedRegions

func (self Instance) SetIncludedRegions(value []RID.Any) Instance

SetIncludedRegions sets the property returned by [GetIncludedRegions]. Returns the instance, so that property settings can be chained.

func (Instance) SetMap

func (self Instance) SetMap(value RID.NavigationMap2D) Instance

SetMap sets the property returned by [GetMap]. Returns the instance, so that property settings can be chained.

func (Instance) SetMetadataFlags

func (self Instance) SetMetadataFlags(value PathMetadataFlags) Instance

SetMetadataFlags sets the property returned by [GetMetadataFlags]. Returns the instance, so that property settings can be chained.

func (Instance) SetNavigationLayers

func (self Instance) SetNavigationLayers(value int) Instance

SetNavigationLayers sets the property returned by [GetNavigationLayers]. Returns the instance, so that property settings can be chained.

func (*Instance) SetObject

func (self *Instance) SetObject(obj [1]gdreference.Object) bool

func (Instance) SetPathPostprocessing

func (self Instance) SetPathPostprocessing(value PathPostProcessing) Instance

SetPathPostprocessing sets the property returned by [GetPathPostprocessing]. Returns the instance, so that property settings can be chained.

func (Instance) SetPathReturnMaxLength

func (self Instance) SetPathReturnMaxLength(value Float.X) Instance

SetPathReturnMaxLength sets the property returned by [GetPathReturnMaxLength]. Returns the instance, so that property settings can be chained.

func (Instance) SetPathReturnMaxRadius

func (self Instance) SetPathReturnMaxRadius(value Float.X) Instance

SetPathReturnMaxRadius sets the property returned by [GetPathReturnMaxRadius]. Returns the instance, so that property settings can be chained.

func (Instance) SetPathSearchMaxDistance

func (self Instance) SetPathSearchMaxDistance(value Float.X) Instance

SetPathSearchMaxDistance sets the property returned by [GetPathSearchMaxDistance]. Returns the instance, so that property settings can be chained.

func (Instance) SetPathSearchMaxPolygons

func (self Instance) SetPathSearchMaxPolygons(value int) Instance

SetPathSearchMaxPolygons sets the property returned by [GetPathSearchMaxPolygons]. Returns the instance, so that property settings can be chained.

func (Instance) SetPathfindingAlgorithm

func (self Instance) SetPathfindingAlgorithm(value PathfindingAlgorithm) Instance

SetPathfindingAlgorithm sets the property returned by [GetPathfindingAlgorithm]. Returns the instance, so that property settings can be chained.

func (Instance) SetSimplifyEpsilon

func (self Instance) SetSimplifyEpsilon(value Float.X) Instance

SetSimplifyEpsilon sets the property returned by [GetSimplifyEpsilon]. Returns the instance, so that property settings can be chained.

func (Instance) SetSimplifyPath

func (self Instance) SetSimplifyPath(value bool) Instance

SetSimplifyPath sets the property returned by [GetSimplifyPath]. Returns the instance, so that property settings can be chained.

func (Instance) SetStartPosition

func (self Instance) SetStartPosition(value Vector2.XY) Instance

SetStartPosition sets the property returned by [GetStartPosition]. Returns the instance, so that property settings can be chained.

func (Instance) SetTargetPosition

func (self Instance) SetTargetPosition(value Vector2.XY) Instance

SetTargetPosition sets the property returned by [GetTargetPosition]. Returns the instance, so that property settings can be chained.

func (Instance) SimplifyEpsilon

func (self Instance) SimplifyEpsilon() Float.X

func (Instance) SimplifyPath

func (self Instance) SimplifyPath() bool

func (Instance) StartPosition

func (self Instance) StartPosition() Vector2.XY

func (Instance) TargetPosition

func (self Instance) TargetPosition() Vector2.XY

func (Instance) Virtual

func (self Instance) Virtual(name string) reflect.Value

type PathMetadataFlags

type PathMetadataFlags int64 //gd:NavigationPathQueryParameters2D.PathMetadataFlags
const (
	PathMetadataIncludeNone   PathMetadataFlags = 0
	PathMetadataIncludeTypes  PathMetadataFlags = 1
	PathMetadataIncludeRids   PathMetadataFlags = 2
	PathMetadataIncludeOwners PathMetadataFlags = 4
	PathMetadataIncludeAll    PathMetadataFlags = 7
)

type PathPostProcessing

type PathPostProcessing int64 //gd:NavigationPathQueryParameters2D.PathPostProcessing
const (
	PathPostprocessingCorridorfunnel PathPostProcessing = 0
	PathPostprocessingEdgecentered   PathPostProcessing = 1
	PathPostprocessingNone           PathPostProcessing = 2
)

type PathfindingAlgorithm

type PathfindingAlgorithm int64 //gd:NavigationPathQueryParameters2D.PathfindingAlgorithm
const (
	PathfindingAlgorithmAstar PathfindingAlgorithm = 0
)

type Singleton

type Singleton[T gdclass.Interface] = Extension[T]

Singleton can be embedded in a new struct to create a Go singleton extension of the class.

It will become available as a global inside scripts and any any other Go Extension types will have any *T typed fields filled in to point at this singleton once they have been instantiated.

T must be a type that is embedding this Singleton as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.

Jump to