Documentation
¶
Index ¶
- type Advanced
- type Any
- type Extension
- func (o *Extension[T]) AsNavigationPathQueryParameters3D() Instance
- func (o *Extension[T]) AsObject() [1]gdreference.Object
- func (o *Extension[T]) AsRefCounted() ie.RC
- func (o *Extension[T]) ExcludedRegions() []RID.Any
- func (o *Extension[T]) IncludedRegions() []RID.Any
- func (o *Extension[T]) Map() RID.NavigationMap3D
- func (o *Extension[T]) MetadataFlags() PathMetadataFlags
- func (o *Extension[T]) NavigationLayers() int
- func (o *Extension[T]) PathPostprocessing() PathPostProcessing
- func (o *Extension[T]) PathReturnMaxLength() Float.X
- func (o *Extension[T]) PathReturnMaxRadius() Float.X
- func (o *Extension[T]) PathSearchMaxDistance() Float.X
- func (o *Extension[T]) PathSearchMaxPolygons() int
- func (o *Extension[T]) PathfindingAlgorithm() PathfindingAlgorithm
- func (o *Extension[T]) SetExcludedRegions(value []RID.Any) *Extension[T]
- func (o *Extension[T]) SetIncludedRegions(value []RID.Any) *Extension[T]
- func (o *Extension[T]) SetMap(value RID.NavigationMap3D) *Extension[T]
- func (o *Extension[T]) SetMetadataFlags(value PathMetadataFlags) *Extension[T]
- func (o *Extension[T]) SetNavigationLayers(value int) *Extension[T]
- func (o *Extension[T]) SetPathPostprocessing(value PathPostProcessing) *Extension[T]
- func (o *Extension[T]) SetPathReturnMaxLength(value Float.X) *Extension[T]
- func (o *Extension[T]) SetPathReturnMaxRadius(value Float.X) *Extension[T]
- func (o *Extension[T]) SetPathSearchMaxDistance(value Float.X) *Extension[T]
- func (o *Extension[T]) SetPathSearchMaxPolygons(value int) *Extension[T]
- func (o *Extension[T]) SetPathfindingAlgorithm(value PathfindingAlgorithm) *Extension[T]
- func (o *Extension[T]) SetSimplifyEpsilon(value Float.X) *Extension[T]
- func (o *Extension[T]) SetSimplifyPath(value bool) *Extension[T]
- func (o *Extension[T]) SetStartPosition(value Vector3.XYZ) *Extension[T]
- func (o *Extension[T]) SetTargetPosition(value Vector3.XYZ) *Extension[T]
- func (o *Extension[T]) SimplifyEpsilon() Float.X
- func (o *Extension[T]) SimplifyPath() bool
- func (o *Extension[T]) StartPosition() Vector3.XYZ
- func (o *Extension[T]) TargetPosition() Vector3.XYZ
- type ID
- type Instance
- func (o Instance) AsNavigationPathQueryParameters3D() Instance
- func (o Instance) AsObject() [1]gdreference.Object
- func (o Instance) AsRefCounted() ie.RC
- func (self Instance) ExcludedRegions() []RID.Any
- func (self Instance) ID() ID
- func (self Instance) IncludedRegions() []RID.Any
- func (self Instance) Map() RID.NavigationMap3D
- func (self Instance) MetadataFlags() PathMetadataFlags
- func (self Instance) NavigationLayers() int
- func (self Instance) PathPostprocessing() PathPostProcessing
- func (self Instance) PathReturnMaxLength() Float.X
- func (self Instance) PathReturnMaxRadius() Float.X
- func (self Instance) PathSearchMaxDistance() Float.X
- func (self Instance) PathSearchMaxPolygons() int
- func (self Instance) PathfindingAlgorithm() PathfindingAlgorithm
- func (self Instance) SetExcludedRegions(value []RID.Any) Instance
- func (self Instance) SetIncludedRegions(value []RID.Any) Instance
- func (self Instance) SetMap(value RID.NavigationMap3D) Instance
- func (self Instance) SetMetadataFlags(value PathMetadataFlags) Instance
- func (self Instance) SetNavigationLayers(value int) Instance
- func (self *Instance) SetObject(obj [1]gdreference.Object) bool
- func (self Instance) SetPathPostprocessing(value PathPostProcessing) Instance
- func (self Instance) SetPathReturnMaxLength(value Float.X) Instance
- func (self Instance) SetPathReturnMaxRadius(value Float.X) Instance
- func (self Instance) SetPathSearchMaxDistance(value Float.X) Instance
- func (self Instance) SetPathSearchMaxPolygons(value int) Instance
- func (self Instance) SetPathfindingAlgorithm(value PathfindingAlgorithm) Instance
- func (self Instance) SetSimplifyEpsilon(value Float.X) Instance
- func (self Instance) SetSimplifyPath(value bool) Instance
- func (self Instance) SetStartPosition(value Vector3.XYZ) Instance
- func (self Instance) SetTargetPosition(value Vector3.XYZ) Instance
- func (self Instance) SimplifyEpsilon() Float.X
- func (self Instance) SimplifyPath() bool
- func (self Instance) StartPosition() Vector3.XYZ
- func (self Instance) TargetPosition() Vector3.XYZ
- func (self Instance) Virtual(name string) reflect.Value
- type PathMetadataFlags
- type PathPostProcessing
- type PathfindingAlgorithm
- type Singleton
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Advanced ¶
type Advanced = class
Advanced exposes a 1:1 low-level instance of the class, undocumented, for those who know what they are doing.
type Extension ¶
Extension can be embedded in a new struct to create a Go extension of this class.
T must be a type that is embedding this Extension as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.
func (*Extension[T]) AsNavigationPathQueryParameters3D ¶
func (*Extension[T]) AsObject ¶
func (o *Extension[T]) AsObject() [1]gdreference.Object
func (*Extension[T]) AsRefCounted ¶
func (*Extension[T]) ExcludedRegions ¶
func (*Extension[T]) IncludedRegions ¶
func (*Extension[T]) Map ¶
func (o *Extension[T]) Map() RID.NavigationMap3D
func (*Extension[T]) MetadataFlags ¶
func (o *Extension[T]) MetadataFlags() PathMetadataFlags
func (*Extension[T]) NavigationLayers ¶
func (*Extension[T]) PathPostprocessing ¶
func (o *Extension[T]) PathPostprocessing() PathPostProcessing
func (*Extension[T]) PathReturnMaxLength ¶
func (*Extension[T]) PathReturnMaxRadius ¶
func (*Extension[T]) PathSearchMaxDistance ¶
func (*Extension[T]) PathSearchMaxPolygons ¶
func (*Extension[T]) PathfindingAlgorithm ¶
func (o *Extension[T]) PathfindingAlgorithm() PathfindingAlgorithm
func (*Extension[T]) SetExcludedRegions ¶
func (*Extension[T]) SetIncludedRegions ¶
func (*Extension[T]) SetMap ¶
func (o *Extension[T]) SetMap(value RID.NavigationMap3D) *Extension[T]
func (*Extension[T]) SetMetadataFlags ¶
func (o *Extension[T]) SetMetadataFlags(value PathMetadataFlags) *Extension[T]
func (*Extension[T]) SetNavigationLayers ¶
func (*Extension[T]) SetPathPostprocessing ¶
func (o *Extension[T]) SetPathPostprocessing(value PathPostProcessing) *Extension[T]
func (*Extension[T]) SetPathReturnMaxLength ¶
func (*Extension[T]) SetPathReturnMaxRadius ¶
func (*Extension[T]) SetPathSearchMaxDistance ¶
func (*Extension[T]) SetPathSearchMaxPolygons ¶
func (*Extension[T]) SetPathfindingAlgorithm ¶
func (o *Extension[T]) SetPathfindingAlgorithm(value PathfindingAlgorithm) *Extension[T]
func (*Extension[T]) SetSimplifyEpsilon ¶
func (*Extension[T]) SetSimplifyPath ¶
func (*Extension[T]) SetStartPosition ¶
func (*Extension[T]) SetTargetPosition ¶
func (*Extension[T]) SimplifyEpsilon ¶
func (*Extension[T]) SimplifyPath ¶
func (*Extension[T]) StartPosition ¶
func (*Extension[T]) TargetPosition ¶
type ID ¶
ID is a typed object ID (reference) to an instance of this class, use it to store references to objects with unknown lifetimes, as an ID will not panic on use if the underlying object has been destroyed.
type Instance ¶
type Instance [1]gdclass.NavigationPathQueryParameters3D
Instance of the class with convieniently typed arguments and results.
var Nil Instance
Nil is a nil/null instance of the class. Equivalent to the zero value.
func (Instance) AsNavigationPathQueryParameters3D ¶
func (Instance) AsObject ¶
func (o Instance) AsObject() [1]gdreference.Object
func (Instance) AsRefCounted ¶
func (Instance) ExcludedRegions ¶
func (Instance) IncludedRegions ¶
func (Instance) Map ¶
func (self Instance) Map() RID.NavigationMap3D
func (Instance) MetadataFlags ¶
func (self Instance) MetadataFlags() PathMetadataFlags
func (Instance) NavigationLayers ¶
func (Instance) PathPostprocessing ¶
func (self Instance) PathPostprocessing() PathPostProcessing
func (Instance) PathReturnMaxLength ¶
func (Instance) PathReturnMaxRadius ¶
func (Instance) PathSearchMaxDistance ¶
func (Instance) PathSearchMaxPolygons ¶
func (Instance) PathfindingAlgorithm ¶
func (self Instance) PathfindingAlgorithm() PathfindingAlgorithm
func (Instance) SetExcludedRegions ¶
SetExcludedRegions sets the property returned by [GetExcludedRegions]. Returns the instance, so that property settings can be chained.
func (Instance) SetIncludedRegions ¶
SetIncludedRegions sets the property returned by [GetIncludedRegions]. Returns the instance, so that property settings can be chained.
func (Instance) SetMap ¶
func (self Instance) SetMap(value RID.NavigationMap3D) Instance
SetMap sets the property returned by [GetMap]. Returns the instance, so that property settings can be chained.
func (Instance) SetMetadataFlags ¶
func (self Instance) SetMetadataFlags(value PathMetadataFlags) Instance
SetMetadataFlags sets the property returned by [GetMetadataFlags]. Returns the instance, so that property settings can be chained.
func (Instance) SetNavigationLayers ¶
SetNavigationLayers sets the property returned by [GetNavigationLayers]. Returns the instance, so that property settings can be chained.
func (Instance) SetPathPostprocessing ¶
func (self Instance) SetPathPostprocessing(value PathPostProcessing) Instance
SetPathPostprocessing sets the property returned by [GetPathPostprocessing]. Returns the instance, so that property settings can be chained.
func (Instance) SetPathReturnMaxLength ¶
SetPathReturnMaxLength sets the property returned by [GetPathReturnMaxLength]. Returns the instance, so that property settings can be chained.
func (Instance) SetPathReturnMaxRadius ¶
SetPathReturnMaxRadius sets the property returned by [GetPathReturnMaxRadius]. Returns the instance, so that property settings can be chained.
func (Instance) SetPathSearchMaxDistance ¶
SetPathSearchMaxDistance sets the property returned by [GetPathSearchMaxDistance]. Returns the instance, so that property settings can be chained.
func (Instance) SetPathSearchMaxPolygons ¶
SetPathSearchMaxPolygons sets the property returned by [GetPathSearchMaxPolygons]. Returns the instance, so that property settings can be chained.
func (Instance) SetPathfindingAlgorithm ¶
func (self Instance) SetPathfindingAlgorithm(value PathfindingAlgorithm) Instance
SetPathfindingAlgorithm sets the property returned by [GetPathfindingAlgorithm]. Returns the instance, so that property settings can be chained.
func (Instance) SetSimplifyEpsilon ¶
SetSimplifyEpsilon sets the property returned by [GetSimplifyEpsilon]. Returns the instance, so that property settings can be chained.
func (Instance) SetSimplifyPath ¶
SetSimplifyPath sets the property returned by [GetSimplifyPath]. Returns the instance, so that property settings can be chained.
func (Instance) SetStartPosition ¶
SetStartPosition sets the property returned by [GetStartPosition]. Returns the instance, so that property settings can be chained.
func (Instance) SetTargetPosition ¶
SetTargetPosition sets the property returned by [GetTargetPosition]. Returns the instance, so that property settings can be chained.
func (Instance) SimplifyEpsilon ¶
func (Instance) SimplifyPath ¶
func (Instance) StartPosition ¶
func (Instance) TargetPosition ¶
type PathMetadataFlags ¶
type PathMetadataFlags int64 //gd:NavigationPathQueryParameters3D.PathMetadataFlags
const ( PathMetadataIncludeNone PathMetadataFlags = 0 PathMetadataIncludeTypes PathMetadataFlags = 1 PathMetadataIncludeRids PathMetadataFlags = 2 PathMetadataIncludeOwners PathMetadataFlags = 4 PathMetadataIncludeAll PathMetadataFlags = 7 )
type PathPostProcessing ¶
type PathPostProcessing int64 //gd:NavigationPathQueryParameters3D.PathPostProcessing
const ( PathPostprocessingCorridorfunnel PathPostProcessing = 0 PathPostprocessingEdgecentered PathPostProcessing = 1 PathPostprocessingNone PathPostProcessing = 2 )
type PathfindingAlgorithm ¶
type PathfindingAlgorithm int64 //gd:NavigationPathQueryParameters3D.PathfindingAlgorithm
const (
PathfindingAlgorithmAstar PathfindingAlgorithm = 0
)
type Singleton ¶
Singleton can be embedded in a new struct to create a Go singleton extension of the class.
It will become available as a global inside scripts and any any other Go Extension types will have any *T typed fields filled in to point at this singleton once they have been instantiated.
T must be a type that is embedding this Singleton as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.