OpenXRAndroidThreadSettingsExtension

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 24, 2026 License: MIT Imports: 26 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Advanced

type Advanced = class

Advanced exposes a 1:1 low-level instance of the class, undocumented, for those who know what they are doing.

type Any

type Any interface {
	gd.IsClass
	AsOpenXRAndroidThreadSettingsExtension() Instance
}

type Expanded

type Expanded = MoreArgs

type Extension

type Extension[T gdclass.Interface] struct{ gdclass.Extension[T, Instance] }

Extension can be embedded in a new struct to create a Go extension of this class.

T must be a type that is embedding this Extension as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.

func (*Extension[T]) AsObject

func (o *Extension[T]) AsObject() [1]gdreference.Object

func (*Extension[T]) AsOpenXRAndroidThreadSettingsExtension

func (o *Extension[T]) AsOpenXRAndroidThreadSettingsExtension() Instance

func (*Extension[T]) AsOpenXRExtensionWrapper

func (o *Extension[T]) AsOpenXRExtensionWrapper() OpenXRExtensionWrapper.Instance

func (*Extension[T]) RegisterExtensionWrapper

func (o *Extension[T]) RegisterExtensionWrapper()

RegisterExtensionWrapper is promoted from OpenXRExtensionWrapper.Instance.RegisterExtensionWrapper.

type ID

type ID Object.ID

ID is a typed object ID (reference) to an instance of this class, use it to store references to objects with unknown lifetimes, as an ID will not panic on use if the underlying object has been destroyed.

func (ID) Instance

func (id ID) Instance() (Instance, bool)

type Instance

Instance of the class with convieniently typed arguments and results.

var Nil Instance

Nil is a nil/null instance of the class. Equivalent to the zero value.

func New

func New() Instance

func (Instance) AsObject

func (o Instance) AsObject() [1]gdreference.Object

func (Instance) AsOpenXRAndroidThreadSettingsExtension

func (o Instance) AsOpenXRAndroidThreadSettingsExtension() Instance

func (Instance) AsOpenXRExtensionWrapper

func (o Instance) AsOpenXRExtensionWrapper() OpenXRExtensionWrapper.Instance

func (Instance) ID

func (self Instance) ID() ID

func (Instance) MoreArgs

func (self Instance) MoreArgs() MoreArgs

MoreArgs enables certain functions to be called with additional 'optional' arguments.

func (Instance) RegisterExtensionWrapper

func (self Instance) RegisterExtensionWrapper()

RegisterExtensionWrapper is promoted from OpenXRExtensionWrapper.Instance.RegisterExtensionWrapper.

func (Instance) SetApplicationThreadType

func (self Instance) SetApplicationThreadType(thread_type ThreadType) bool

func (*Instance) SetObject

func (self *Instance) SetObject(obj [1]gdreference.Object) bool

func (Instance) Virtual

func (self Instance) Virtual(name string) reflect.Value

type MoreArgs

MoreArgs is a container for Instance functions with additional 'optional' arguments.

func (MoreArgs) SetApplicationThreadType

func (self MoreArgs) SetApplicationThreadType(thread_type ThreadType, thread_id int) bool

type Singleton

type Singleton[T gdclass.Interface] = Extension[T]

Singleton can be embedded in a new struct to create a Go singleton extension of the class.

It will become available as a global inside scripts and any any other Go Extension types will have any *T typed fields filled in to point at this singleton once they have been instantiated.

T must be a type that is embedding this Singleton as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.

type ThreadType

type ThreadType int64 //gd:OpenXRAndroidThreadSettingsExtension.ThreadType
const (
	ThreadTypeApplicationMain   ThreadType = 0
	ThreadTypeApplicationWorker ThreadType = 1
	ThreadTypeRendererMain      ThreadType = 2
	ThreadTypeRendererWorker    ThreadType = 3
)

Jump to