ResourceUID

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 24, 2026 License: MIT Imports: 27 Imported by: 0

Documentation

Index

Constants

const InvalidId Resource.UID = -1 //gd:ResourceUID.INVALID_ID

Variables

This section is empty.

Functions

func AddId

func AddId(id Resource.UID, path string)

func Advanced

func Advanced() class

Advanced exposes a 1:1 low-level instance of the class, undocumented, for those who know what they are doing.

func CreateId

func CreateId() int

func CreateIdForPath

func CreateIdForPath(path string) int

func EnsurePath

func EnsurePath(path_or_uid string) string

func GetIdPath

func GetIdPath(id Resource.UID) string

func HasId

func HasId(id Resource.UID) bool

func IdToText

func IdToText(id Resource.UID) string

func PathToUid

func PathToUid(path string) string

func RemoveId

func RemoveId(id Resource.UID)

func SetId

func SetId(id Resource.UID, path string)

func TextToId

func TextToId(text_id string) int

func UidToPath

func UidToPath(uid string) string

Types

type Extension

type Extension[T gdclass.Interface] struct{ gdclass.Extension[T, Instance] }

Extension can be embedded in a new struct to create a Go extension of this class.

T must be a type that is embedding this Extension as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.

func (*Extension[T]) AsObject

func (o *Extension[T]) AsObject() [1]gdreference.Object

type ID

type ID Object.ID

ID is a typed object ID (reference) to an instance of this class, use it to store references to objects with unknown lifetimes, as an ID will not panic on use if the underlying object has been destroyed.

func (ID) Instance

func (id ID) Instance() (Instance, bool)

type Instance

type Instance [1]gdclass.ResourceUID

Instance of the class with convieniently typed arguments and results.

func (Instance) AsObject

func (o Instance) AsObject() [1]gdreference.Object

func (Instance) ID

func (self Instance) ID() ID

func (*Instance) SetObject

func (self *Instance) SetObject(obj [1]gdreference.Object) bool

func (Instance) Virtual

func (self Instance) Virtual(name string) reflect.Value

type Singleton

type Singleton[T gdclass.Interface] = Extension[T]

Singleton can be embedded in a new struct to create a Go singleton extension of the class.

It will become available as a global inside scripts and any any other Go Extension types will have any *T typed fields filled in to point at this singleton once they have been instantiated.

T must be a type that is embedding this Singleton as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.

Jump to