Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Advanced ¶
type Advanced = class
Advanced exposes a 1:1 low-level instance of the class, undocumented, for those who know what they are doing.
type Extension ¶
Extension can be embedded in a new struct to create a Go extension of this class.
T must be a type that is embedding this Extension as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.
func (*Extension[T]) AsObject ¶
func (o *Extension[T]) AsObject() [1]gdreference.Object
func (*Extension[T]) AsScriptLanguage ¶
type ID ¶
ID is a typed object ID (reference) to an instance of this class, use it to store references to objects with unknown lifetimes, as an ID will not panic on use if the underlying object has been destroyed.
type Instance ¶
type Instance [1]gdclass.ScriptLanguage
Instance of the class with convieniently typed arguments and results.
var Nil Instance
Nil is a nil/null instance of the class. Equivalent to the zero value.
func (Instance) AsObject ¶
func (o Instance) AsObject() [1]gdreference.Object
func (Instance) AsScriptLanguage ¶
type ScriptNameCasing ¶
type ScriptNameCasing int64 //gd:ScriptLanguage.ScriptNameCasing
const ( ScriptNameCasingAuto ScriptNameCasing = 0 ScriptNameCasingPascalCase ScriptNameCasing = 1 ScriptNameCasingSnakeCase ScriptNameCasing = 2 ScriptNameCasingKebabCase ScriptNameCasing = 3 ScriptNameCasingCamelCase ScriptNameCasing = 4 )
type Singleton ¶
Singleton can be embedded in a new struct to create a Go singleton extension of the class.
It will become available as a global inside scripts and any any other Go Extension types will have any *T typed fields filled in to point at this singleton once they have been instantiated.
T must be a type that is embedding this Singleton as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.