VisualShaderNodeTexture2DArray

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 24, 2026 License: MIT Imports: 29 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Advanced

type Advanced = class

Advanced exposes a 1:1 low-level instance of the class, undocumented, for those who know what they are doing.

type Any

type Any interface {
	gd.IsClass
	AsVisualShaderNodeTexture2DArray() Instance
}

type Extension

type Extension[T gdclass.Interface] struct{ gdclass.Extension[T, Instance] }

Extension can be embedded in a new struct to create a Go extension of this class.

T must be a type that is embedding this Extension as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.

func (*Extension[T]) AsObject

func (o *Extension[T]) AsObject() [1]gdreference.Object

func (*Extension[T]) AsRefCounted

func (o *Extension[T]) AsRefCounted() ie.RC

func (*Extension[T]) AsResource

func (o *Extension[T]) AsResource() Resource.Instance

func (*Extension[T]) AsVisualShaderNode

func (o *Extension[T]) AsVisualShaderNode() VisualShaderNode.Instance

func (*Extension[T]) AsVisualShaderNodeSample3D

func (o *Extension[T]) AsVisualShaderNodeSample3D() VisualShaderNodeSample3D.Instance

func (*Extension[T]) AsVisualShaderNodeTexture2DArray

func (o *Extension[T]) AsVisualShaderNodeTexture2DArray() Instance

func (*Extension[T]) ClearDefaultInputValues

func (o *Extension[T]) ClearDefaultInputValues()

ClearDefaultInputValues is promoted from VisualShaderNode.Instance.ClearDefaultInputValues.

func (*Extension[T]) DefaultInputValues

func (o *Extension[T]) DefaultInputValues() []any

func (*Extension[T]) EmitChanged

func (o *Extension[T]) EmitChanged()

EmitChanged is promoted from Resource.Instance.EmitChanged.

func (*Extension[T]) GetDefaultInputPort

func (o *Extension[T]) GetDefaultInputPort(atype VisualShaderNode.PortType) int

GetDefaultInputPort is promoted from VisualShaderNode.Instance.GetDefaultInputPort.

func (*Extension[T]) GetIdForPath

func (o *Extension[T]) GetIdForPath(path string) string

GetIdForPath is promoted from Resource.Instance.GetIdForPath.

func (*Extension[T]) GetInputPortDefaultValue

func (o *Extension[T]) GetInputPortDefaultValue(port int) any

GetInputPortDefaultValue is promoted from VisualShaderNode.Instance.GetInputPortDefaultValue.

func (*Extension[T]) GetRid

func (o *Extension[T]) GetRid() Resource.ID

GetRid is promoted from Resource.Instance.GetRid.

func (*Extension[T]) IsBuiltIn

func (o *Extension[T]) IsBuiltIn() bool

IsBuiltIn is promoted from Resource.Instance.IsBuiltIn.

func (*Extension[T]) LinkedParentGraphFrame

func (o *Extension[T]) LinkedParentGraphFrame() int

func (*Extension[T]) OnChanged

func (o *Extension[T]) OnChanged(cb func(), flags ...Signal.Flags) *Extension[T]

OnChanged is promoted from Resource.Instance.OnChanged.

func (*Extension[T]) OnSetupLocalToSceneRequested

func (o *Extension[T]) OnSetupLocalToSceneRequested(cb func(), flags ...Signal.Flags) *Extension[T]

OnSetupLocalToSceneRequested is promoted from Resource.Instance.OnSetupLocalToSceneRequested.

func (*Extension[T]) OutputPortForPreview

func (o *Extension[T]) OutputPortForPreview() int

func (*Extension[T]) RemoveInputPortDefaultValue

func (o *Extension[T]) RemoveInputPortDefaultValue(port int)

RemoveInputPortDefaultValue is promoted from VisualShaderNode.Instance.RemoveInputPortDefaultValue.

func (*Extension[T]) ResetState

func (o *Extension[T]) ResetState()

ResetState is promoted from Resource.Instance.ResetState.

func (*Extension[T]) ResourceLocalToScene

func (o *Extension[T]) ResourceLocalToScene() bool

func (*Extension[T]) ResourceName

func (o *Extension[T]) ResourceName() string

func (*Extension[T]) ResourcePath

func (o *Extension[T]) ResourcePath() string

func (*Extension[T]) ResourceSceneUniqueId

func (o *Extension[T]) ResourceSceneUniqueId() string

func (*Extension[T]) SetDefaultInputValues

func (o *Extension[T]) SetDefaultInputValues(value []any) *Extension[T]

func (*Extension[T]) SetIdForPath

func (o *Extension[T]) SetIdForPath(path string, id string) *Extension[T]

SetIdForPath is promoted from Resource.Instance.SetIdForPath.

func (*Extension[T]) SetLinkedParentGraphFrame

func (o *Extension[T]) SetLinkedParentGraphFrame(value int) *Extension[T]

func (*Extension[T]) SetOutputPortForPreview

func (o *Extension[T]) SetOutputPortForPreview(value int) *Extension[T]

func (*Extension[T]) SetPathCache

func (o *Extension[T]) SetPathCache(path string) *Extension[T]

SetPathCache is promoted from Resource.Instance.SetPathCache.

func (*Extension[T]) SetResourceLocalToScene

func (o *Extension[T]) SetResourceLocalToScene(value bool) *Extension[T]

func (*Extension[T]) SetResourceName

func (o *Extension[T]) SetResourceName(value string) *Extension[T]

func (*Extension[T]) SetResourcePath

func (o *Extension[T]) SetResourcePath(value string) *Extension[T]

func (*Extension[T]) SetResourceSceneUniqueId

func (o *Extension[T]) SetResourceSceneUniqueId(value string) *Extension[T]

func (*Extension[T]) SetSource

func (o *Extension[T]) SetSource(value VisualShaderNodeSample3D.Source) *Extension[T]

func (*Extension[T]) SetTextureArray

func (o *Extension[T]) SetTextureArray(value TextureLayered.Instance) *Extension[T]

func (*Extension[T]) SetupLocalToScene

func (o *Extension[T]) SetupLocalToScene()

SetupLocalToScene is promoted from Resource.Instance.SetupLocalToScene.

func (*Extension[T]) Source

func (o *Extension[T]) Source() VisualShaderNodeSample3D.Source

func (*Extension[T]) TakeOverPath

func (o *Extension[T]) TakeOverPath(path string)

TakeOverPath is promoted from Resource.Instance.TakeOverPath.

func (*Extension[T]) TextureArray

func (o *Extension[T]) TextureArray() TextureLayered.Instance

type ID

type ID Object.ID

ID is a typed object ID (reference) to an instance of this class, use it to store references to objects with unknown lifetimes, as an ID will not panic on use if the underlying object has been destroyed.

func (ID) Instance

func (id ID) Instance() (Instance, bool)

type Instance

Instance of the class with convieniently typed arguments and results.

var Nil Instance

Nil is a nil/null instance of the class. Equivalent to the zero value.

func New

func New() Instance

func (Instance) AsObject

func (o Instance) AsObject() [1]gdreference.Object

func (Instance) AsRefCounted

func (o Instance) AsRefCounted() ie.RC

func (Instance) AsResource

func (o Instance) AsResource() Resource.Instance

func (Instance) AsVisualShaderNode

func (o Instance) AsVisualShaderNode() VisualShaderNode.Instance

func (Instance) AsVisualShaderNodeSample3D

func (o Instance) AsVisualShaderNodeSample3D() VisualShaderNodeSample3D.Instance

func (Instance) AsVisualShaderNodeTexture2DArray

func (o Instance) AsVisualShaderNodeTexture2DArray() Instance

func (Instance) ClearDefaultInputValues

func (self Instance) ClearDefaultInputValues()

ClearDefaultInputValues is promoted from VisualShaderNode.Instance.ClearDefaultInputValues.

func (Instance) DefaultInputValues

func (self Instance) DefaultInputValues() []any

DefaultInputValues is promoted from VisualShaderNode.Instance.DefaultInputValues.

func (Instance) EmitChanged

func (self Instance) EmitChanged()

EmitChanged is promoted from Resource.Instance.EmitChanged.

func (Instance) GetDefaultInputPort

func (self Instance) GetDefaultInputPort(atype VisualShaderNode.PortType) int

GetDefaultInputPort is promoted from VisualShaderNode.Instance.GetDefaultInputPort.

func (Instance) GetIdForPath

func (self Instance) GetIdForPath(path string) string

GetIdForPath is promoted from Resource.Instance.GetIdForPath.

func (Instance) GetInputPortDefaultValue

func (self Instance) GetInputPortDefaultValue(port int) any

GetInputPortDefaultValue is promoted from VisualShaderNode.Instance.GetInputPortDefaultValue.

func (Instance) GetRid

func (self Instance) GetRid() Resource.ID

GetRid is promoted from Resource.Instance.GetRid.

func (Instance) ID

func (self Instance) ID() ID

func (Instance) IsBuiltIn

func (self Instance) IsBuiltIn() bool

IsBuiltIn is promoted from Resource.Instance.IsBuiltIn.

func (Instance) LinkedParentGraphFrame

func (self Instance) LinkedParentGraphFrame() int

LinkedParentGraphFrame is promoted from VisualShaderNode.Instance.LinkedParentGraphFrame.

func (Instance) OnChanged

func (self Instance) OnChanged(cb func(), flags ...Signal.Flags) Instance

OnChanged is promoted from Resource.Instance.OnChanged.

func (Instance) OnSetupLocalToSceneRequested

func (self Instance) OnSetupLocalToSceneRequested(cb func(), flags ...Signal.Flags) Instance

OnSetupLocalToSceneRequested is promoted from Resource.Instance.OnSetupLocalToSceneRequested.

func (Instance) OutputPortForPreview

func (self Instance) OutputPortForPreview() int

OutputPortForPreview is promoted from VisualShaderNode.Instance.OutputPortForPreview.

func (Instance) RemoveInputPortDefaultValue

func (self Instance) RemoveInputPortDefaultValue(port int)

RemoveInputPortDefaultValue is promoted from VisualShaderNode.Instance.RemoveInputPortDefaultValue.

func (Instance) ResetState

func (self Instance) ResetState()

ResetState is promoted from Resource.Instance.ResetState.

func (Instance) ResourceLocalToScene

func (self Instance) ResourceLocalToScene() bool

ResourceLocalToScene is promoted from Resource.Instance.ResourceLocalToScene.

func (Instance) ResourceName

func (self Instance) ResourceName() string

ResourceName is promoted from Resource.Instance.ResourceName.

func (Instance) ResourcePath

func (self Instance) ResourcePath() string

ResourcePath is promoted from Resource.Instance.ResourcePath.

func (Instance) ResourceSceneUniqueId

func (self Instance) ResourceSceneUniqueId() string

ResourceSceneUniqueId is promoted from Resource.Instance.ResourceSceneUniqueId.

func (Instance) SetDefaultInputValues

func (self Instance) SetDefaultInputValues(value []any) Instance

SetDefaultInputValues is promoted from VisualShaderNode.Instance.SetDefaultInputValues.

func (Instance) SetIdForPath

func (self Instance) SetIdForPath(path string, id string) Instance

SetIdForPath is promoted from Resource.Instance.SetIdForPath.

func (Instance) SetLinkedParentGraphFrame

func (self Instance) SetLinkedParentGraphFrame(value int) Instance

SetLinkedParentGraphFrame is promoted from VisualShaderNode.Instance.SetLinkedParentGraphFrame.

func (*Instance) SetObject

func (self *Instance) SetObject(obj [1]gdreference.Object) bool

func (Instance) SetOutputPortForPreview

func (self Instance) SetOutputPortForPreview(value int) Instance

SetOutputPortForPreview is promoted from VisualShaderNode.Instance.SetOutputPortForPreview.

func (Instance) SetPathCache

func (self Instance) SetPathCache(path string) Instance

SetPathCache is promoted from Resource.Instance.SetPathCache.

func (Instance) SetResourceLocalToScene

func (self Instance) SetResourceLocalToScene(value bool) Instance

SetResourceLocalToScene is promoted from Resource.Instance.SetResourceLocalToScene.

func (Instance) SetResourceName

func (self Instance) SetResourceName(value string) Instance

SetResourceName is promoted from Resource.Instance.SetResourceName.

func (Instance) SetResourcePath

func (self Instance) SetResourcePath(value string) Instance

SetResourcePath is promoted from Resource.Instance.SetResourcePath.

func (Instance) SetResourceSceneUniqueId

func (self Instance) SetResourceSceneUniqueId(value string) Instance

SetResourceSceneUniqueId is promoted from Resource.Instance.SetResourceSceneUniqueId.

func (Instance) SetSource

func (self Instance) SetSource(value VisualShaderNodeSample3D.Source) Instance

SetSource is promoted from VisualShaderNodeSample3D.Instance.SetSource.

func (Instance) SetTextureArray

func (self Instance) SetTextureArray(value TextureLayered.Instance) Instance

SetTextureArray sets the property returned by [GetTextureArray]. Returns the instance, so that property settings can be chained.

func (Instance) SetupLocalToScene

func (self Instance) SetupLocalToScene()

SetupLocalToScene is promoted from Resource.Instance.SetupLocalToScene.

func (Instance) Source

Source is promoted from VisualShaderNodeSample3D.Instance.Source.

func (Instance) TakeOverPath

func (self Instance) TakeOverPath(path string)

TakeOverPath is promoted from Resource.Instance.TakeOverPath.

func (Instance) TextureArray

func (self Instance) TextureArray() TextureLayered.Instance

func (Instance) Virtual

func (self Instance) Virtual(name string) reflect.Value

type Singleton

type Singleton[T gdclass.Interface] = Extension[T]

Singleton can be embedded in a new struct to create a Go singleton extension of the class.

It will become available as a global inside scripts and any any other Go Extension types will have any *T typed fields filled in to point at this singleton once they have been instantiated.

T must be a type that is embedding this Singleton as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.

Jump to