Documentation
¶
Index ¶
- type Advanced
- type Any
- type Expanded
- type Extension
- func (o *Extension[T]) AsAudioStream() AudioStream.Instance
- func (o *Extension[T]) AsAudioStreamRandomizer() Instance
- func (o *Extension[T]) AsObject() [1]gdreference.Object
- func (o *Extension[T]) AsRefCounted() ie.RC
- func (o *Extension[T]) AsResource() Resource.Instance
- func (o *Extension[T]) CanBeSampled() bool
- func (o *Extension[T]) EmitChanged()
- func (o *Extension[T]) GenerateSample() AudioSample.Instance
- func (o *Extension[T]) GetIdForPath(path string) string
- func (o *Extension[T]) GetLength() Float.X
- func (o *Extension[T]) GetRid() Resource.ID
- func (o *Extension[T]) GetStream(index int) AudioStream.Instance
- func (o *Extension[T]) GetStreamProbabilityWeight(index int) Float.X
- func (o *Extension[T]) InstantiatePlayback() AudioStreamPlayback.Instance
- func (o *Extension[T]) IsBuiltIn() bool
- func (o *Extension[T]) IsMetaStream() bool
- func (o *Extension[T]) IsMonophonic() bool
- func (o *Extension[T]) MoveStream(index_from int, index_to int)
- func (o *Extension[T]) OnChanged(cb func(), flags ...Signal.Flags) *Extension[T]
- func (o *Extension[T]) OnParameterListChanged(cb func(), flags ...Signal.Flags) *Extension[T]
- func (o *Extension[T]) OnSetupLocalToSceneRequested(cb func(), flags ...Signal.Flags) *Extension[T]
- func (o *Extension[T]) PlaybackMode() PlaybackMode
- func (o *Extension[T]) RandomPitch() Float.X
- func (o *Extension[T]) RandomPitchSemitones() Float.X
- func (o *Extension[T]) RandomVolumeOffsetDb() Float.X
- func (o *Extension[T]) RemoveStream(index int)
- func (o *Extension[T]) ResetState()
- func (o *Extension[T]) ResourceLocalToScene() bool
- func (o *Extension[T]) ResourceName() string
- func (o *Extension[T]) ResourcePath() string
- func (o *Extension[T]) ResourceSceneUniqueId() string
- func (o *Extension[T]) SetIdForPath(path string, id string) *Extension[T]
- func (o *Extension[T]) SetPathCache(path string) *Extension[T]
- func (o *Extension[T]) SetPlaybackMode(value PlaybackMode) *Extension[T]
- func (o *Extension[T]) SetRandomPitch(value Float.X) *Extension[T]
- func (o *Extension[T]) SetRandomPitchSemitones(value Float.X) *Extension[T]
- func (o *Extension[T]) SetRandomVolumeOffsetDb(value Float.X) *Extension[T]
- func (o *Extension[T]) SetResourceLocalToScene(value bool) *Extension[T]
- func (o *Extension[T]) SetResourceName(value string) *Extension[T]
- func (o *Extension[T]) SetResourcePath(value string) *Extension[T]
- func (o *Extension[T]) SetResourceSceneUniqueId(value string) *Extension[T]
- func (o *Extension[T]) SetStream(index int, stream AudioStream.Instance) *Extension[T]
- func (o *Extension[T]) SetStreamProbabilityWeight(index int, weight Float.X) *Extension[T]
- func (o *Extension[T]) SetStreamsCount(value int) *Extension[T]
- func (o *Extension[T]) SetupLocalToScene()
- func (o *Extension[T]) StreamsCount() int
- func (o *Extension[T]) TakeOverPath(path string)
- type ID
- type Instance
- func (self Instance) AddStream(index int, stream AudioStream.Instance)
- func (o Instance) AsAudioStream() AudioStream.Instance
- func (o Instance) AsAudioStreamRandomizer() Instance
- func (o Instance) AsObject() [1]gdreference.Object
- func (o Instance) AsRefCounted() ie.RC
- func (o Instance) AsResource() Resource.Instance
- func (self Instance) CanBeSampled() bool
- func (self Instance) EmitChanged()
- func (self Instance) GenerateSample() AudioSample.Instance
- func (self Instance) GetIdForPath(path string) string
- func (self Instance) GetLength() Float.X
- func (self Instance) GetRid() Resource.ID
- func (self Instance) GetStream(index int) AudioStream.Instance
- func (self Instance) GetStreamProbabilityWeight(index int) Float.X
- func (self Instance) ID() ID
- func (self Instance) InstantiatePlayback() AudioStreamPlayback.Instance
- func (self Instance) IsBuiltIn() bool
- func (self Instance) IsMetaStream() bool
- func (self Instance) IsMonophonic() bool
- func (self Instance) MoreArgs() MoreArgs
- func (self Instance) MoveStream(index_from int, index_to int)
- func (self Instance) OnChanged(cb func(), flags ...Signal.Flags) Instance
- func (self Instance) OnParameterListChanged(cb func(), flags ...Signal.Flags) Instance
- func (self Instance) OnSetupLocalToSceneRequested(cb func(), flags ...Signal.Flags) Instance
- func (self Instance) PlaybackMode() PlaybackMode
- func (self Instance) RandomPitch() Float.X
- func (self Instance) RandomPitchSemitones() Float.X
- func (self Instance) RandomVolumeOffsetDb() Float.X
- func (self Instance) RemoveStream(index int)
- func (self Instance) ResetState()
- func (self Instance) ResourceLocalToScene() bool
- func (self Instance) ResourceName() string
- func (self Instance) ResourcePath() string
- func (self Instance) ResourceSceneUniqueId() string
- func (self Instance) SetIdForPath(path string, id string) Instance
- func (self *Instance) SetObject(obj [1]gdreference.Object) bool
- func (self Instance) SetPathCache(path string) Instance
- func (self Instance) SetPlaybackMode(value PlaybackMode) Instance
- func (self Instance) SetRandomPitch(value Float.X) Instance
- func (self Instance) SetRandomPitchSemitones(value Float.X) Instance
- func (self Instance) SetRandomVolumeOffsetDb(value Float.X) Instance
- func (self Instance) SetResourceLocalToScene(value bool) Instance
- func (self Instance) SetResourceName(value string) Instance
- func (self Instance) SetResourcePath(value string) Instance
- func (self Instance) SetResourceSceneUniqueId(value string) Instance
- func (self Instance) SetStream(index int, stream AudioStream.Instance) Instance
- func (self Instance) SetStreamProbabilityWeight(index int, weight Float.X) Instance
- func (self Instance) SetStreamsCount(value int) Instance
- func (self Instance) SetupLocalToScene()
- func (self Instance) StreamsCount() int
- func (self Instance) TakeOverPath(path string)
- func (self Instance) Virtual(name string) reflect.Value
- type MoreArgs
- type PlaybackMode
- type Singleton
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Advanced ¶
type Advanced = class
Advanced exposes a 1:1 low-level instance of the class, undocumented, for those who know what they are doing.
type Extension ¶
Extension can be embedded in a new struct to create a Go extension of this class.
T must be a type that is embedding this Extension as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.
func (*Extension[T]) AsAudioStream ¶
func (o *Extension[T]) AsAudioStream() AudioStream.Instance
func (*Extension[T]) AsAudioStreamRandomizer ¶
func (*Extension[T]) AsObject ¶
func (o *Extension[T]) AsObject() [1]gdreference.Object
func (*Extension[T]) AsRefCounted ¶
func (*Extension[T]) AsResource ¶
func (*Extension[T]) CanBeSampled ¶
CanBeSampled is promoted from AudioStream.Instance.CanBeSampled.
func (*Extension[T]) EmitChanged ¶
func (o *Extension[T]) EmitChanged()
EmitChanged is promoted from Resource.Instance.EmitChanged.
func (*Extension[T]) GenerateSample ¶
func (o *Extension[T]) GenerateSample() AudioSample.Instance
GenerateSample is promoted from AudioStream.Instance.GenerateSample.
func (*Extension[T]) GetIdForPath ¶
GetIdForPath is promoted from Resource.Instance.GetIdForPath.
func (*Extension[T]) GetLength ¶
GetLength is promoted from AudioStream.Instance.GetLength.
func (*Extension[T]) GetRid ¶
GetRid is promoted from Resource.Instance.GetRid.
func (*Extension[T]) GetStreamProbabilityWeight ¶
func (*Extension[T]) InstantiatePlayback ¶
func (o *Extension[T]) InstantiatePlayback() AudioStreamPlayback.Instance
InstantiatePlayback is promoted from AudioStream.Instance.InstantiatePlayback.
func (*Extension[T]) IsBuiltIn ¶
IsBuiltIn is promoted from Resource.Instance.IsBuiltIn.
func (*Extension[T]) IsMetaStream ¶
IsMetaStream is promoted from AudioStream.Instance.IsMetaStream.
func (*Extension[T]) IsMonophonic ¶
IsMonophonic is promoted from AudioStream.Instance.IsMonophonic.
func (*Extension[T]) MoveStream ¶
func (*Extension[T]) OnChanged ¶
OnChanged is promoted from Resource.Instance.OnChanged.
func (*Extension[T]) OnParameterListChanged ¶
OnParameterListChanged is promoted from AudioStream.Instance.OnParameterListChanged.
func (*Extension[T]) OnSetupLocalToSceneRequested ¶
OnSetupLocalToSceneRequested is promoted from Resource.Instance.OnSetupLocalToSceneRequested.
func (*Extension[T]) PlaybackMode ¶
func (o *Extension[T]) PlaybackMode() PlaybackMode
func (*Extension[T]) RandomPitch ¶
func (*Extension[T]) RandomPitchSemitones ¶
func (*Extension[T]) RandomVolumeOffsetDb ¶
func (*Extension[T]) RemoveStream ¶
func (*Extension[T]) ResetState ¶
func (o *Extension[T]) ResetState()
ResetState is promoted from Resource.Instance.ResetState.
func (*Extension[T]) ResourceLocalToScene ¶
func (*Extension[T]) ResourceName ¶
func (*Extension[T]) ResourcePath ¶
func (*Extension[T]) ResourceSceneUniqueId ¶
func (*Extension[T]) SetIdForPath ¶
SetIdForPath is promoted from Resource.Instance.SetIdForPath.
func (*Extension[T]) SetPathCache ¶
SetPathCache is promoted from Resource.Instance.SetPathCache.
func (*Extension[T]) SetPlaybackMode ¶
func (o *Extension[T]) SetPlaybackMode(value PlaybackMode) *Extension[T]
func (*Extension[T]) SetRandomPitch ¶
func (*Extension[T]) SetRandomPitchSemitones ¶
func (*Extension[T]) SetRandomVolumeOffsetDb ¶
func (*Extension[T]) SetResourceLocalToScene ¶
func (*Extension[T]) SetResourceName ¶
func (*Extension[T]) SetResourcePath ¶
func (*Extension[T]) SetResourceSceneUniqueId ¶
func (*Extension[T]) SetStream ¶
func (o *Extension[T]) SetStream(index int, stream AudioStream.Instance) *Extension[T]
func (*Extension[T]) SetStreamProbabilityWeight ¶
func (*Extension[T]) SetStreamsCount ¶
func (*Extension[T]) SetupLocalToScene ¶
func (o *Extension[T]) SetupLocalToScene()
SetupLocalToScene is promoted from Resource.Instance.SetupLocalToScene.
func (*Extension[T]) StreamsCount ¶
func (*Extension[T]) TakeOverPath ¶
TakeOverPath is promoted from Resource.Instance.TakeOverPath.
type ID ¶
ID is a typed object ID (reference) to an instance of this class, use it to store references to objects with unknown lifetimes, as an ID will not panic on use if the underlying object has been destroyed.
type Instance ¶
type Instance [1]gdclass.AudioStreamRandomizer
Instance of the class with convieniently typed arguments and results.
var Nil Instance
Nil is a nil/null instance of the class. Equivalent to the zero value.
func (Instance) AsAudioStream ¶
func (o Instance) AsAudioStream() AudioStream.Instance
func (Instance) AsAudioStreamRandomizer ¶
func (Instance) AsObject ¶
func (o Instance) AsObject() [1]gdreference.Object
func (Instance) AsRefCounted ¶
func (Instance) AsResource ¶
func (Instance) CanBeSampled ¶
CanBeSampled is promoted from AudioStream.Instance.CanBeSampled.
func (Instance) EmitChanged ¶
func (self Instance) EmitChanged()
EmitChanged is promoted from Resource.Instance.EmitChanged.
func (Instance) GenerateSample ¶
func (self Instance) GenerateSample() AudioSample.Instance
GenerateSample is promoted from AudioStream.Instance.GenerateSample.
func (Instance) GetIdForPath ¶
GetIdForPath is promoted from Resource.Instance.GetIdForPath.
func (Instance) GetLength ¶
GetLength is promoted from AudioStream.Instance.GetLength.
func (Instance) GetRid ¶
GetRid is promoted from Resource.Instance.GetRid.
func (Instance) GetStreamProbabilityWeight ¶
func (Instance) InstantiatePlayback ¶
func (self Instance) InstantiatePlayback() AudioStreamPlayback.Instance
InstantiatePlayback is promoted from AudioStream.Instance.InstantiatePlayback.
func (Instance) IsBuiltIn ¶
IsBuiltIn is promoted from Resource.Instance.IsBuiltIn.
func (Instance) IsMetaStream ¶
IsMetaStream is promoted from AudioStream.Instance.IsMetaStream.
func (Instance) IsMonophonic ¶
IsMonophonic is promoted from AudioStream.Instance.IsMonophonic.
func (Instance) MoreArgs ¶
MoreArgs enables certain functions to be called with additional 'optional' arguments.
func (Instance) MoveStream ¶
func (Instance) OnChanged ¶
OnChanged is promoted from Resource.Instance.OnChanged.
func (Instance) OnParameterListChanged ¶
OnParameterListChanged is promoted from AudioStream.Instance.OnParameterListChanged.
func (Instance) OnSetupLocalToSceneRequested ¶
OnSetupLocalToSceneRequested is promoted from Resource.Instance.OnSetupLocalToSceneRequested.
func (Instance) PlaybackMode ¶
func (self Instance) PlaybackMode() PlaybackMode
func (Instance) RandomPitch ¶
func (Instance) RandomPitchSemitones ¶
func (Instance) RandomVolumeOffsetDb ¶
func (Instance) RemoveStream ¶
func (Instance) ResetState ¶
func (self Instance) ResetState()
ResetState is promoted from Resource.Instance.ResetState.
func (Instance) ResourceLocalToScene ¶
ResourceLocalToScene is promoted from Resource.Instance.ResourceLocalToScene.
func (Instance) ResourceName ¶
ResourceName is promoted from Resource.Instance.ResourceName.
func (Instance) ResourcePath ¶
ResourcePath is promoted from Resource.Instance.ResourcePath.
func (Instance) ResourceSceneUniqueId ¶
ResourceSceneUniqueId is promoted from Resource.Instance.ResourceSceneUniqueId.
func (Instance) SetIdForPath ¶
SetIdForPath is promoted from Resource.Instance.SetIdForPath.
func (Instance) SetPathCache ¶
SetPathCache is promoted from Resource.Instance.SetPathCache.
func (Instance) SetPlaybackMode ¶
func (self Instance) SetPlaybackMode(value PlaybackMode) Instance
SetPlaybackMode sets the property returned by [GetPlaybackMode]. Returns the instance, so that property settings can be chained.
func (Instance) SetRandomPitch ¶
SetRandomPitch sets the property returned by [GetRandomPitch]. Returns the instance, so that property settings can be chained.
func (Instance) SetRandomPitchSemitones ¶
SetRandomPitchSemitones sets the property returned by [GetRandomPitchSemitones]. Returns the instance, so that property settings can be chained.
func (Instance) SetRandomVolumeOffsetDb ¶
SetRandomVolumeOffsetDb sets the property returned by [GetRandomVolumeOffsetDb]. Returns the instance, so that property settings can be chained.
func (Instance) SetResourceLocalToScene ¶
SetResourceLocalToScene is promoted from Resource.Instance.SetResourceLocalToScene.
func (Instance) SetResourceName ¶
SetResourceName is promoted from Resource.Instance.SetResourceName.
func (Instance) SetResourcePath ¶
SetResourcePath is promoted from Resource.Instance.SetResourcePath.
func (Instance) SetResourceSceneUniqueId ¶
SetResourceSceneUniqueId is promoted from Resource.Instance.SetResourceSceneUniqueId.
func (Instance) SetStream ¶
func (self Instance) SetStream(index int, stream AudioStream.Instance) Instance
func (Instance) SetStreamProbabilityWeight ¶
func (Instance) SetStreamsCount ¶
SetStreamsCount sets the property returned by [GetStreamsCount]. Returns the instance, so that property settings can be chained.
func (Instance) SetupLocalToScene ¶
func (self Instance) SetupLocalToScene()
SetupLocalToScene is promoted from Resource.Instance.SetupLocalToScene.
func (Instance) StreamsCount ¶
func (Instance) TakeOverPath ¶
TakeOverPath is promoted from Resource.Instance.TakeOverPath.
type MoreArgs ¶
type MoreArgs [1]gdclass.AudioStreamRandomizer
MoreArgs is a container for Instance functions with additional 'optional' arguments.
type PlaybackMode ¶
type PlaybackMode int64 //gd:AudioStreamRandomizer.PlaybackMode
const ( PlaybackRandomNoRepeats PlaybackMode = 0 PlaybackRandom PlaybackMode = 1 PlaybackSequential PlaybackMode = 2 )
type Singleton ¶
Singleton can be embedded in a new struct to create a Go singleton extension of the class.
It will become available as a global inside scripts and any any other Go Extension types will have any *T typed fields filled in to point at this singleton once they have been instantiated.
T must be a type that is embedding this Singleton as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.