Documentation
¶
Index ¶
- type Advanced
- type Any
- type Expanded
- type Extension
- func (o *Extension[T]) AsConfigFile() Instance
- func (o *Extension[T]) AsObject() [1]gdreference.Object
- func (o *Extension[T]) AsRefCounted() ie.RC
- func (o *Extension[T]) Clear()
- func (o *Extension[T]) EncodeToText() string
- func (o *Extension[T]) EraseSection(section string)
- func (o *Extension[T]) EraseSectionKey(section string, key string)
- func (o *Extension[T]) GetSectionKeys(section string) []string
- func (o *Extension[T]) GetSections() []string
- func (o *Extension[T]) HasSection(section string) bool
- func (o *Extension[T]) HasSectionKey(section string, key string) bool
- func (o *Extension[T]) Load(path string) error
- func (o *Extension[T]) LoadEncrypted(path string, key []byte) error
- func (o *Extension[T]) LoadEncryptedPass(path string, password string) error
- func (o *Extension[T]) Parse(data string) error
- func (o *Extension[T]) Save(path string) error
- func (o *Extension[T]) SaveEncrypted(path string, key []byte) error
- func (o *Extension[T]) SaveEncryptedPass(path string, password string) error
- func (o *Extension[T]) SetValue(section string, key string, value any) *Extension[T]
- type ID
- type Instance
- func (o Instance) AsConfigFile() Instance
- func (o Instance) AsObject() [1]gdreference.Object
- func (o Instance) AsRefCounted() ie.RC
- func (self Instance) Clear()
- func (self Instance) EncodeToText() string
- func (self Instance) EraseSection(section string)
- func (self Instance) EraseSectionKey(section string, key string)
- func (self Instance) GetSectionKeys(section string) []string
- func (self Instance) GetSections() []string
- func (self Instance) GetValue(section string, key string) any
- func (self Instance) HasSection(section string) bool
- func (self Instance) HasSectionKey(section string, key string) bool
- func (self Instance) ID() ID
- func (self Instance) Load(path string) error
- func (self Instance) LoadEncrypted(path string, key []byte) error
- func (self Instance) LoadEncryptedPass(path string, password string) error
- func (self Instance) MoreArgs() MoreArgs
- func (self Instance) Parse(data string) error
- func (self Instance) Save(path string) error
- func (self Instance) SaveEncrypted(path string, key []byte) error
- func (self Instance) SaveEncryptedPass(path string, password string) error
- func (self *Instance) SetObject(obj [1]gdreference.Object) bool
- func (self Instance) SetValue(section string, key string, value any) Instance
- func (self Instance) Virtual(name string) reflect.Value
- type MoreArgs
- type Singleton
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Advanced ¶
type Advanced = class
Advanced exposes a 1:1 low-level instance of the class, undocumented, for those who know what they are doing.
type Extension ¶
Extension can be embedded in a new struct to create a Go extension of this class.
T must be a type that is embedding this Extension as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.
func (*Extension[T]) AsConfigFile ¶
func (*Extension[T]) AsObject ¶
func (o *Extension[T]) AsObject() [1]gdreference.Object
func (*Extension[T]) AsRefCounted ¶
func (*Extension[T]) EncodeToText ¶
func (*Extension[T]) EraseSection ¶
func (*Extension[T]) EraseSectionKey ¶
func (*Extension[T]) GetSectionKeys ¶
func (*Extension[T]) GetSections ¶
func (*Extension[T]) HasSection ¶
func (*Extension[T]) HasSectionKey ¶
func (*Extension[T]) LoadEncrypted ¶
func (*Extension[T]) LoadEncryptedPass ¶
func (*Extension[T]) SaveEncrypted ¶
func (*Extension[T]) SaveEncryptedPass ¶
type ID ¶
ID is a typed object ID (reference) to an instance of this class, use it to store references to objects with unknown lifetimes, as an ID will not panic on use if the underlying object has been destroyed.
type Instance ¶
type Instance [1]gdclass.ConfigFile
Instance of the class with convieniently typed arguments and results.
var Nil Instance
Nil is a nil/null instance of the class. Equivalent to the zero value.
func (Instance) AsConfigFile ¶
func (Instance) AsObject ¶
func (o Instance) AsObject() [1]gdreference.Object
func (Instance) AsRefCounted ¶
func (Instance) EncodeToText ¶
func (Instance) EraseSection ¶
func (Instance) EraseSectionKey ¶
func (Instance) GetSectionKeys ¶
func (Instance) GetSections ¶
func (Instance) HasSection ¶
func (Instance) LoadEncryptedPass ¶
func (Instance) MoreArgs ¶
MoreArgs enables certain functions to be called with additional 'optional' arguments.
func (Instance) SaveEncryptedPass ¶
type MoreArgs ¶
type MoreArgs [1]gdclass.ConfigFile
MoreArgs is a container for Instance functions with additional 'optional' arguments.
type Singleton ¶
Singleton can be embedded in a new struct to create a Go singleton extension of the class.
It will become available as a global inside scripts and any any other Go Extension types will have any *T typed fields filled in to point at this singleton once they have been instantiated.
T must be a type that is embedding this Singleton as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.