Documentation
¶
Index ¶
- type Advanced
- type Any
- type Extension
- func (o *Extension[T]) AddMessage(atype EditorExportPlatform.ExportMessageType, category string, message string)
- func (o *Extension[T]) AsEditorExportPlatform() EditorExportPlatform.Instance
- func (o *Extension[T]) AsEditorExportPlatformAndroid() Instance
- func (o *Extension[T]) AsObject() [1]gdreference.Object
- func (o *Extension[T]) AsRefCounted() ie.RC
- func (o *Extension[T]) ClearMessages()
- func (o *Extension[T]) CreatePreset() EditorExportPreset.Instance
- func (o *Extension[T]) FindExportTemplate(template_file_name string) EditorExportPlatform.Template
- func (o *Extension[T]) GenExportFlags(flags EditorExportPlatform.DebugFlags) []string
- func (o *Extension[T]) GetCurrentPresets() []EditorExportPreset.Instance
- func (o *Extension[T]) GetInternalExportFiles(preset EditorExportPreset.Instance, debug bool) map[string][]uint8
- func (o *Extension[T]) GetMessageCategory(index int) string
- func (o *Extension[T]) GetMessageCount() int
- func (o *Extension[T]) GetMessageText(index int) string
- func (o *Extension[T]) GetMessageType(index int) EditorExportPlatform.ExportMessageType
- func (o *Extension[T]) GetOsName() string
- func (o *Extension[T]) GetWorstMessageType() EditorExportPlatform.ExportMessageType
- func (o *Extension[T]) SavePackPatch(preset EditorExportPreset.Instance, debug bool, path string) EditorExportPlatform.Report
- func (o *Extension[T]) SaveZip(preset EditorExportPreset.Instance, debug bool, path string) EditorExportPlatform.Report
- func (o *Extension[T]) SaveZipPatch(preset EditorExportPreset.Instance, debug bool, path string) EditorExportPlatform.Report
- func (o *Extension[T]) SshPushToRemote(host string, port string, scp_args []string, src_file string, dst_file string) error
- type File
- type ID
- type Instance
- func (self Instance) AddMessage(atype EditorExportPlatform.ExportMessageType, category string, message string)
- func (o Instance) AsEditorExportPlatform() EditorExportPlatform.Instance
- func (o Instance) AsEditorExportPlatformAndroid() Instance
- func (o Instance) AsObject() [1]gdreference.Object
- func (o Instance) AsRefCounted() ie.RC
- func (self Instance) ClearMessages()
- func (self Instance) CreatePreset() EditorExportPreset.Instance
- func (self Instance) FindExportTemplate(template_file_name string) EditorExportPlatform.Template
- func (self Instance) GenExportFlags(flags EditorExportPlatform.DebugFlags) []string
- func (self Instance) GetCurrentPresets() []EditorExportPreset.Instance
- func (self Instance) GetInternalExportFiles(preset EditorExportPreset.Instance, debug bool) map[string][]uint8
- func (self Instance) GetMessageCategory(index int) string
- func (self Instance) GetMessageCount() int
- func (self Instance) GetMessageText(index int) string
- func (self Instance) GetMessageType(index int) EditorExportPlatform.ExportMessageType
- func (self Instance) GetOsName() string
- func (self Instance) GetWorstMessageType() EditorExportPlatform.ExportMessageType
- func (self Instance) ID() ID
- func (self Instance) SavePackPatch(preset EditorExportPreset.Instance, debug bool, path string) EditorExportPlatform.Report
- func (self Instance) SaveZip(preset EditorExportPreset.Instance, debug bool, path string) EditorExportPlatform.Report
- func (self Instance) SaveZipPatch(preset EditorExportPreset.Instance, debug bool, path string) EditorExportPlatform.Report
- func (self *Instance) SetObject(obj [1]gdreference.Object) bool
- func (self Instance) SshPushToRemote(host string, port string, scp_args []string, src_file string, dst_file string) error
- func (self Instance) Virtual(name string) reflect.Value
- type Report
- type Singleton
- type Template
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Advanced ¶
type Advanced = class
Advanced exposes a 1:1 low-level instance of the class, undocumented, for those who know what they are doing.
type Extension ¶
Extension can be embedded in a new struct to create a Go extension of this class.
T must be a type that is embedding this Extension as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.
func (*Extension[T]) AddMessage ¶
func (o *Extension[T]) AddMessage(atype EditorExportPlatform.ExportMessageType, category string, message string)
AddMessage is promoted from EditorExportPlatform.Instance.AddMessage.
func (*Extension[T]) AsEditorExportPlatform ¶
func (o *Extension[T]) AsEditorExportPlatform() EditorExportPlatform.Instance
func (*Extension[T]) AsEditorExportPlatformAndroid ¶
func (*Extension[T]) AsObject ¶
func (o *Extension[T]) AsObject() [1]gdreference.Object
func (*Extension[T]) AsRefCounted ¶
func (*Extension[T]) ClearMessages ¶
func (o *Extension[T]) ClearMessages()
ClearMessages is promoted from EditorExportPlatform.Instance.ClearMessages.
func (*Extension[T]) CreatePreset ¶
func (o *Extension[T]) CreatePreset() EditorExportPreset.Instance
CreatePreset is promoted from EditorExportPlatform.Instance.CreatePreset.
func (*Extension[T]) FindExportTemplate ¶
func (o *Extension[T]) FindExportTemplate(template_file_name string) EditorExportPlatform.Template
FindExportTemplate is promoted from EditorExportPlatform.Instance.FindExportTemplate.
func (*Extension[T]) GenExportFlags ¶
func (o *Extension[T]) GenExportFlags(flags EditorExportPlatform.DebugFlags) []string
GenExportFlags is promoted from EditorExportPlatform.Instance.GenExportFlags.
func (*Extension[T]) GetCurrentPresets ¶
func (o *Extension[T]) GetCurrentPresets() []EditorExportPreset.Instance
GetCurrentPresets is promoted from EditorExportPlatform.Instance.GetCurrentPresets.
func (*Extension[T]) GetInternalExportFiles ¶
func (o *Extension[T]) GetInternalExportFiles(preset EditorExportPreset.Instance, debug bool) map[string][]uint8
GetInternalExportFiles is promoted from EditorExportPlatform.Instance.GetInternalExportFiles.
func (*Extension[T]) GetMessageCategory ¶
GetMessageCategory is promoted from EditorExportPlatform.Instance.GetMessageCategory.
func (*Extension[T]) GetMessageCount ¶
GetMessageCount is promoted from EditorExportPlatform.Instance.GetMessageCount.
func (*Extension[T]) GetMessageText ¶
GetMessageText is promoted from EditorExportPlatform.Instance.GetMessageText.
func (*Extension[T]) GetMessageType ¶
func (o *Extension[T]) GetMessageType(index int) EditorExportPlatform.ExportMessageType
GetMessageType is promoted from EditorExportPlatform.Instance.GetMessageType.
func (*Extension[T]) GetOsName ¶
GetOsName is promoted from EditorExportPlatform.Instance.GetOsName.
func (*Extension[T]) GetWorstMessageType ¶
func (o *Extension[T]) GetWorstMessageType() EditorExportPlatform.ExportMessageType
GetWorstMessageType is promoted from EditorExportPlatform.Instance.GetWorstMessageType.
func (*Extension[T]) SavePackPatch ¶
func (o *Extension[T]) SavePackPatch(preset EditorExportPreset.Instance, debug bool, path string) EditorExportPlatform.Report
SavePackPatch is promoted from EditorExportPlatform.Instance.SavePackPatch.
func (*Extension[T]) SaveZip ¶
func (o *Extension[T]) SaveZip(preset EditorExportPreset.Instance, debug bool, path string) EditorExportPlatform.Report
SaveZip is promoted from EditorExportPlatform.Instance.SaveZip.
func (*Extension[T]) SaveZipPatch ¶
func (o *Extension[T]) SaveZipPatch(preset EditorExportPreset.Instance, debug bool, path string) EditorExportPlatform.Report
SaveZipPatch is promoted from EditorExportPlatform.Instance.SaveZipPatch.
func (*Extension[T]) SshPushToRemote ¶
func (o *Extension[T]) SshPushToRemote(host string, port string, scp_args []string, src_file string, dst_file string) error
SshPushToRemote is promoted from EditorExportPlatform.Instance.SshPushToRemote.
type ID ¶
ID is a typed object ID (reference) to an instance of this class, use it to store references to objects with unknown lifetimes, as an ID will not panic on use if the underlying object has been destroyed.
type Instance ¶
type Instance [1]gdclass.EditorExportPlatformAndroid
Instance of the class with convieniently typed arguments and results.
var Nil Instance
Nil is a nil/null instance of the class. Equivalent to the zero value.
func (Instance) AddMessage ¶
func (self Instance) AddMessage(atype EditorExportPlatform.ExportMessageType, category string, message string)
AddMessage is promoted from EditorExportPlatform.Instance.AddMessage.
func (Instance) AsEditorExportPlatform ¶
func (o Instance) AsEditorExportPlatform() EditorExportPlatform.Instance
func (Instance) AsEditorExportPlatformAndroid ¶
func (Instance) AsObject ¶
func (o Instance) AsObject() [1]gdreference.Object
func (Instance) AsRefCounted ¶
func (Instance) ClearMessages ¶
func (self Instance) ClearMessages()
ClearMessages is promoted from EditorExportPlatform.Instance.ClearMessages.
func (Instance) CreatePreset ¶
func (self Instance) CreatePreset() EditorExportPreset.Instance
CreatePreset is promoted from EditorExportPlatform.Instance.CreatePreset.
func (Instance) FindExportTemplate ¶
func (self Instance) FindExportTemplate(template_file_name string) EditorExportPlatform.Template
FindExportTemplate is promoted from EditorExportPlatform.Instance.FindExportTemplate.
func (Instance) GenExportFlags ¶
func (self Instance) GenExportFlags(flags EditorExportPlatform.DebugFlags) []string
GenExportFlags is promoted from EditorExportPlatform.Instance.GenExportFlags.
func (Instance) GetCurrentPresets ¶
func (self Instance) GetCurrentPresets() []EditorExportPreset.Instance
GetCurrentPresets is promoted from EditorExportPlatform.Instance.GetCurrentPresets.
func (Instance) GetInternalExportFiles ¶
func (self Instance) GetInternalExportFiles(preset EditorExportPreset.Instance, debug bool) map[string][]uint8
GetInternalExportFiles is promoted from EditorExportPlatform.Instance.GetInternalExportFiles.
func (Instance) GetMessageCategory ¶
GetMessageCategory is promoted from EditorExportPlatform.Instance.GetMessageCategory.
func (Instance) GetMessageCount ¶
GetMessageCount is promoted from EditorExportPlatform.Instance.GetMessageCount.
func (Instance) GetMessageText ¶
GetMessageText is promoted from EditorExportPlatform.Instance.GetMessageText.
func (Instance) GetMessageType ¶
func (self Instance) GetMessageType(index int) EditorExportPlatform.ExportMessageType
GetMessageType is promoted from EditorExportPlatform.Instance.GetMessageType.
func (Instance) GetOsName ¶
GetOsName is promoted from EditorExportPlatform.Instance.GetOsName.
func (Instance) GetWorstMessageType ¶
func (self Instance) GetWorstMessageType() EditorExportPlatform.ExportMessageType
GetWorstMessageType is promoted from EditorExportPlatform.Instance.GetWorstMessageType.
func (Instance) SavePackPatch ¶
func (self Instance) SavePackPatch(preset EditorExportPreset.Instance, debug bool, path string) EditorExportPlatform.Report
SavePackPatch is promoted from EditorExportPlatform.Instance.SavePackPatch.
func (Instance) SaveZip ¶
func (self Instance) SaveZip(preset EditorExportPreset.Instance, debug bool, path string) EditorExportPlatform.Report
SaveZip is promoted from EditorExportPlatform.Instance.SaveZip.
func (Instance) SaveZipPatch ¶
func (self Instance) SaveZipPatch(preset EditorExportPreset.Instance, debug bool, path string) EditorExportPlatform.Report
SaveZipPatch is promoted from EditorExportPlatform.Instance.SaveZipPatch.
func (Instance) SshPushToRemote ¶
func (self Instance) SshPushToRemote(host string, port string, scp_args []string, src_file string, dst_file string) error
SshPushToRemote is promoted from EditorExportPlatform.Instance.SshPushToRemote.
type Singleton ¶
Singleton can be embedded in a new struct to create a Go singleton extension of the class.
It will become available as a global inside scripts and any any other Go Extension types will have any *T typed fields filled in to point at this singleton once they have been instantiated.
T must be a type that is embedding this Singleton as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.