Documentation
¶
Index ¶
- func AddRootNode(node Node.Instance)
- func Advanced() class
- func CloseScene() error
- func DistractionFreeMode() bool
- func EditNode(node Node.Instance)
- func EditResource(resource Resource.Instance)
- func EditScript(script Script.Instance, column int)
- func EditScriptOptions(script Script.Instance, line int, column int, grab_focus bool)
- func GetBaseControl() Control.Instance
- func GetCommandPalette() EditorCommandPalette.Instance
- func GetCurrentDirectory() string
- func GetCurrentFeatureProfile() string
- func GetCurrentPath() string
- func GetEditedSceneRoot() Node.Instance
- func GetEditorLanguage() string
- func GetEditorMainScreen() VBoxContainer.Instance
- func GetEditorPaths() EditorPaths.Instance
- func GetEditorScale() Float.X
- func GetEditorSettings() EditorSettings.Instance
- func GetEditorTheme() Theme.Instance
- func GetEditorToaster() EditorToaster.Instance
- func GetEditorUndoRedo() EditorUndoRedoManager.Instance
- func GetEditorViewport2d() SubViewport.Instance
- func GetEditorViewport3d(idx int) SubViewport.Instance
- func GetFileSystemDock() FileSystemDock.Instance
- func GetInspector() EditorInspector.Instance
- func GetNode3dRotateSnap() Float.X
- func GetNode3dScaleSnap() Float.X
- func GetNode3dTranslateSnap() Float.X
- func GetOpenSceneRoots() []Node.Instance
- func GetOpenScenes() []string
- func GetPlayingScene() string
- func GetResourceFilesystem() EditorFileSystem.Instance
- func GetResourcePreviewer() EditorResourcePreview.Instance
- func GetScriptEditor() ScriptEditor.Instance
- func GetSelectedPaths() []string
- func GetSelection() EditorSelection.Instance
- func InspectObject(obj Object.Instance, for_property string, inspector_only bool)
- func IsMultiWindowEnabled() bool
- func IsNode3dSnapEnabled() bool
- func IsObjectEdited(obj Object.Instance) bool
- func IsPlayingScene() bool
- func IsPluginEnabled(plugin string) bool
- func MakeMeshPreviews(meshes []Mesh.Instance, preview_size int) []Texture2D.Instance
- func MarkSceneAsUnsaved()
- func MovieMakerEnabled() bool
- func OpenSceneFromPath(scene_filepath string, set_inherited bool)
- func PlayCurrentScene()
- func PlayCustomScene(scene_filepath string)
- func PlayMainScene()
- func PopupCreateDialog(callback func(selected string), base_type string, current_type string, ...)
- func PopupDialog(dialog Window.Instance, rect Rect2i.PositionSize)
- func PopupDialogCentered(dialog Window.Instance, minsize Vector2i.XY)
- func PopupDialogCenteredClamped(dialog Window.Instance, minsize Vector2i.XY)
- func PopupDialogCenteredClampedOptions(dialog Window.Instance, minsize Vector2i.XY, fallback_ratio Float.X)
- func PopupDialogCenteredRatio(dialog Window.Instance)
- func PopupDialogCenteredRatioOptions(dialog Window.Instance, ratio Float.X)
- func PopupMethodSelector(obj Object.Instance, callback func(selected string), current_value string)
- func PopupNodeSelector(callback func(selected string), valid_types []string, ...)
- func PopupPropertySelector(obj Object.Instance, callback func(selected string), type_filter []int32, ...)
- func PopupQuickOpen(callback func(selected string), base_types []string)
- func ReloadSceneFromPath(scene_filepath string)
- func RestartEditor()
- func RestartEditorOptions(save bool)
- func SaveAllScenes()
- func SaveScene() error
- func SaveSceneAs(path string)
- func SaveSceneAsOptions(path string, with_preview bool)
- func SelectFile(file string)
- func SetCurrentFeatureProfile(profile_name string)
- func SetDistractionFreeMode(value bool)
- func SetMainScreenEditor(name string)
- func SetMovieMakerEnabled(value bool)
- func SetObjectEdited(obj Object.Instance, edited bool)
- func SetPluginEnabled(plugin string, enabled bool)
- func StopPlayingScene()
- type Extension
- type ID
- type Instance
- type Singleton
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AddRootNode ¶
func Advanced ¶
func Advanced() class
Advanced exposes a 1:1 low-level instance of the class, undocumented, for those who know what they are doing.
func CloseScene ¶
func CloseScene() error
func DistractionFreeMode ¶
func DistractionFreeMode() bool
func EditResource ¶
func EditScript ¶
func EditScriptOptions ¶
func GetBaseControl ¶
func GetCommandPalette ¶
func GetCommandPalette() EditorCommandPalette.Instance
func GetCurrentDirectory ¶
func GetCurrentDirectory() string
func GetCurrentFeatureProfile ¶
func GetCurrentFeatureProfile() string
func GetCurrentPath ¶
func GetCurrentPath() string
func GetEditedSceneRoot ¶
func GetEditorLanguage ¶
func GetEditorLanguage() string
func GetEditorMainScreen ¶
func GetEditorMainScreen() VBoxContainer.Instance
func GetEditorPaths ¶
func GetEditorPaths() EditorPaths.Instance
func GetEditorScale ¶
func GetEditorSettings ¶
func GetEditorSettings() EditorSettings.Instance
func GetEditorTheme ¶
func GetEditorToaster ¶
func GetEditorToaster() EditorToaster.Instance
func GetEditorUndoRedo ¶
func GetEditorUndoRedo() EditorUndoRedoManager.Instance
func GetEditorViewport2d ¶
func GetEditorViewport2d() SubViewport.Instance
func GetEditorViewport3d ¶
func GetEditorViewport3d(idx int) SubViewport.Instance
func GetFileSystemDock ¶
func GetFileSystemDock() FileSystemDock.Instance
func GetInspector ¶
func GetInspector() EditorInspector.Instance
func GetNode3dRotateSnap ¶
func GetNode3dScaleSnap ¶
func GetNode3dTranslateSnap ¶
func GetOpenSceneRoots ¶
func GetOpenScenes ¶
func GetOpenScenes() []string
func GetPlayingScene ¶
func GetPlayingScene() string
func GetResourceFilesystem ¶
func GetResourceFilesystem() EditorFileSystem.Instance
func GetResourcePreviewer ¶
func GetResourcePreviewer() EditorResourcePreview.Instance
func GetScriptEditor ¶
func GetScriptEditor() ScriptEditor.Instance
func GetSelectedPaths ¶
func GetSelectedPaths() []string
func GetSelection ¶
func GetSelection() EditorSelection.Instance
func InspectObject ¶
func IsMultiWindowEnabled ¶
func IsMultiWindowEnabled() bool
func IsNode3dSnapEnabled ¶
func IsNode3dSnapEnabled() bool
func IsObjectEdited ¶
func IsPlayingScene ¶
func IsPlayingScene() bool
func IsPluginEnabled ¶
func MakeMeshPreviews ¶
func MarkSceneAsUnsaved ¶
func MarkSceneAsUnsaved()
func MovieMakerEnabled ¶
func MovieMakerEnabled() bool
func OpenSceneFromPath ¶
func PlayCurrentScene ¶
func PlayCurrentScene()
func PlayCustomScene ¶
func PlayCustomScene(scene_filepath string)
func PlayMainScene ¶
func PlayMainScene()
func PopupCreateDialog ¶
func PopupDialog ¶
func PopupDialog(dialog Window.Instance, rect Rect2i.PositionSize)
func PopupMethodSelector ¶
func PopupNodeSelector ¶
func PopupPropertySelector ¶
func PopupQuickOpen ¶
func ReloadSceneFromPath ¶
func ReloadSceneFromPath(scene_filepath string)
func RestartEditor ¶
func RestartEditor()
func RestartEditorOptions ¶
func RestartEditorOptions(save bool)
func SaveAllScenes ¶
func SaveAllScenes()
func SaveSceneAs ¶
func SaveSceneAs(path string)
func SaveSceneAsOptions ¶
func SelectFile ¶
func SelectFile(file string)
func SetCurrentFeatureProfile ¶
func SetCurrentFeatureProfile(profile_name string)
func SetDistractionFreeMode ¶
func SetDistractionFreeMode(value bool)
SetDistractionFreeMode sets the property returned by [IsDistractionFreeModeEnabled].
func SetMainScreenEditor ¶
func SetMainScreenEditor(name string)
func SetMovieMakerEnabled ¶
func SetMovieMakerEnabled(value bool)
SetMovieMakerEnabled sets the property returned by [IsMovieMakerEnabled].
func SetObjectEdited ¶
func SetPluginEnabled ¶
func StopPlayingScene ¶
func StopPlayingScene()
Types ¶
type Extension ¶
Extension can be embedded in a new struct to create a Go extension of this class.
T must be a type that is embedding this Extension as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.
func (*Extension[T]) AsObject ¶
func (o *Extension[T]) AsObject() [1]gdreference.Object
type ID ¶
ID is a typed object ID (reference) to an instance of this class, use it to store references to objects with unknown lifetimes, as an ID will not panic on use if the underlying object has been destroyed.
type Instance ¶
type Instance [1]gdclass.EditorInterface
Instance of the class with convieniently typed arguments and results.
func (Instance) AsObject ¶
func (o Instance) AsObject() [1]gdreference.Object
type Singleton ¶
Singleton can be embedded in a new struct to create a Go singleton extension of the class.
It will become available as a global inside scripts and any any other Go Extension types will have any *T typed fields filled in to point at this singleton once they have been instantiated.
T must be a type that is embedding this Singleton as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.