Documentation
¶
Index ¶
- type Advanced
- type Any
- type Expanded
- type Extension
- type ID
- type Implementation
- type Instance
- func (self Instance) AddImportOption(name string, value any)
- func (self Instance) AddImportOptionAdvanced(atype variant.Type, name string, default_value any)
- func (o Instance) AsEditorScenePostImportPlugin() Instance
- func (o Instance) AsObject() [1]gdreference.Object
- func (o Instance) AsRefCounted() ie.RC
- func (self Instance) GetOptionValue(name string) any
- func (self Instance) ID() ID
- func (self Instance) MoreArgs() MoreArgs
- func (self *Instance) SetObject(obj [1]gdreference.Object) bool
- func (self Instance) Virtual(name string) reflect.Value
- type Interface
- type InternalImportCategory
- type MoreArgs
- type Singleton
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Advanced ¶
type Advanced = class
Advanced exposes a 1:1 low-level instance of the class, undocumented, for those who know what they are doing.
type Extension ¶
Extension can be embedded in a new struct to create a Go extension of this class.
T must be a type that is embedding this Extension as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way. See Interface for methods that can be overridden by T.
func (*Extension[T]) AddImportOption ¶
func (*Extension[T]) AsEditorScenePostImportPlugin ¶
func (*Extension[T]) AsObject ¶
func (o *Extension[T]) AsObject() [1]gdreference.Object
func (*Extension[T]) AsRefCounted ¶
func (*Extension[T]) GetOptionValue ¶
type ID ¶
ID is a typed object ID (reference) to an instance of this class, use it to store references to objects with unknown lifetimes, as an ID will not panic on use if the underlying object has been destroyed.
type Implementation ¶
type Implementation = implementation
Implementation implements Interface with empty methods.
type Instance ¶
type Instance [1]gdclass.EditorScenePostImportPlugin
Instance of the class with convieniently typed arguments and results.
var Nil Instance
Nil is a nil/null instance of the class. Equivalent to the zero value.
func (Instance) AddImportOption ¶
func (Instance) AddImportOptionAdvanced ¶
func (Instance) AsEditorScenePostImportPlugin ¶
func (Instance) AsObject ¶
func (o Instance) AsObject() [1]gdreference.Object
func (Instance) AsRefCounted ¶
func (Instance) GetOptionValue ¶
type Interface ¶
type Interface interface {
GetInternalImportOptions(category int)
GetInternalOptionVisibility(category int, for_animation bool, option string) any
GetInternalOptionUpdateViewRequired(category int, option string) any
InternalProcess(category int, base_node Node.Instance, node Node.Instance, resource Resource.Instance)
GetImportOptions(path string)
GetOptionVisibility(path string, for_animation bool, option string) any
PreProcess(scene Node.Instance)
PostProcess(scene Node.Instance)
}
type InternalImportCategory ¶
type InternalImportCategory int64 //gd:EditorScenePostImportPlugin.InternalImportCategory
const ( InternalImportCategoryNode InternalImportCategory = 0 InternalImportCategoryMesh3dNode InternalImportCategory = 1 InternalImportCategoryMesh InternalImportCategory = 2 InternalImportCategoryMaterial InternalImportCategory = 3 InternalImportCategoryAnimation InternalImportCategory = 4 InternalImportCategoryAnimationNode InternalImportCategory = 5 InternalImportCategorySkeleton3dNode InternalImportCategory = 6 InternalImportCategoryMax InternalImportCategory = 7 )
type MoreArgs ¶
type MoreArgs [1]gdclass.EditorScenePostImportPlugin
MoreArgs is a container for Instance functions with additional 'optional' arguments.
type Singleton ¶
Singleton can be embedded in a new struct to create a Go singleton extension of the class.
It will become available as a global inside scripts and any any other Go Extension types will have any *T typed fields filled in to point at this singleton once they have been instantiated.
T must be a type that is embedding this Singleton as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way. See Interface for methods that can be overridden by T.