Documentation
¶
Index ¶
- type Advanced
- type Any
- type Extension
- func (o *Extension[T]) AllowSystemFallback() bool
- func (o *Extension[T]) Antialiasing() TextServer.FontAntialiasing
- func (o *Extension[T]) AsFont() Font.Instance
- func (o *Extension[T]) AsFontFile() Instance
- func (o *Extension[T]) AsObject() [1]gdreference.Object
- func (o *Extension[T]) AsRefCounted() ie.RC
- func (o *Extension[T]) AsResource() Resource.Instance
- func (o *Extension[T]) ClearCache()
- func (o *Extension[T]) ClearGlyphs(cache_index int, size Vector2i.XY)
- func (o *Extension[T]) ClearKerningMap(cache_index int, size int)
- func (o *Extension[T]) ClearSizeCache(cache_index int)
- func (o *Extension[T]) ClearTextures(cache_index int, size Vector2i.XY)
- func (o *Extension[T]) Data() []byte
- func (o *Extension[T]) DisableEmbeddedBitmaps() bool
- func (o *Extension[T]) EmitChanged()
- func (o *Extension[T]) Fallbacks() []Font.Instance
- func (o *Extension[T]) FixedSize() int
- func (o *Extension[T]) FixedSizeScaleMode() TextServer.FixedSizeScaleMode
- func (o *Extension[T]) ForceAutohinter() bool
- func (o *Extension[T]) GenerateMipmaps() bool
- func (o *Extension[T]) GetCacheAscent(cache_index int, size int) Float.X
- func (o *Extension[T]) GetCacheCount() int
- func (o *Extension[T]) GetCacheDescent(cache_index int, size int) Float.X
- func (o *Extension[T]) GetCacheScale(cache_index int, size int) Float.X
- func (o *Extension[T]) GetCacheUnderlinePosition(cache_index int, size int) Float.X
- func (o *Extension[T]) GetCacheUnderlineThickness(cache_index int, size int) Float.X
- func (o *Extension[T]) GetCharFromGlyphIndex(size int, glyph_index int) int
- func (o *Extension[T]) GetCharSize(char int, font_size int) Vector2.XY
- func (o *Extension[T]) GetEmbolden(cache_index int) Float.X
- func (o *Extension[T]) GetExtraBaselineOffset(cache_index int) Float.X
- func (o *Extension[T]) GetExtraSpacing(cache_index int, spacing TextServer.SpacingType) int
- func (o *Extension[T]) GetFaceCount() int
- func (o *Extension[T]) GetFaceIndex(cache_index int) int
- func (o *Extension[T]) GetFontName() string
- func (o *Extension[T]) GetFontStretch() int
- func (o *Extension[T]) GetFontStyle() TextServer.FontStyle
- func (o *Extension[T]) GetFontStyleName() string
- func (o *Extension[T]) GetFontWeight() int
- func (o *Extension[T]) GetGlyphAdvance(cache_index int, size int, glyph int) Vector2.XY
- func (o *Extension[T]) GetGlyphIndex(size int, char int, variation_selector int) int
- func (o *Extension[T]) GetGlyphList(cache_index int, size Vector2i.XY) []int32
- func (o *Extension[T]) GetGlyphOffset(cache_index int, size Vector2i.XY, glyph int) Vector2.XY
- func (o *Extension[T]) GetGlyphSize(cache_index int, size Vector2i.XY, glyph int) Vector2.XY
- func (o *Extension[T]) GetGlyphTextureIdx(cache_index int, size Vector2i.XY, glyph int) int
- func (o *Extension[T]) GetGlyphUvRect(cache_index int, size Vector2i.XY, glyph int) Rect2.PositionSize
- func (o *Extension[T]) GetIdForPath(path string) string
- func (o *Extension[T]) GetKerning(cache_index int, size int, glyph_pair Vector2i.XY) Vector2.XY
- func (o *Extension[T]) GetKerningList(cache_index int, size int) []Vector2i.XY
- func (o *Extension[T]) GetLanguageSupportOverride(language string) bool
- func (o *Extension[T]) GetLanguageSupportOverrides() []string
- func (o *Extension[T]) GetOpentypeFeatures() map[string][2]string
- func (o *Extension[T]) GetOtNameStrings() map[string]map[string]string
- func (o *Extension[T]) GetRid() Resource.ID
- func (o *Extension[T]) GetRids() []RID.Font
- func (o *Extension[T]) GetScriptSupportOverride(script string) bool
- func (o *Extension[T]) GetScriptSupportOverrides() []string
- func (o *Extension[T]) GetSizeCacheList(cache_index int) []Vector2i.XY
- func (o *Extension[T]) GetSpacing(spacing TextServer.SpacingType) int
- func (o *Extension[T]) GetSupportedChars() string
- func (o *Extension[T]) GetSupportedFeatureList() map[string]Font.OpenTypeFeature
- func (o *Extension[T]) GetSupportedVariationList() map[int]struct{ ... }
- func (o *Extension[T]) GetTextureCount(cache_index int, size Vector2i.XY) int
- func (o *Extension[T]) GetTextureImage(cache_index int, size Vector2i.XY, texture_index int) Image.Instance
- func (o *Extension[T]) GetTextureOffsets(cache_index int, size Vector2i.XY, texture_index int) []int32
- func (o *Extension[T]) GetTransform(cache_index int) Transform2D.OriginXY
- func (o *Extension[T]) GetVariationCoordinates(cache_index int) map[string]float32
- func (o *Extension[T]) HasChar(char int) bool
- func (o *Extension[T]) Hinting() TextServer.Hinting
- func (o *Extension[T]) IsBuiltIn() bool
- func (o *Extension[T]) IsLanguageSupported(language string) bool
- func (o *Extension[T]) IsScriptSupported(script string) bool
- func (o *Extension[T]) KeepRoundingRemainders() bool
- func (o *Extension[T]) LoadBitmapFont(path string) error
- func (o *Extension[T]) LoadDynamicFont(path string) error
- func (o *Extension[T]) ModulateColorGlyphs() bool
- func (o *Extension[T]) MsdfPixelRange() int
- func (o *Extension[T]) MsdfSize() int
- func (o *Extension[T]) MultichannelSignedDistanceField() bool
- func (o *Extension[T]) OnChanged(cb func(), flags ...Signal.Flags) *Extension[T]
- func (o *Extension[T]) OnSetupLocalToSceneRequested(cb func(), flags ...Signal.Flags) *Extension[T]
- func (o *Extension[T]) OpentypeFeatureOverrides() map[any]any
- func (o *Extension[T]) Oversampling() Float.X
- func (o *Extension[T]) RemoveCache(cache_index int)
- func (o *Extension[T]) RemoveGlyph(cache_index int, size Vector2i.XY, glyph int)
- func (o *Extension[T]) RemoveKerning(cache_index int, size int, glyph_pair Vector2i.XY)
- func (o *Extension[T]) RemoveLanguageSupportOverride(language string)
- func (o *Extension[T]) RemoveScriptSupportOverride(script string)
- func (o *Extension[T]) RemoveSizeCache(cache_index int, size Vector2i.XY)
- func (o *Extension[T]) RemoveTexture(cache_index int, size Vector2i.XY, texture_index int)
- func (o *Extension[T]) RenderGlyph(cache_index int, size Vector2i.XY, index int)
- func (o *Extension[T]) RenderRange(cache_index int, size Vector2i.XY, start int, end int)
- func (o *Extension[T]) ResetState()
- func (o *Extension[T]) ResourceLocalToScene() bool
- func (o *Extension[T]) ResourceName() string
- func (o *Extension[T]) ResourcePath() string
- func (o *Extension[T]) ResourceSceneUniqueId() string
- func (o *Extension[T]) SetAllowSystemFallback(value bool) *Extension[T]
- func (o *Extension[T]) SetAntialiasing(value TextServer.FontAntialiasing) *Extension[T]
- func (o *Extension[T]) SetCacheAscent(cache_index int, size int, ascent Float.X) *Extension[T]
- func (o *Extension[T]) SetCacheCapacity(single_line int, multi_line int) *Extension[T]
- func (o *Extension[T]) SetCacheDescent(cache_index int, size int, descent Float.X) *Extension[T]
- func (o *Extension[T]) SetCacheScale(cache_index int, size int, scale Float.X) *Extension[T]
- func (o *Extension[T]) SetCacheUnderlinePosition(cache_index int, size int, underline_position Float.X) *Extension[T]
- func (o *Extension[T]) SetCacheUnderlineThickness(cache_index int, size int, underline_thickness Float.X) *Extension[T]
- func (o *Extension[T]) SetData(value []byte) *Extension[T]
- func (o *Extension[T]) SetDisableEmbeddedBitmaps(value bool) *Extension[T]
- func (o *Extension[T]) SetEmbolden(cache_index int, strength Float.X) *Extension[T]
- func (o *Extension[T]) SetExtraBaselineOffset(cache_index int, baseline_offset Float.X) *Extension[T]
- func (o *Extension[T]) SetExtraSpacing(cache_index int, spacing TextServer.SpacingType, value int) *Extension[T]
- func (o *Extension[T]) SetFaceIndex(cache_index int, face_index int) *Extension[T]
- func (o *Extension[T]) SetFallbacks(value []Font.Instance) *Extension[T]
- func (o *Extension[T]) SetFixedSize(value int) *Extension[T]
- func (o *Extension[T]) SetFixedSizeScaleMode(value TextServer.FixedSizeScaleMode) *Extension[T]
- func (o *Extension[T]) SetFontName(value string) *Extension[T]
- func (o *Extension[T]) SetFontStretch(value int) *Extension[T]
- func (o *Extension[T]) SetFontStyle(value TextServer.FontStyle) *Extension[T]
- func (o *Extension[T]) SetFontWeight(value int) *Extension[T]
- func (o *Extension[T]) SetForceAutohinter(value bool) *Extension[T]
- func (o *Extension[T]) SetGenerateMipmaps(value bool) *Extension[T]
- func (o *Extension[T]) SetGlyphAdvance(cache_index int, size int, glyph int, advance Vector2.XY) *Extension[T]
- func (o *Extension[T]) SetGlyphOffset(cache_index int, size Vector2i.XY, glyph int, offset Vector2.XY) *Extension[T]
- func (o *Extension[T]) SetGlyphSize(cache_index int, size Vector2i.XY, glyph int, gl_size Vector2.XY) *Extension[T]
- func (o *Extension[T]) SetGlyphTextureIdx(cache_index int, size Vector2i.XY, glyph int, texture_idx int) *Extension[T]
- func (o *Extension[T]) SetGlyphUvRect(cache_index int, size Vector2i.XY, glyph int, uv_rect Rect2.PositionSize) *Extension[T]
- func (o *Extension[T]) SetHinting(value TextServer.Hinting) *Extension[T]
- func (o *Extension[T]) SetIdForPath(path string, id string) *Extension[T]
- func (o *Extension[T]) SetKeepRoundingRemainders(value bool) *Extension[T]
- func (o *Extension[T]) SetKerning(cache_index int, size int, glyph_pair Vector2i.XY, kerning Vector2.XY) *Extension[T]
- func (o *Extension[T]) SetLanguageSupportOverride(language string, supported bool) *Extension[T]
- func (o *Extension[T]) SetModulateColorGlyphs(value bool) *Extension[T]
- func (o *Extension[T]) SetMsdfPixelRange(value int) *Extension[T]
- func (o *Extension[T]) SetMsdfSize(value int) *Extension[T]
- func (o *Extension[T]) SetMultichannelSignedDistanceField(value bool) *Extension[T]
- func (o *Extension[T]) SetOpentypeFeatureOverrides(value map[any]any) *Extension[T]
- func (o *Extension[T]) SetOversampling(value Float.X) *Extension[T]
- func (o *Extension[T]) SetPathCache(path string) *Extension[T]
- func (o *Extension[T]) SetResourceLocalToScene(value bool) *Extension[T]
- func (o *Extension[T]) SetResourceName(value string) *Extension[T]
- func (o *Extension[T]) SetResourcePath(value string) *Extension[T]
- func (o *Extension[T]) SetResourceSceneUniqueId(value string) *Extension[T]
- func (o *Extension[T]) SetScriptSupportOverride(script string, supported bool) *Extension[T]
- func (o *Extension[T]) SetStyleName(value string) *Extension[T]
- func (o *Extension[T]) SetSubpixelPositioning(value TextServer.SubpixelPositioning) *Extension[T]
- func (o *Extension[T]) SetTextureImage(cache_index int, size Vector2i.XY, texture_index int, image Image.Instance) *Extension[T]
- func (o *Extension[T]) SetTextureOffsets(cache_index int, size Vector2i.XY, texture_index int, offset []int32) *Extension[T]
- func (o *Extension[T]) SetTransform(cache_index int, transform Transform2D.OriginXY) *Extension[T]
- func (o *Extension[T]) SetVariationCoordinates(cache_index int, variation_coordinates map[string]float32) *Extension[T]
- func (o *Extension[T]) SetupLocalToScene()
- func (o *Extension[T]) SubpixelPositioning() TextServer.SubpixelPositioning
- func (o *Extension[T]) TakeOverPath(path string)
- type ID
- type Instance
- func (self Instance) AllowSystemFallback() bool
- func (self Instance) Antialiasing() TextServer.FontAntialiasing
- func (o Instance) AsFont() Font.Instance
- func (o Instance) AsFontFile() Instance
- func (o Instance) AsObject() [1]gdreference.Object
- func (o Instance) AsRefCounted() ie.RC
- func (o Instance) AsResource() Resource.Instance
- func (self Instance) ClearCache()
- func (self Instance) ClearGlyphs(cache_index int, size Vector2i.XY)
- func (self Instance) ClearKerningMap(cache_index int, size int)
- func (self Instance) ClearSizeCache(cache_index int)
- func (self Instance) ClearTextures(cache_index int, size Vector2i.XY)
- func (self Instance) Data() []byte
- func (self Instance) DisableEmbeddedBitmaps() bool
- func (self Instance) EmitChanged()
- func (self Instance) Fallbacks() []Font.Instance
- func (self Instance) FixedSize() int
- func (self Instance) FixedSizeScaleMode() TextServer.FixedSizeScaleMode
- func (self Instance) ForceAutohinter() bool
- func (self Instance) GenerateMipmaps() bool
- func (self Instance) GetCacheAscent(cache_index int, size int) Float.X
- func (self Instance) GetCacheCount() int
- func (self Instance) GetCacheDescent(cache_index int, size int) Float.X
- func (self Instance) GetCacheScale(cache_index int, size int) Float.X
- func (self Instance) GetCacheUnderlinePosition(cache_index int, size int) Float.X
- func (self Instance) GetCacheUnderlineThickness(cache_index int, size int) Float.X
- func (self Instance) GetCharFromGlyphIndex(size int, glyph_index int) int
- func (self Instance) GetCharSize(char int, font_size int) Vector2.XY
- func (self Instance) GetEmbolden(cache_index int) Float.X
- func (self Instance) GetExtraBaselineOffset(cache_index int) Float.X
- func (self Instance) GetExtraSpacing(cache_index int, spacing TextServer.SpacingType) int
- func (self Instance) GetFaceCount() int
- func (self Instance) GetFaceIndex(cache_index int) int
- func (self Instance) GetFontName() string
- func (self Instance) GetFontStretch() int
- func (self Instance) GetFontStyle() TextServer.FontStyle
- func (self Instance) GetFontStyleName() string
- func (self Instance) GetFontWeight() int
- func (self Instance) GetGlyphAdvance(cache_index int, size int, glyph int) Vector2.XY
- func (self Instance) GetGlyphIndex(size int, char int, variation_selector int) int
- func (self Instance) GetGlyphList(cache_index int, size Vector2i.XY) []int32
- func (self Instance) GetGlyphOffset(cache_index int, size Vector2i.XY, glyph int) Vector2.XY
- func (self Instance) GetGlyphSize(cache_index int, size Vector2i.XY, glyph int) Vector2.XY
- func (self Instance) GetGlyphTextureIdx(cache_index int, size Vector2i.XY, glyph int) int
- func (self Instance) GetGlyphUvRect(cache_index int, size Vector2i.XY, glyph int) Rect2.PositionSize
- func (self Instance) GetIdForPath(path string) string
- func (self Instance) GetKerning(cache_index int, size int, glyph_pair Vector2i.XY) Vector2.XY
- func (self Instance) GetKerningList(cache_index int, size int) []Vector2i.XY
- func (self Instance) GetLanguageSupportOverride(language string) bool
- func (self Instance) GetLanguageSupportOverrides() []string
- func (self Instance) GetOpentypeFeatures() map[string][2]string
- func (self Instance) GetOtNameStrings() map[string]map[string]string
- func (self Instance) GetRid() Resource.ID
- func (self Instance) GetRids() []RID.Font
- func (self Instance) GetScriptSupportOverride(script string) bool
- func (self Instance) GetScriptSupportOverrides() []string
- func (self Instance) GetSizeCacheList(cache_index int) []Vector2i.XY
- func (self Instance) GetSpacing(spacing TextServer.SpacingType) int
- func (self Instance) GetSupportedChars() string
- func (self Instance) GetSupportedFeatureList() map[string]Font.OpenTypeFeature
- func (self Instance) GetSupportedVariationList() map[int]struct{ ... }
- func (self Instance) GetTextureCount(cache_index int, size Vector2i.XY) int
- func (self Instance) GetTextureImage(cache_index int, size Vector2i.XY, texture_index int) Image.Instance
- func (self Instance) GetTextureOffsets(cache_index int, size Vector2i.XY, texture_index int) []int32
- func (self Instance) GetTransform(cache_index int) Transform2D.OriginXY
- func (self Instance) GetVariationCoordinates(cache_index int) map[string]float32
- func (self Instance) HasChar(char int) bool
- func (self Instance) Hinting() TextServer.Hinting
- func (self Instance) ID() ID
- func (self Instance) IsBuiltIn() bool
- func (self Instance) IsLanguageSupported(language string) bool
- func (self Instance) IsScriptSupported(script string) bool
- func (self Instance) KeepRoundingRemainders() bool
- func (self Instance) LoadBitmapFont(path string) error
- func (self Instance) LoadDynamicFont(path string) error
- func (self Instance) ModulateColorGlyphs() bool
- func (self Instance) MsdfPixelRange() int
- func (self Instance) MsdfSize() int
- func (self Instance) MultichannelSignedDistanceField() bool
- func (self Instance) OnChanged(cb func(), flags ...Signal.Flags) Instance
- func (self Instance) OnSetupLocalToSceneRequested(cb func(), flags ...Signal.Flags) Instance
- func (self Instance) OpentypeFeatureOverrides() map[any]any
- func (self Instance) Oversampling() Float.X
- func (self Instance) RemoveCache(cache_index int)
- func (self Instance) RemoveGlyph(cache_index int, size Vector2i.XY, glyph int)
- func (self Instance) RemoveKerning(cache_index int, size int, glyph_pair Vector2i.XY)
- func (self Instance) RemoveLanguageSupportOverride(language string)
- func (self Instance) RemoveScriptSupportOverride(script string)
- func (self Instance) RemoveSizeCache(cache_index int, size Vector2i.XY)
- func (self Instance) RemoveTexture(cache_index int, size Vector2i.XY, texture_index int)
- func (self Instance) RenderGlyph(cache_index int, size Vector2i.XY, index int)
- func (self Instance) RenderRange(cache_index int, size Vector2i.XY, start int, end int)
- func (self Instance) ResetState()
- func (self Instance) ResourceLocalToScene() bool
- func (self Instance) ResourceName() string
- func (self Instance) ResourcePath() string
- func (self Instance) ResourceSceneUniqueId() string
- func (self Instance) SetAllowSystemFallback(value bool) Instance
- func (self Instance) SetAntialiasing(value TextServer.FontAntialiasing) Instance
- func (self Instance) SetCacheAscent(cache_index int, size int, ascent Float.X) Instance
- func (self Instance) SetCacheCapacity(single_line int, multi_line int) Instance
- func (self Instance) SetCacheDescent(cache_index int, size int, descent Float.X) Instance
- func (self Instance) SetCacheScale(cache_index int, size int, scale Float.X) Instance
- func (self Instance) SetCacheUnderlinePosition(cache_index int, size int, underline_position Float.X) Instance
- func (self Instance) SetCacheUnderlineThickness(cache_index int, size int, underline_thickness Float.X) Instance
- func (self Instance) SetData(value []byte) Instance
- func (self Instance) SetDisableEmbeddedBitmaps(value bool) Instance
- func (self Instance) SetEmbolden(cache_index int, strength Float.X) Instance
- func (self Instance) SetExtraBaselineOffset(cache_index int, baseline_offset Float.X) Instance
- func (self Instance) SetExtraSpacing(cache_index int, spacing TextServer.SpacingType, value int) Instance
- func (self Instance) SetFaceIndex(cache_index int, face_index int) Instance
- func (self Instance) SetFallbacks(value []Font.Instance) Instance
- func (self Instance) SetFixedSize(value int) Instance
- func (self Instance) SetFixedSizeScaleMode(value TextServer.FixedSizeScaleMode) Instance
- func (self Instance) SetFontName(value string) Instance
- func (self Instance) SetFontStretch(value int) Instance
- func (self Instance) SetFontStyle(value TextServer.FontStyle) Instance
- func (self Instance) SetFontWeight(value int) Instance
- func (self Instance) SetForceAutohinter(value bool) Instance
- func (self Instance) SetGenerateMipmaps(value bool) Instance
- func (self Instance) SetGlyphAdvance(cache_index int, size int, glyph int, advance Vector2.XY) Instance
- func (self Instance) SetGlyphOffset(cache_index int, size Vector2i.XY, glyph int, offset Vector2.XY) Instance
- func (self Instance) SetGlyphSize(cache_index int, size Vector2i.XY, glyph int, gl_size Vector2.XY) Instance
- func (self Instance) SetGlyphTextureIdx(cache_index int, size Vector2i.XY, glyph int, texture_idx int) Instance
- func (self Instance) SetGlyphUvRect(cache_index int, size Vector2i.XY, glyph int, uv_rect Rect2.PositionSize) Instance
- func (self Instance) SetHinting(value TextServer.Hinting) Instance
- func (self Instance) SetIdForPath(path string, id string) Instance
- func (self Instance) SetKeepRoundingRemainders(value bool) Instance
- func (self Instance) SetKerning(cache_index int, size int, glyph_pair Vector2i.XY, kerning Vector2.XY) Instance
- func (self Instance) SetLanguageSupportOverride(language string, supported bool) Instance
- func (self Instance) SetModulateColorGlyphs(value bool) Instance
- func (self Instance) SetMsdfPixelRange(value int) Instance
- func (self Instance) SetMsdfSize(value int) Instance
- func (self Instance) SetMultichannelSignedDistanceField(value bool) Instance
- func (self *Instance) SetObject(obj [1]gdreference.Object) bool
- func (self Instance) SetOpentypeFeatureOverrides(value map[any]any) Instance
- func (self Instance) SetOversampling(value Float.X) Instance
- func (self Instance) SetPathCache(path string) Instance
- func (self Instance) SetResourceLocalToScene(value bool) Instance
- func (self Instance) SetResourceName(value string) Instance
- func (self Instance) SetResourcePath(value string) Instance
- func (self Instance) SetResourceSceneUniqueId(value string) Instance
- func (self Instance) SetScriptSupportOverride(script string, supported bool) Instance
- func (self Instance) SetStyleName(value string) Instance
- func (self Instance) SetSubpixelPositioning(value TextServer.SubpixelPositioning) Instance
- func (self Instance) SetTextureImage(cache_index int, size Vector2i.XY, texture_index int, image Image.Instance) Instance
- func (self Instance) SetTextureOffsets(cache_index int, size Vector2i.XY, texture_index int, offset []int32) Instance
- func (self Instance) SetTransform(cache_index int, transform Transform2D.OriginXY) Instance
- func (self Instance) SetVariationCoordinates(cache_index int, variation_coordinates map[string]float32) Instance
- func (self Instance) SetupLocalToScene()
- func (self Instance) SubpixelPositioning() TextServer.SubpixelPositioning
- func (self Instance) TakeOverPath(path string)
- func (self Instance) Virtual(name string) reflect.Value
- type OpenTypeFeature
- type Singleton
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Advanced ¶
type Advanced = class
Advanced exposes a 1:1 low-level instance of the class, undocumented, for those who know what they are doing.
type Extension ¶
Extension can be embedded in a new struct to create a Go extension of this class.
T must be a type that is embedding this Extension as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.
func (*Extension[T]) AllowSystemFallback ¶
func (*Extension[T]) Antialiasing ¶
func (o *Extension[T]) Antialiasing() TextServer.FontAntialiasing
func (*Extension[T]) AsFontFile ¶
func (*Extension[T]) AsObject ¶
func (o *Extension[T]) AsObject() [1]gdreference.Object
func (*Extension[T]) AsRefCounted ¶
func (*Extension[T]) AsResource ¶
func (*Extension[T]) ClearCache ¶
func (o *Extension[T]) ClearCache()
func (*Extension[T]) ClearGlyphs ¶
func (*Extension[T]) ClearKerningMap ¶
func (*Extension[T]) ClearSizeCache ¶
func (*Extension[T]) ClearTextures ¶
func (*Extension[T]) DisableEmbeddedBitmaps ¶
func (*Extension[T]) EmitChanged ¶
func (o *Extension[T]) EmitChanged()
EmitChanged is promoted from Resource.Instance.EmitChanged.
func (*Extension[T]) FixedSizeScaleMode ¶
func (o *Extension[T]) FixedSizeScaleMode() TextServer.FixedSizeScaleMode
func (*Extension[T]) ForceAutohinter ¶
func (*Extension[T]) GenerateMipmaps ¶
func (*Extension[T]) GetCacheAscent ¶
func (*Extension[T]) GetCacheCount ¶
func (*Extension[T]) GetCacheDescent ¶
func (*Extension[T]) GetCacheScale ¶
func (*Extension[T]) GetCacheUnderlinePosition ¶
func (*Extension[T]) GetCacheUnderlineThickness ¶
func (*Extension[T]) GetCharFromGlyphIndex ¶
func (*Extension[T]) GetCharSize ¶
GetCharSize is promoted from Font.Instance.GetCharSize.
func (*Extension[T]) GetExtraBaselineOffset ¶
func (*Extension[T]) GetExtraSpacing ¶
func (o *Extension[T]) GetExtraSpacing(cache_index int, spacing TextServer.SpacingType) int
func (*Extension[T]) GetFaceCount ¶
GetFaceCount is promoted from Font.Instance.GetFaceCount.
func (*Extension[T]) GetFaceIndex ¶
func (*Extension[T]) GetFontName ¶
GetFontName is promoted from Font.Instance.GetFontName.
func (*Extension[T]) GetFontStretch ¶
GetFontStretch is promoted from Font.Instance.GetFontStretch.
func (*Extension[T]) GetFontStyle ¶
func (o *Extension[T]) GetFontStyle() TextServer.FontStyle
GetFontStyle is promoted from Font.Instance.GetFontStyle.
func (*Extension[T]) GetFontStyleName ¶
GetFontStyleName is promoted from Font.Instance.GetFontStyleName.
func (*Extension[T]) GetFontWeight ¶
GetFontWeight is promoted from Font.Instance.GetFontWeight.
func (*Extension[T]) GetGlyphAdvance ¶
func (*Extension[T]) GetGlyphIndex ¶
func (*Extension[T]) GetGlyphList ¶
func (*Extension[T]) GetGlyphOffset ¶
func (*Extension[T]) GetGlyphSize ¶
func (*Extension[T]) GetGlyphTextureIdx ¶
func (*Extension[T]) GetGlyphUvRect ¶
func (*Extension[T]) GetIdForPath ¶
GetIdForPath is promoted from Resource.Instance.GetIdForPath.
func (*Extension[T]) GetKerning ¶
func (*Extension[T]) GetKerningList ¶
func (*Extension[T]) GetLanguageSupportOverride ¶
func (*Extension[T]) GetLanguageSupportOverrides ¶
func (*Extension[T]) GetOpentypeFeatures ¶
GetOpentypeFeatures is promoted from Font.Instance.GetOpentypeFeatures.
func (*Extension[T]) GetOtNameStrings ¶
GetOtNameStrings is promoted from Font.Instance.GetOtNameStrings.
func (*Extension[T]) GetRid ¶
GetRid is promoted from Resource.Instance.GetRid.
func (*Extension[T]) GetRids ¶
GetRids is promoted from Font.Instance.GetRids.
func (*Extension[T]) GetScriptSupportOverride ¶
func (*Extension[T]) GetScriptSupportOverrides ¶
func (*Extension[T]) GetSizeCacheList ¶
func (*Extension[T]) GetSpacing ¶
func (o *Extension[T]) GetSpacing(spacing TextServer.SpacingType) int
GetSpacing is promoted from Font.Instance.GetSpacing.
func (*Extension[T]) GetSupportedChars ¶
GetSupportedChars is promoted from Font.Instance.GetSupportedChars.
func (*Extension[T]) GetSupportedFeatureList ¶
func (o *Extension[T]) GetSupportedFeatureList() map[string]Font.OpenTypeFeature
GetSupportedFeatureList is promoted from Font.Instance.GetSupportedFeatureList.
func (*Extension[T]) GetSupportedVariationList ¶
GetSupportedVariationList is promoted from Font.Instance.GetSupportedVariationList.
func (*Extension[T]) GetTextureCount ¶
func (*Extension[T]) GetTextureImage ¶
func (*Extension[T]) GetTextureOffsets ¶
func (*Extension[T]) GetTransform ¶
func (o *Extension[T]) GetTransform(cache_index int) Transform2D.OriginXY
func (*Extension[T]) GetVariationCoordinates ¶
func (*Extension[T]) HasChar ¶
HasChar is promoted from Font.Instance.HasChar.
func (*Extension[T]) Hinting ¶
func (o *Extension[T]) Hinting() TextServer.Hinting
func (*Extension[T]) IsBuiltIn ¶
IsBuiltIn is promoted from Resource.Instance.IsBuiltIn.
func (*Extension[T]) IsLanguageSupported ¶
IsLanguageSupported is promoted from Font.Instance.IsLanguageSupported.
func (*Extension[T]) IsScriptSupported ¶
IsScriptSupported is promoted from Font.Instance.IsScriptSupported.
func (*Extension[T]) KeepRoundingRemainders ¶
func (*Extension[T]) LoadBitmapFont ¶
func (*Extension[T]) LoadDynamicFont ¶
func (*Extension[T]) ModulateColorGlyphs ¶
func (*Extension[T]) MsdfPixelRange ¶
func (*Extension[T]) MultichannelSignedDistanceField ¶
func (*Extension[T]) OnChanged ¶
OnChanged is promoted from Resource.Instance.OnChanged.
func (*Extension[T]) OnSetupLocalToSceneRequested ¶
OnSetupLocalToSceneRequested is promoted from Resource.Instance.OnSetupLocalToSceneRequested.
func (*Extension[T]) OpentypeFeatureOverrides ¶
func (*Extension[T]) Oversampling ¶
func (*Extension[T]) RemoveCache ¶
func (*Extension[T]) RemoveGlyph ¶
func (*Extension[T]) RemoveKerning ¶
func (*Extension[T]) RemoveLanguageSupportOverride ¶
func (*Extension[T]) RemoveScriptSupportOverride ¶
func (*Extension[T]) RemoveSizeCache ¶
func (*Extension[T]) RemoveTexture ¶
func (*Extension[T]) RenderGlyph ¶
func (*Extension[T]) RenderRange ¶
func (*Extension[T]) ResetState ¶
func (o *Extension[T]) ResetState()
ResetState is promoted from Resource.Instance.ResetState.
func (*Extension[T]) ResourceLocalToScene ¶
func (*Extension[T]) ResourceName ¶
func (*Extension[T]) ResourcePath ¶
func (*Extension[T]) ResourceSceneUniqueId ¶
func (*Extension[T]) SetAllowSystemFallback ¶
func (*Extension[T]) SetAntialiasing ¶
func (o *Extension[T]) SetAntialiasing(value TextServer.FontAntialiasing) *Extension[T]
func (*Extension[T]) SetCacheAscent ¶
func (*Extension[T]) SetCacheCapacity ¶
SetCacheCapacity is promoted from Font.Instance.SetCacheCapacity.
func (*Extension[T]) SetCacheDescent ¶
func (*Extension[T]) SetCacheScale ¶
func (*Extension[T]) SetCacheUnderlinePosition ¶
func (*Extension[T]) SetCacheUnderlineThickness ¶
func (*Extension[T]) SetDisableEmbeddedBitmaps ¶
func (*Extension[T]) SetEmbolden ¶
func (*Extension[T]) SetExtraBaselineOffset ¶
func (*Extension[T]) SetExtraSpacing ¶
func (o *Extension[T]) SetExtraSpacing(cache_index int, spacing TextServer.SpacingType, value int) *Extension[T]
func (*Extension[T]) SetFaceIndex ¶
func (*Extension[T]) SetFallbacks ¶
func (*Extension[T]) SetFixedSize ¶
func (*Extension[T]) SetFixedSizeScaleMode ¶
func (o *Extension[T]) SetFixedSizeScaleMode(value TextServer.FixedSizeScaleMode) *Extension[T]
func (*Extension[T]) SetFontName ¶
func (*Extension[T]) SetFontStretch ¶
func (*Extension[T]) SetFontStyle ¶
func (o *Extension[T]) SetFontStyle(value TextServer.FontStyle) *Extension[T]
func (*Extension[T]) SetFontWeight ¶
func (*Extension[T]) SetForceAutohinter ¶
func (*Extension[T]) SetGenerateMipmaps ¶
func (*Extension[T]) SetGlyphAdvance ¶
func (*Extension[T]) SetGlyphOffset ¶
func (*Extension[T]) SetGlyphSize ¶
func (*Extension[T]) SetGlyphTextureIdx ¶
func (*Extension[T]) SetGlyphUvRect ¶
func (*Extension[T]) SetHinting ¶
func (o *Extension[T]) SetHinting(value TextServer.Hinting) *Extension[T]
func (*Extension[T]) SetIdForPath ¶
SetIdForPath is promoted from Resource.Instance.SetIdForPath.
func (*Extension[T]) SetKeepRoundingRemainders ¶
func (*Extension[T]) SetKerning ¶
func (*Extension[T]) SetLanguageSupportOverride ¶
func (*Extension[T]) SetModulateColorGlyphs ¶
func (*Extension[T]) SetMsdfPixelRange ¶
func (*Extension[T]) SetMsdfSize ¶
func (*Extension[T]) SetMultichannelSignedDistanceField ¶
func (*Extension[T]) SetOpentypeFeatureOverrides ¶
func (*Extension[T]) SetOversampling ¶
func (*Extension[T]) SetPathCache ¶
SetPathCache is promoted from Resource.Instance.SetPathCache.
func (*Extension[T]) SetResourceLocalToScene ¶
func (*Extension[T]) SetResourceName ¶
func (*Extension[T]) SetResourcePath ¶
func (*Extension[T]) SetResourceSceneUniqueId ¶
func (*Extension[T]) SetScriptSupportOverride ¶
func (*Extension[T]) SetStyleName ¶
func (*Extension[T]) SetSubpixelPositioning ¶
func (o *Extension[T]) SetSubpixelPositioning(value TextServer.SubpixelPositioning) *Extension[T]
func (*Extension[T]) SetTextureImage ¶
func (*Extension[T]) SetTextureOffsets ¶
func (*Extension[T]) SetTransform ¶
func (o *Extension[T]) SetTransform(cache_index int, transform Transform2D.OriginXY) *Extension[T]
func (*Extension[T]) SetVariationCoordinates ¶
func (*Extension[T]) SetupLocalToScene ¶
func (o *Extension[T]) SetupLocalToScene()
SetupLocalToScene is promoted from Resource.Instance.SetupLocalToScene.
func (*Extension[T]) SubpixelPositioning ¶
func (o *Extension[T]) SubpixelPositioning() TextServer.SubpixelPositioning
func (*Extension[T]) TakeOverPath ¶
TakeOverPath is promoted from Resource.Instance.TakeOverPath.
type ID ¶
ID is a typed object ID (reference) to an instance of this class, use it to store references to objects with unknown lifetimes, as an ID will not panic on use if the underlying object has been destroyed.
type Instance ¶
Instance of the class with convieniently typed arguments and results.
var Nil Instance
Nil is a nil/null instance of the class. Equivalent to the zero value.
func (Instance) AllowSystemFallback ¶
func (Instance) Antialiasing ¶
func (self Instance) Antialiasing() TextServer.FontAntialiasing
func (Instance) AsFontFile ¶
func (Instance) AsObject ¶
func (o Instance) AsObject() [1]gdreference.Object
func (Instance) AsRefCounted ¶
func (Instance) AsResource ¶
func (Instance) ClearCache ¶
func (self Instance) ClearCache()
func (Instance) ClearKerningMap ¶
func (Instance) ClearSizeCache ¶
func (Instance) ClearTextures ¶
func (Instance) DisableEmbeddedBitmaps ¶
func (Instance) EmitChanged ¶
func (self Instance) EmitChanged()
EmitChanged is promoted from Resource.Instance.EmitChanged.
func (Instance) Fallbacks ¶
Fallbacks is promoted from Font.Instance.Fallbacks.
func (Instance) FixedSizeScaleMode ¶
func (self Instance) FixedSizeScaleMode() TextServer.FixedSizeScaleMode
func (Instance) ForceAutohinter ¶
func (Instance) GenerateMipmaps ¶
func (Instance) GetCacheAscent ¶
func (Instance) GetCacheCount ¶
func (Instance) GetCacheDescent ¶
func (Instance) GetCacheScale ¶
func (Instance) GetCacheUnderlinePosition ¶
func (Instance) GetCacheUnderlineThickness ¶
func (Instance) GetCharFromGlyphIndex ¶
func (Instance) GetCharSize ¶
GetCharSize is promoted from Font.Instance.GetCharSize.
func (Instance) GetExtraBaselineOffset ¶
func (Instance) GetExtraSpacing ¶
func (self Instance) GetExtraSpacing(cache_index int, spacing TextServer.SpacingType) int
func (Instance) GetFaceCount ¶
GetFaceCount is promoted from Font.Instance.GetFaceCount.
func (Instance) GetFaceIndex ¶
func (Instance) GetFontName ¶
GetFontName is promoted from Font.Instance.GetFontName.
func (Instance) GetFontStretch ¶
GetFontStretch is promoted from Font.Instance.GetFontStretch.
func (Instance) GetFontStyle ¶
func (self Instance) GetFontStyle() TextServer.FontStyle
GetFontStyle is promoted from Font.Instance.GetFontStyle.
func (Instance) GetFontStyleName ¶
GetFontStyleName is promoted from Font.Instance.GetFontStyleName.
func (Instance) GetFontWeight ¶
GetFontWeight is promoted from Font.Instance.GetFontWeight.
func (Instance) GetGlyphAdvance ¶
func (Instance) GetGlyphIndex ¶
func (Instance) GetGlyphList ¶
func (Instance) GetGlyphOffset ¶
func (Instance) GetGlyphSize ¶
func (Instance) GetGlyphTextureIdx ¶
func (Instance) GetGlyphUvRect ¶
func (Instance) GetIdForPath ¶
GetIdForPath is promoted from Resource.Instance.GetIdForPath.
func (Instance) GetKerning ¶
func (Instance) GetKerningList ¶
func (Instance) GetLanguageSupportOverride ¶
func (Instance) GetLanguageSupportOverrides ¶
func (Instance) GetOpentypeFeatures ¶
GetOpentypeFeatures is promoted from Font.Instance.GetOpentypeFeatures.
func (Instance) GetOtNameStrings ¶
GetOtNameStrings is promoted from Font.Instance.GetOtNameStrings.
func (Instance) GetRid ¶
GetRid is promoted from Resource.Instance.GetRid.
func (Instance) GetRids ¶
GetRids is promoted from Font.Instance.GetRids.
func (Instance) GetScriptSupportOverride ¶
func (Instance) GetScriptSupportOverrides ¶
func (Instance) GetSizeCacheList ¶
func (Instance) GetSpacing ¶
func (self Instance) GetSpacing(spacing TextServer.SpacingType) int
GetSpacing is promoted from Font.Instance.GetSpacing.
func (Instance) GetSupportedChars ¶
GetSupportedChars is promoted from Font.Instance.GetSupportedChars.
func (Instance) GetSupportedFeatureList ¶
func (self Instance) GetSupportedFeatureList() map[string]Font.OpenTypeFeature
GetSupportedFeatureList is promoted from Font.Instance.GetSupportedFeatureList.
func (Instance) GetSupportedVariationList ¶
GetSupportedVariationList is promoted from Font.Instance.GetSupportedVariationList.
func (Instance) GetTextureCount ¶
func (Instance) GetTextureImage ¶
func (Instance) GetTextureOffsets ¶
func (Instance) GetTransform ¶
func (self Instance) GetTransform(cache_index int) Transform2D.OriginXY
func (Instance) GetVariationCoordinates ¶
func (Instance) HasChar ¶
HasChar is promoted from Font.Instance.HasChar.
func (Instance) Hinting ¶
func (self Instance) Hinting() TextServer.Hinting
func (Instance) IsBuiltIn ¶
IsBuiltIn is promoted from Resource.Instance.IsBuiltIn.
func (Instance) IsLanguageSupported ¶
IsLanguageSupported is promoted from Font.Instance.IsLanguageSupported.
func (Instance) IsScriptSupported ¶
IsScriptSupported is promoted from Font.Instance.IsScriptSupported.
func (Instance) KeepRoundingRemainders ¶
func (Instance) LoadBitmapFont ¶
func (Instance) LoadDynamicFont ¶
func (Instance) ModulateColorGlyphs ¶
func (Instance) MsdfPixelRange ¶
func (Instance) MultichannelSignedDistanceField ¶
func (Instance) OnChanged ¶
OnChanged is promoted from Resource.Instance.OnChanged.
func (Instance) OnSetupLocalToSceneRequested ¶
OnSetupLocalToSceneRequested is promoted from Resource.Instance.OnSetupLocalToSceneRequested.
func (Instance) OpentypeFeatureOverrides ¶
func (Instance) Oversampling ¶
func (Instance) RemoveCache ¶
func (Instance) RemoveGlyph ¶
func (Instance) RemoveKerning ¶
func (Instance) RemoveLanguageSupportOverride ¶
func (Instance) RemoveScriptSupportOverride ¶
func (Instance) RemoveSizeCache ¶
func (Instance) RemoveTexture ¶
func (Instance) RenderGlyph ¶
func (Instance) RenderRange ¶
func (Instance) ResetState ¶
func (self Instance) ResetState()
ResetState is promoted from Resource.Instance.ResetState.
func (Instance) ResourceLocalToScene ¶
ResourceLocalToScene is promoted from Resource.Instance.ResourceLocalToScene.
func (Instance) ResourceName ¶
ResourceName is promoted from Resource.Instance.ResourceName.
func (Instance) ResourcePath ¶
ResourcePath is promoted from Resource.Instance.ResourcePath.
func (Instance) ResourceSceneUniqueId ¶
ResourceSceneUniqueId is promoted from Resource.Instance.ResourceSceneUniqueId.
func (Instance) SetAllowSystemFallback ¶
SetAllowSystemFallback sets the property returned by [IsAllowSystemFallback]. Returns the instance, so that property settings can be chained.
func (Instance) SetAntialiasing ¶
func (self Instance) SetAntialiasing(value TextServer.FontAntialiasing) Instance
SetAntialiasing sets the property returned by [GetAntialiasing]. Returns the instance, so that property settings can be chained.
func (Instance) SetCacheAscent ¶
func (Instance) SetCacheCapacity ¶
SetCacheCapacity is promoted from Font.Instance.SetCacheCapacity.
func (Instance) SetCacheDescent ¶
func (Instance) SetCacheScale ¶
func (Instance) SetCacheUnderlinePosition ¶
func (Instance) SetCacheUnderlineThickness ¶
func (Instance) SetData ¶
SetData sets the property returned by [GetData]. Returns the instance, so that property settings can be chained.
func (Instance) SetDisableEmbeddedBitmaps ¶
SetDisableEmbeddedBitmaps sets the property returned by [GetDisableEmbeddedBitmaps]. Returns the instance, so that property settings can be chained.
func (Instance) SetEmbolden ¶
func (Instance) SetExtraBaselineOffset ¶
func (Instance) SetExtraSpacing ¶
func (self Instance) SetExtraSpacing(cache_index int, spacing TextServer.SpacingType, value int) Instance
func (Instance) SetFaceIndex ¶
func (Instance) SetFallbacks ¶
SetFallbacks is promoted from Font.Instance.SetFallbacks.
func (Instance) SetFixedSize ¶
SetFixedSize sets the property returned by [GetFixedSize]. Returns the instance, so that property settings can be chained.
func (Instance) SetFixedSizeScaleMode ¶
func (self Instance) SetFixedSizeScaleMode(value TextServer.FixedSizeScaleMode) Instance
SetFixedSizeScaleMode sets the property returned by [GetFixedSizeScaleMode]. Returns the instance, so that property settings can be chained.
func (Instance) SetFontName ¶
func (Instance) SetFontStretch ¶
func (Instance) SetFontStyle ¶
func (self Instance) SetFontStyle(value TextServer.FontStyle) Instance
func (Instance) SetFontWeight ¶
func (Instance) SetForceAutohinter ¶
SetForceAutohinter sets the property returned by [IsForceAutohinter]. Returns the instance, so that property settings can be chained.
func (Instance) SetGenerateMipmaps ¶
SetGenerateMipmaps sets the property returned by [GetGenerateMipmaps]. Returns the instance, so that property settings can be chained.
func (Instance) SetGlyphAdvance ¶
func (Instance) SetGlyphOffset ¶
func (Instance) SetGlyphSize ¶
func (Instance) SetGlyphTextureIdx ¶
func (Instance) SetGlyphUvRect ¶
func (Instance) SetHinting ¶
func (self Instance) SetHinting(value TextServer.Hinting) Instance
SetHinting sets the property returned by [GetHinting]. Returns the instance, so that property settings can be chained.
func (Instance) SetIdForPath ¶
SetIdForPath is promoted from Resource.Instance.SetIdForPath.
func (Instance) SetKeepRoundingRemainders ¶
SetKeepRoundingRemainders sets the property returned by [GetKeepRoundingRemainders]. Returns the instance, so that property settings can be chained.
func (Instance) SetKerning ¶
func (Instance) SetLanguageSupportOverride ¶
func (Instance) SetModulateColorGlyphs ¶
SetModulateColorGlyphs sets the property returned by [IsModulateColorGlyphs]. Returns the instance, so that property settings can be chained.
func (Instance) SetMsdfPixelRange ¶
SetMsdfPixelRange sets the property returned by [GetMsdfPixelRange]. Returns the instance, so that property settings can be chained.
func (Instance) SetMsdfSize ¶
SetMsdfSize sets the property returned by [GetMsdfSize]. Returns the instance, so that property settings can be chained.
func (Instance) SetMultichannelSignedDistanceField ¶
SetMultichannelSignedDistanceField sets the property returned by [IsMultichannelSignedDistanceField]. Returns the instance, so that property settings can be chained.
func (Instance) SetOpentypeFeatureOverrides ¶
SetOpentypeFeatureOverrides sets the property returned by [GetOpentypeFeatureOverrides]. Returns the instance, so that property settings can be chained.
func (Instance) SetOversampling ¶
SetOversampling sets the property returned by [GetOversampling]. Returns the instance, so that property settings can be chained.
func (Instance) SetPathCache ¶
SetPathCache is promoted from Resource.Instance.SetPathCache.
func (Instance) SetResourceLocalToScene ¶
SetResourceLocalToScene is promoted from Resource.Instance.SetResourceLocalToScene.
func (Instance) SetResourceName ¶
SetResourceName is promoted from Resource.Instance.SetResourceName.
func (Instance) SetResourcePath ¶
SetResourcePath is promoted from Resource.Instance.SetResourcePath.
func (Instance) SetResourceSceneUniqueId ¶
SetResourceSceneUniqueId is promoted from Resource.Instance.SetResourceSceneUniqueId.
func (Instance) SetScriptSupportOverride ¶
func (Instance) SetStyleName ¶
func (Instance) SetSubpixelPositioning ¶
func (self Instance) SetSubpixelPositioning(value TextServer.SubpixelPositioning) Instance
SetSubpixelPositioning sets the property returned by [GetSubpixelPositioning]. Returns the instance, so that property settings can be chained.
func (Instance) SetTextureImage ¶
func (Instance) SetTextureOffsets ¶
func (Instance) SetTransform ¶
func (self Instance) SetTransform(cache_index int, transform Transform2D.OriginXY) Instance
func (Instance) SetVariationCoordinates ¶
func (Instance) SetupLocalToScene ¶
func (self Instance) SetupLocalToScene()
SetupLocalToScene is promoted from Resource.Instance.SetupLocalToScene.
func (Instance) SubpixelPositioning ¶
func (self Instance) SubpixelPositioning() TextServer.SubpixelPositioning
func (Instance) TakeOverPath ¶
TakeOverPath is promoted from Resource.Instance.TakeOverPath.
type OpenTypeFeature ¶
type Singleton ¶
Singleton can be embedded in a new struct to create a Go singleton extension of the class.
It will become available as a global inside scripts and any any other Go Extension types will have any *T typed fields filled in to point at this singleton once they have been instantiated.
T must be a type that is embedding this Singleton as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.