Documentation
¶
Index ¶
- func ActionAddEvent(action string, event InputEvent.Instance)
- func ActionEraseEvent(action string, event InputEvent.Instance)
- func ActionEraseEvents(action string)
- func ActionGetDeadzone(action string) Float.X
- func ActionGetEvents(action string) []InputEvent.Instance
- func ActionHasEvent(action string, event InputEvent.Instance) bool
- func ActionSetDeadzone(action string, deadzone Float.X)
- func AddAction(action string)
- func AddActionOptions(action string, deadzone Float.X)
- func Advanced() class
- func EraseAction(action string)
- func EventIsAction(event InputEvent.Instance, action string, exact_match bool) bool
- func GetActionDescription(action string) string
- func GetActions() []string
- func HasAction(action string) bool
- func LoadFromProjectSettings()
- type Extension
- type ID
- type Instance
- type Singleton
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ActionAddEvent ¶
func ActionAddEvent(action string, event InputEvent.Instance)
func ActionEraseEvent ¶
func ActionEraseEvent(action string, event InputEvent.Instance)
func ActionEraseEvents ¶
func ActionEraseEvents(action string)
func ActionGetDeadzone ¶
func ActionGetEvents ¶
func ActionGetEvents(action string) []InputEvent.Instance
func ActionHasEvent ¶
func ActionHasEvent(action string, event InputEvent.Instance) bool
func ActionSetDeadzone ¶
func AddActionOptions ¶
func Advanced ¶
func Advanced() class
Advanced exposes a 1:1 low-level instance of the class, undocumented, for those who know what they are doing.
func EraseAction ¶
func EraseAction(action string)
func EventIsAction ¶
func EventIsAction(event InputEvent.Instance, action string, exact_match bool) bool
func GetActionDescription ¶
func GetActions ¶
func GetActions() []string
func LoadFromProjectSettings ¶
func LoadFromProjectSettings()
Types ¶
type Extension ¶
Extension can be embedded in a new struct to create a Go extension of this class.
T must be a type that is embedding this Extension as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.
func (*Extension[T]) AsObject ¶
func (o *Extension[T]) AsObject() [1]gdreference.Object
type ID ¶
ID is a typed object ID (reference) to an instance of this class, use it to store references to objects with unknown lifetimes, as an ID will not panic on use if the underlying object has been destroyed.
type Instance ¶
Instance of the class with convieniently typed arguments and results.
func (Instance) AsObject ¶
func (o Instance) AsObject() [1]gdreference.Object
type Singleton ¶
Singleton can be embedded in a new struct to create a Go singleton extension of the class.
It will become available as a global inside scripts and any any other Go Extension types will have any *T typed fields filled in to point at this singleton once they have been instantiated.
T must be a type that is embedding this Singleton as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.