Documentation
¶
Index ¶
- func Advanced() class
- func CreateCallback(callable func(args []any) any) JavaScriptObject.Instance
- func CreateObject(obj string, args ...any) any
- func DownloadBuffer(buffer []byte, name string)
- func DownloadBufferOptions(buffer []byte, name string, mime string)
- func Eval(code string, use_global_execution_context bool) any
- func ForceFsSync()
- func GetInterface(intf string) JavaScriptObject.Instance
- func IsJsBuffer(javascript_object JavaScriptObject.Instance) bool
- func JsBufferToPackedByteArray(javascript_buffer JavaScriptObject.Instance) []byte
- func OnPwaUpdateAvailable(cb func(), flags ...Signal.Flags)
- func PwaNeedsUpdate() bool
- func PwaUpdate() error
- type Extension
- type ID
- type Instance
- type Singleton
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Advanced ¶
func Advanced() class
Advanced exposes a 1:1 low-level instance of the class, undocumented, for those who know what they are doing.
func CreateCallback ¶
func CreateCallback(callable func(args []any) any) JavaScriptObject.Instance
func CreateObject ¶
func DownloadBuffer ¶
func DownloadBufferOptions ¶
func ForceFsSync ¶
func ForceFsSync()
func GetInterface ¶
func GetInterface(intf string) JavaScriptObject.Instance
func IsJsBuffer ¶
func IsJsBuffer(javascript_object JavaScriptObject.Instance) bool
func JsBufferToPackedByteArray ¶
func JsBufferToPackedByteArray(javascript_buffer JavaScriptObject.Instance) []byte
func OnPwaUpdateAvailable ¶
func PwaNeedsUpdate ¶
func PwaNeedsUpdate() bool
Types ¶
type Extension ¶
Extension can be embedded in a new struct to create a Go extension of this class.
T must be a type that is embedding this Extension as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.
func (*Extension[T]) AsObject ¶
func (o *Extension[T]) AsObject() [1]gdreference.Object
type ID ¶
ID is a typed object ID (reference) to an instance of this class, use it to store references to objects with unknown lifetimes, as an ID will not panic on use if the underlying object has been destroyed.
type Instance ¶
type Instance [1]gdclass.JavaScriptBridge
Instance of the class with convieniently typed arguments and results.
func (Instance) AsObject ¶
func (o Instance) AsObject() [1]gdreference.Object
type Singleton ¶
Singleton can be embedded in a new struct to create a Go singleton extension of the class.
It will become available as a global inside scripts and any any other Go Extension types will have any *T typed fields filled in to point at this singleton once they have been instantiated.
T must be a type that is embedding this Singleton as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.