Documentation
¶
Index ¶
- type Advanced
- type Any
- type Expanded
- type Extension
- type ID
- type Instance
- func (o Instance) AsObject() [1]gdreference.Object
- func (o Instance) AsOpenXRAndroidThreadSettingsExtension() Instance
- func (o Instance) AsOpenXRExtensionWrapper() OpenXRExtensionWrapper.Instance
- func (self Instance) ID() ID
- func (self Instance) MoreArgs() MoreArgs
- func (self Instance) RegisterExtensionWrapper()
- func (self Instance) SetApplicationThreadType(thread_type ThreadType) bool
- func (self *Instance) SetObject(obj [1]gdreference.Object) bool
- func (self Instance) Virtual(name string) reflect.Value
- type MoreArgs
- type Singleton
- type ThreadType
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Advanced ¶
type Advanced = class
Advanced exposes a 1:1 low-level instance of the class, undocumented, for those who know what they are doing.
type Extension ¶
Extension can be embedded in a new struct to create a Go extension of this class.
T must be a type that is embedding this Extension as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.
func (*Extension[T]) AsObject ¶
func (o *Extension[T]) AsObject() [1]gdreference.Object
func (*Extension[T]) AsOpenXRAndroidThreadSettingsExtension ¶
func (*Extension[T]) AsOpenXRExtensionWrapper ¶
func (o *Extension[T]) AsOpenXRExtensionWrapper() OpenXRExtensionWrapper.Instance
func (*Extension[T]) RegisterExtensionWrapper ¶
func (o *Extension[T]) RegisterExtensionWrapper()
RegisterExtensionWrapper is promoted from OpenXRExtensionWrapper.Instance.RegisterExtensionWrapper.
type ID ¶
ID is a typed object ID (reference) to an instance of this class, use it to store references to objects with unknown lifetimes, as an ID will not panic on use if the underlying object has been destroyed.
type Instance ¶
type Instance [1]gdclass.OpenXRAndroidThreadSettingsExtension
Instance of the class with convieniently typed arguments and results.
var Nil Instance
Nil is a nil/null instance of the class. Equivalent to the zero value.
func (Instance) AsObject ¶
func (o Instance) AsObject() [1]gdreference.Object
func (Instance) AsOpenXRAndroidThreadSettingsExtension ¶
func (Instance) AsOpenXRExtensionWrapper ¶
func (o Instance) AsOpenXRExtensionWrapper() OpenXRExtensionWrapper.Instance
func (Instance) MoreArgs ¶
MoreArgs enables certain functions to be called with additional 'optional' arguments.
func (Instance) RegisterExtensionWrapper ¶
func (self Instance) RegisterExtensionWrapper()
RegisterExtensionWrapper is promoted from OpenXRExtensionWrapper.Instance.RegisterExtensionWrapper.
func (Instance) SetApplicationThreadType ¶
func (self Instance) SetApplicationThreadType(thread_type ThreadType) bool
type MoreArgs ¶
type MoreArgs [1]gdclass.OpenXRAndroidThreadSettingsExtension
MoreArgs is a container for Instance functions with additional 'optional' arguments.
func (MoreArgs) SetApplicationThreadType ¶
func (self MoreArgs) SetApplicationThreadType(thread_type ThreadType, thread_id int) bool
type Singleton ¶
Singleton can be embedded in a new struct to create a Go singleton extension of the class.
It will become available as a global inside scripts and any any other Go Extension types will have any *T typed fields filled in to point at this singleton once they have been instantiated.
T must be a type that is embedding this Singleton as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.
type ThreadType ¶
type ThreadType int64 //gd:OpenXRAndroidThreadSettingsExtension.ThreadType
const ( ThreadTypeApplicationMain ThreadType = 0 ThreadTypeApplicationWorker ThreadType = 1 ThreadTypeRendererMain ThreadType = 2 ThreadTypeRendererWorker ThreadType = 3 )