Documentation
¶
Index ¶
- type Advanced
- type Any
- type Extension
- func (o *Extension[T]) AddResource(name string, resource Resource.Instance)
- func (o *Extension[T]) AsNode() Node.Instance
- func (o *Extension[T]) AsObject() [1]gdreference.Object
- func (o *Extension[T]) AsResourcePreloader() Instance
- func (o *Extension[T]) AutoTranslateMode() Node.AutoTranslateMode
- func (o *Extension[T]) CanAutoTranslate() bool
- func (o *Extension[T]) CanProcess() bool
- func (o *Extension[T]) CreateTween() Tween.Instance
- func (o *Extension[T]) EditorDescription() string
- func (o *Extension[T]) FindParent(pattern string) Node.Instance
- func (o *Extension[T]) GetAccessibilityElement() RID.AccessibilityElement
- func (o *Extension[T]) GetGroups() []string
- func (o *Extension[T]) GetMultiplayerAuthority() int
- func (o *Extension[T]) GetNode(path string) Node.Instance
- func (o *Extension[T]) GetNodeOrNull(path string) Node.Instance
- func (o *Extension[T]) GetNodeRpcConfig() any
- func (o *Extension[T]) GetParent() Node.Instance
- func (o *Extension[T]) GetPath() string
- func (o *Extension[T]) GetPhysicsProcessDeltaTime() Float.X
- func (o *Extension[T]) GetProcessDeltaTime() Float.X
- func (o *Extension[T]) GetResource(name string) Resource.Instance
- func (o *Extension[T]) GetResourceList() []string
- func (o *Extension[T]) GetSceneInstanceLoadPlaceholder() bool
- func (o *Extension[T]) GetTreeString() string
- func (o *Extension[T]) GetTreeStringPretty() string
- func (o *Extension[T]) HasNode(path string) bool
- func (o *Extension[T]) HasNodeAndResource(path string) bool
- func (o *Extension[T]) HasResource(name string) bool
- func (o *Extension[T]) IsAncestorOf(node Node.Instance) bool
- func (o *Extension[T]) IsDisplayedFolded() bool
- func (o *Extension[T]) IsEditableInstance(node Node.Instance) bool
- func (o *Extension[T]) IsGreaterThan(node Node.Instance) bool
- func (o *Extension[T]) IsInGroup(group string) bool
- func (o *Extension[T]) IsInsideTree() bool
- func (o *Extension[T]) IsMultiplayerAuthority() bool
- func (o *Extension[T]) IsNodeReady() bool
- func (o *Extension[T]) IsPartOfEditedScene() bool
- func (o *Extension[T]) IsPhysicsInterpolated() bool
- func (o *Extension[T]) IsPhysicsInterpolatedAndEnabled() bool
- func (o *Extension[T]) IsPhysicsProcessing() bool
- func (o *Extension[T]) IsPhysicsProcessingInternal() bool
- func (o *Extension[T]) IsProcessing() bool
- func (o *Extension[T]) IsProcessingInput() bool
- func (o *Extension[T]) IsProcessingInternal() bool
- func (o *Extension[T]) IsProcessingShortcutInput() bool
- func (o *Extension[T]) IsProcessingUnhandledInput() bool
- func (o *Extension[T]) IsProcessingUnhandledKeyInput() bool
- func (o *Extension[T]) MoveChild(child_node Node.Instance, to_index int)
- func (o *Extension[T]) Multiplayer() MultiplayerAPI.Instance
- func (o *Extension[T]) Name() string
- func (o *Extension[T]) NotifyDeferredThreadGroup(what int)
- func (o *Extension[T]) NotifyThreadSafe(what int)
- func (o *Extension[T]) OnChildEnteredTree(cb func(node Node.Instance), flags ...Signal.Flags) *Extension[T]
- func (o *Extension[T]) OnChildExitingTree(cb func(node Node.Instance), flags ...Signal.Flags) *Extension[T]
- func (o *Extension[T]) OnChildOrderChanged(cb func(), flags ...Signal.Flags) *Extension[T]
- func (o *Extension[T]) OnEditorDescriptionChanged(cb func(node Node.Instance), flags ...Signal.Flags) *Extension[T]
- func (o *Extension[T]) OnEditorStateChanged(cb func(), flags ...Signal.Flags) *Extension[T]
- func (o *Extension[T]) OnReady(cb func(), flags ...Signal.Flags) *Extension[T]
- func (o *Extension[T]) OnRenamed(cb func(), flags ...Signal.Flags) *Extension[T]
- func (o *Extension[T]) OnReplacingBy(cb func(node Node.Instance), flags ...Signal.Flags) *Extension[T]
- func (o *Extension[T]) OnTreeEntered(cb func(), flags ...Signal.Flags) *Extension[T]
- func (o *Extension[T]) OnTreeExited(cb func(), flags ...Signal.Flags) *Extension[T]
- func (o *Extension[T]) OnTreeExiting(cb func(), flags ...Signal.Flags) *Extension[T]
- func (o *Extension[T]) Owner() Node.Instance
- func (o *Extension[T]) PhysicsInterpolationMode() Node.PhysicsInterpolationMode
- func (o *Extension[T]) PrintTree()
- func (o *Extension[T]) PrintTreePretty()
- func (o *Extension[T]) ProcessMode() Node.ProcessMode
- func (o *Extension[T]) ProcessPhysicsPriority() int
- func (o *Extension[T]) ProcessPriority() int
- func (o *Extension[T]) ProcessThreadGroup() Node.ProcessThreadGroup
- func (o *Extension[T]) ProcessThreadGroupOrder() int
- func (o *Extension[T]) ProcessThreadMessages() Node.ProcessThreadMessages
- func (o *Extension[T]) PropagateNotification(what int)
- func (o *Extension[T]) QueueAccessibilityUpdate()
- func (o *Extension[T]) QueueFree()
- func (o *Extension[T]) RemoveChild(node Node.Instance)
- func (o *Extension[T]) RemoveFromGroup(group string)
- func (o *Extension[T]) RemoveResource(name string)
- func (o *Extension[T]) RenameResource(name string, newname string)
- func (o *Extension[T]) RequestReady()
- func (o *Extension[T]) ResetPhysicsInterpolation()
- func (o *Extension[T]) RpcConfig(method string, config any)
- func (o *Extension[T]) SceneFilePath() string
- func (o *Extension[T]) SetAutoTranslateMode(value Node.AutoTranslateMode) *Extension[T]
- func (o *Extension[T]) SetDeferredThreadGroup(property string, value any) *Extension[T]
- func (o *Extension[T]) SetDisplayFolded(fold bool) *Extension[T]
- func (o *Extension[T]) SetEditableInstance(node Node.Instance, is_editable bool) *Extension[T]
- func (o *Extension[T]) SetEditorDescription(value string) *Extension[T]
- func (o *Extension[T]) SetName(value string) *Extension[T]
- func (o *Extension[T]) SetOwner(value Node.Instance) *Extension[T]
- func (o *Extension[T]) SetPhysicsInterpolationMode(value Node.PhysicsInterpolationMode) *Extension[T]
- func (o *Extension[T]) SetPhysicsProcess(enable bool) *Extension[T]
- func (o *Extension[T]) SetPhysicsProcessInternal(enable bool) *Extension[T]
- func (o *Extension[T]) SetProcess(enable bool) *Extension[T]
- func (o *Extension[T]) SetProcessInput(enable bool) *Extension[T]
- func (o *Extension[T]) SetProcessInternal(enable bool) *Extension[T]
- func (o *Extension[T]) SetProcessMode(value Node.ProcessMode) *Extension[T]
- func (o *Extension[T]) SetProcessPhysicsPriority(value int) *Extension[T]
- func (o *Extension[T]) SetProcessPriority(value int) *Extension[T]
- func (o *Extension[T]) SetProcessShortcutInput(enable bool) *Extension[T]
- func (o *Extension[T]) SetProcessThreadGroup(value Node.ProcessThreadGroup) *Extension[T]
- func (o *Extension[T]) SetProcessThreadGroupOrder(value int) *Extension[T]
- func (o *Extension[T]) SetProcessThreadMessages(value Node.ProcessThreadMessages) *Extension[T]
- func (o *Extension[T]) SetProcessUnhandledInput(enable bool) *Extension[T]
- func (o *Extension[T]) SetProcessUnhandledKeyInput(enable bool) *Extension[T]
- func (o *Extension[T]) SetSceneFilePath(value string) *Extension[T]
- func (o *Extension[T]) SetSceneInstanceLoadPlaceholder(load_placeholder bool) *Extension[T]
- func (o *Extension[T]) SetThreadSafe(property string, value any) *Extension[T]
- func (o *Extension[T]) SetTranslationDomainInherited() *Extension[T]
- func (o *Extension[T]) SetUniqueNameInOwner(value bool) *Extension[T]
- func (o *Extension[T]) UniqueNameInOwner() bool
- func (o *Extension[T]) UpdateConfigurationWarnings()
- type ID
- type Instance
- func (self Instance) AddResource(name string, resource Resource.Instance)
- func (o Instance) AsNode() Node.Instance
- func (o Instance) AsObject() [1]gdreference.Object
- func (o Instance) AsResourcePreloader() Instance
- func (self Instance) AutoTranslateMode() Node.AutoTranslateMode
- func (self Instance) CanAutoTranslate() bool
- func (self Instance) CanProcess() bool
- func (self Instance) CreateTween() Tween.Instance
- func (self Instance) EditorDescription() string
- func (self Instance) FindParent(pattern string) Node.Instance
- func (self Instance) GetAccessibilityElement() RID.AccessibilityElement
- func (self Instance) GetGroups() []string
- func (self Instance) GetMultiplayerAuthority() int
- func (self Instance) GetNode(path string) Node.Instance
- func (self Instance) GetNodeOrNull(path string) Node.Instance
- func (self Instance) GetNodeRpcConfig() any
- func (self Instance) GetParent() Node.Instance
- func (self Instance) GetPath() string
- func (self Instance) GetPhysicsProcessDeltaTime() Float.X
- func (self Instance) GetProcessDeltaTime() Float.X
- func (self Instance) GetResource(name string) Resource.Instance
- func (self Instance) GetResourceList() []string
- func (self Instance) GetSceneInstanceLoadPlaceholder() bool
- func (self Instance) GetTreeString() string
- func (self Instance) GetTreeStringPretty() string
- func (self Instance) HasNode(path string) bool
- func (self Instance) HasNodeAndResource(path string) bool
- func (self Instance) HasResource(name string) bool
- func (self Instance) ID() ID
- func (self Instance) IsAncestorOf(node Node.Instance) bool
- func (self Instance) IsDisplayedFolded() bool
- func (self Instance) IsEditableInstance(node Node.Instance) bool
- func (self Instance) IsGreaterThan(node Node.Instance) bool
- func (self Instance) IsInGroup(group string) bool
- func (self Instance) IsInsideTree() bool
- func (self Instance) IsMultiplayerAuthority() bool
- func (self Instance) IsNodeReady() bool
- func (self Instance) IsPartOfEditedScene() bool
- func (self Instance) IsPhysicsInterpolated() bool
- func (self Instance) IsPhysicsInterpolatedAndEnabled() bool
- func (self Instance) IsPhysicsProcessing() bool
- func (self Instance) IsPhysicsProcessingInternal() bool
- func (self Instance) IsProcessing() bool
- func (self Instance) IsProcessingInput() bool
- func (self Instance) IsProcessingInternal() bool
- func (self Instance) IsProcessingShortcutInput() bool
- func (self Instance) IsProcessingUnhandledInput() bool
- func (self Instance) IsProcessingUnhandledKeyInput() bool
- func (self Instance) MoveChild(child_node Node.Instance, to_index int)
- func (self Instance) Multiplayer() MultiplayerAPI.Instance
- func (self Instance) Name() string
- func (self Instance) NotifyDeferredThreadGroup(what int)
- func (self Instance) NotifyThreadSafe(what int)
- func (self Instance) OnChildEnteredTree(cb func(node Node.Instance), flags ...Signal.Flags) Instance
- func (self Instance) OnChildExitingTree(cb func(node Node.Instance), flags ...Signal.Flags) Instance
- func (self Instance) OnChildOrderChanged(cb func(), flags ...Signal.Flags) Instance
- func (self Instance) OnEditorDescriptionChanged(cb func(node Node.Instance), flags ...Signal.Flags) Instance
- func (self Instance) OnEditorStateChanged(cb func(), flags ...Signal.Flags) Instance
- func (self Instance) OnReady(cb func(), flags ...Signal.Flags) Instance
- func (self Instance) OnRenamed(cb func(), flags ...Signal.Flags) Instance
- func (self Instance) OnReplacingBy(cb func(node Node.Instance), flags ...Signal.Flags) Instance
- func (self Instance) OnTreeEntered(cb func(), flags ...Signal.Flags) Instance
- func (self Instance) OnTreeExited(cb func(), flags ...Signal.Flags) Instance
- func (self Instance) OnTreeExiting(cb func(), flags ...Signal.Flags) Instance
- func (self Instance) Owner() Node.Instance
- func (self Instance) PhysicsInterpolationMode() Node.PhysicsInterpolationMode
- func (self Instance) PrintTree()
- func (self Instance) PrintTreePretty()
- func (self Instance) ProcessMode() Node.ProcessMode
- func (self Instance) ProcessPhysicsPriority() int
- func (self Instance) ProcessPriority() int
- func (self Instance) ProcessThreadGroup() Node.ProcessThreadGroup
- func (self Instance) ProcessThreadGroupOrder() int
- func (self Instance) ProcessThreadMessages() Node.ProcessThreadMessages
- func (self Instance) PropagateNotification(what int)
- func (self Instance) QueueAccessibilityUpdate()
- func (self Instance) QueueFree()
- func (self Instance) RemoveChild(node Node.Instance)
- func (self Instance) RemoveFromGroup(group string)
- func (self Instance) RemoveResource(name string)
- func (self Instance) RenameResource(name string, newname string)
- func (self Instance) RequestReady()
- func (self Instance) ResetPhysicsInterpolation()
- func (self Instance) RpcConfig(method string, config any)
- func (self Instance) SceneFilePath() string
- func (self Instance) SetAutoTranslateMode(value Node.AutoTranslateMode) Instance
- func (self Instance) SetDeferredThreadGroup(property string, value any) Instance
- func (self Instance) SetDisplayFolded(fold bool) Instance
- func (self Instance) SetEditableInstance(node Node.Instance, is_editable bool) Instance
- func (self Instance) SetEditorDescription(value string) Instance
- func (self Instance) SetName(value string) Instance
- func (self *Instance) SetObject(obj [1]gdreference.Object) bool
- func (self Instance) SetOwner(value Node.Instance) Instance
- func (self Instance) SetPhysicsInterpolationMode(value Node.PhysicsInterpolationMode) Instance
- func (self Instance) SetPhysicsProcess(enable bool) Instance
- func (self Instance) SetPhysicsProcessInternal(enable bool) Instance
- func (self Instance) SetProcess(enable bool) Instance
- func (self Instance) SetProcessInput(enable bool) Instance
- func (self Instance) SetProcessInternal(enable bool) Instance
- func (self Instance) SetProcessMode(value Node.ProcessMode) Instance
- func (self Instance) SetProcessPhysicsPriority(value int) Instance
- func (self Instance) SetProcessPriority(value int) Instance
- func (self Instance) SetProcessShortcutInput(enable bool) Instance
- func (self Instance) SetProcessThreadGroup(value Node.ProcessThreadGroup) Instance
- func (self Instance) SetProcessThreadGroupOrder(value int) Instance
- func (self Instance) SetProcessThreadMessages(value Node.ProcessThreadMessages) Instance
- func (self Instance) SetProcessUnhandledInput(enable bool) Instance
- func (self Instance) SetProcessUnhandledKeyInput(enable bool) Instance
- func (self Instance) SetSceneFilePath(value string) Instance
- func (self Instance) SetSceneInstanceLoadPlaceholder(load_placeholder bool) Instance
- func (self Instance) SetThreadSafe(property string, value any) Instance
- func (self Instance) SetTranslationDomainInherited() Instance
- func (self Instance) SetUniqueNameInOwner(value bool) Instance
- func (self Instance) UniqueNameInOwner() bool
- func (self Instance) UpdateConfigurationWarnings()
- func (self Instance) Virtual(name string) reflect.Value
- type Singleton
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Advanced ¶
type Advanced = class
Advanced exposes a 1:1 low-level instance of the class, undocumented, for those who know what they are doing.
type Extension ¶
Extension can be embedded in a new struct to create a Go extension of this class.
T must be a type that is embedding this Extension as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.
func (*Extension[T]) AddResource ¶
func (*Extension[T]) AsObject ¶
func (o *Extension[T]) AsObject() [1]gdreference.Object
func (*Extension[T]) AsResourcePreloader ¶
func (*Extension[T]) AutoTranslateMode ¶
func (o *Extension[T]) AutoTranslateMode() Node.AutoTranslateMode
func (*Extension[T]) CanAutoTranslate ¶
CanAutoTranslate is promoted from Node.Instance.CanAutoTranslate.
func (*Extension[T]) CanProcess ¶
CanProcess is promoted from Node.Instance.CanProcess.
func (*Extension[T]) CreateTween ¶
CreateTween is promoted from Node.Instance.CreateTween.
func (*Extension[T]) EditorDescription ¶
func (*Extension[T]) FindParent ¶
FindParent is promoted from Node.Instance.FindParent.
func (*Extension[T]) GetAccessibilityElement ¶
func (o *Extension[T]) GetAccessibilityElement() RID.AccessibilityElement
GetAccessibilityElement is promoted from Node.Instance.GetAccessibilityElement.
func (*Extension[T]) GetGroups ¶
GetGroups is promoted from Node.Instance.GetGroups.
func (*Extension[T]) GetMultiplayerAuthority ¶
GetMultiplayerAuthority is promoted from Node.Instance.GetMultiplayerAuthority.
func (*Extension[T]) GetNode ¶
GetNode is promoted from Node.Instance.GetNode.
func (*Extension[T]) GetNodeOrNull ¶
GetNodeOrNull is promoted from Node.Instance.GetNodeOrNull.
func (*Extension[T]) GetNodeRpcConfig ¶
GetNodeRpcConfig is promoted from Node.Instance.GetNodeRpcConfig.
func (*Extension[T]) GetParent ¶
GetParent is promoted from Node.Instance.GetParent.
func (*Extension[T]) GetPath ¶
GetPath is promoted from Node.Instance.GetPath.
func (*Extension[T]) GetPhysicsProcessDeltaTime ¶
GetPhysicsProcessDeltaTime is promoted from Node.Instance.GetPhysicsProcessDeltaTime.
func (*Extension[T]) GetProcessDeltaTime ¶
GetProcessDeltaTime is promoted from Node.Instance.GetProcessDeltaTime.
func (*Extension[T]) GetResource ¶
func (*Extension[T]) GetResourceList ¶
func (*Extension[T]) GetSceneInstanceLoadPlaceholder ¶
GetSceneInstanceLoadPlaceholder is promoted from Node.Instance.GetSceneInstanceLoadPlaceholder.
func (*Extension[T]) GetTreeString ¶
GetTreeString is promoted from Node.Instance.GetTreeString.
func (*Extension[T]) GetTreeStringPretty ¶
GetTreeStringPretty is promoted from Node.Instance.GetTreeStringPretty.
func (*Extension[T]) HasNode ¶
HasNode is promoted from Node.Instance.HasNode.
func (*Extension[T]) HasNodeAndResource ¶
HasNodeAndResource is promoted from Node.Instance.HasNodeAndResource.
func (*Extension[T]) HasResource ¶
func (*Extension[T]) IsAncestorOf ¶
IsAncestorOf is promoted from Node.Instance.IsAncestorOf.
func (*Extension[T]) IsDisplayedFolded ¶
IsDisplayedFolded is promoted from Node.Instance.IsDisplayedFolded.
func (*Extension[T]) IsEditableInstance ¶
IsEditableInstance is promoted from Node.Instance.IsEditableInstance.
func (*Extension[T]) IsGreaterThan ¶
IsGreaterThan is promoted from Node.Instance.IsGreaterThan.
func (*Extension[T]) IsInGroup ¶
IsInGroup is promoted from Node.Instance.IsInGroup.
func (*Extension[T]) IsInsideTree ¶
IsInsideTree is promoted from Node.Instance.IsInsideTree.
func (*Extension[T]) IsMultiplayerAuthority ¶
IsMultiplayerAuthority is promoted from Node.Instance.IsMultiplayerAuthority.
func (*Extension[T]) IsNodeReady ¶
IsNodeReady is promoted from Node.Instance.IsNodeReady.
func (*Extension[T]) IsPartOfEditedScene ¶
IsPartOfEditedScene is promoted from Node.Instance.IsPartOfEditedScene.
func (*Extension[T]) IsPhysicsInterpolated ¶
IsPhysicsInterpolated is promoted from Node.Instance.IsPhysicsInterpolated.
func (*Extension[T]) IsPhysicsInterpolatedAndEnabled ¶
IsPhysicsInterpolatedAndEnabled is promoted from Node.Instance.IsPhysicsInterpolatedAndEnabled.
func (*Extension[T]) IsPhysicsProcessing ¶
IsPhysicsProcessing is promoted from Node.Instance.IsPhysicsProcessing.
func (*Extension[T]) IsPhysicsProcessingInternal ¶
IsPhysicsProcessingInternal is promoted from Node.Instance.IsPhysicsProcessingInternal.
func (*Extension[T]) IsProcessing ¶
IsProcessing is promoted from Node.Instance.IsProcessing.
func (*Extension[T]) IsProcessingInput ¶
IsProcessingInput is promoted from Node.Instance.IsProcessingInput.
func (*Extension[T]) IsProcessingInternal ¶
IsProcessingInternal is promoted from Node.Instance.IsProcessingInternal.
func (*Extension[T]) IsProcessingShortcutInput ¶
IsProcessingShortcutInput is promoted from Node.Instance.IsProcessingShortcutInput.
func (*Extension[T]) IsProcessingUnhandledInput ¶
IsProcessingUnhandledInput is promoted from Node.Instance.IsProcessingUnhandledInput.
func (*Extension[T]) IsProcessingUnhandledKeyInput ¶
IsProcessingUnhandledKeyInput is promoted from Node.Instance.IsProcessingUnhandledKeyInput.
func (*Extension[T]) MoveChild ¶
MoveChild is promoted from Node.Instance.MoveChild.
func (*Extension[T]) Multiplayer ¶
func (o *Extension[T]) Multiplayer() MultiplayerAPI.Instance
func (*Extension[T]) NotifyDeferredThreadGroup ¶
NotifyDeferredThreadGroup is promoted from Node.Instance.NotifyDeferredThreadGroup.
func (*Extension[T]) NotifyThreadSafe ¶
NotifyThreadSafe is promoted from Node.Instance.NotifyThreadSafe.
func (*Extension[T]) OnChildEnteredTree ¶
func (o *Extension[T]) OnChildEnteredTree(cb func(node Node.Instance), flags ...Signal.Flags) *Extension[T]
OnChildEnteredTree is promoted from Node.Instance.OnChildEnteredTree.
func (*Extension[T]) OnChildExitingTree ¶
func (o *Extension[T]) OnChildExitingTree(cb func(node Node.Instance), flags ...Signal.Flags) *Extension[T]
OnChildExitingTree is promoted from Node.Instance.OnChildExitingTree.
func (*Extension[T]) OnChildOrderChanged ¶
OnChildOrderChanged is promoted from Node.Instance.OnChildOrderChanged.
func (*Extension[T]) OnEditorDescriptionChanged ¶
func (o *Extension[T]) OnEditorDescriptionChanged(cb func(node Node.Instance), flags ...Signal.Flags) *Extension[T]
OnEditorDescriptionChanged is promoted from Node.Instance.OnEditorDescriptionChanged.
func (*Extension[T]) OnEditorStateChanged ¶
OnEditorStateChanged is promoted from Node.Instance.OnEditorStateChanged.
func (*Extension[T]) OnReady ¶
OnReady is promoted from Node.Instance.OnReady.
func (*Extension[T]) OnRenamed ¶
OnRenamed is promoted from Node.Instance.OnRenamed.
func (*Extension[T]) OnReplacingBy ¶
func (o *Extension[T]) OnReplacingBy(cb func(node Node.Instance), flags ...Signal.Flags) *Extension[T]
OnReplacingBy is promoted from Node.Instance.OnReplacingBy.
func (*Extension[T]) OnTreeEntered ¶
OnTreeEntered is promoted from Node.Instance.OnTreeEntered.
func (*Extension[T]) OnTreeExited ¶
OnTreeExited is promoted from Node.Instance.OnTreeExited.
func (*Extension[T]) OnTreeExiting ¶
OnTreeExiting is promoted from Node.Instance.OnTreeExiting.
func (*Extension[T]) PhysicsInterpolationMode ¶
func (o *Extension[T]) PhysicsInterpolationMode() Node.PhysicsInterpolationMode
func (*Extension[T]) PrintTree ¶
func (o *Extension[T]) PrintTree()
PrintTree is promoted from Node.Instance.PrintTree.
func (*Extension[T]) PrintTreePretty ¶
func (o *Extension[T]) PrintTreePretty()
PrintTreePretty is promoted from Node.Instance.PrintTreePretty.
func (*Extension[T]) ProcessMode ¶
func (o *Extension[T]) ProcessMode() Node.ProcessMode
func (*Extension[T]) ProcessPhysicsPriority ¶
func (*Extension[T]) ProcessPriority ¶
func (*Extension[T]) ProcessThreadGroup ¶
func (o *Extension[T]) ProcessThreadGroup() Node.ProcessThreadGroup
func (*Extension[T]) ProcessThreadGroupOrder ¶
func (*Extension[T]) ProcessThreadMessages ¶
func (o *Extension[T]) ProcessThreadMessages() Node.ProcessThreadMessages
func (*Extension[T]) PropagateNotification ¶
PropagateNotification is promoted from Node.Instance.PropagateNotification.
func (*Extension[T]) QueueAccessibilityUpdate ¶
func (o *Extension[T]) QueueAccessibilityUpdate()
QueueAccessibilityUpdate is promoted from Node.Instance.QueueAccessibilityUpdate.
func (*Extension[T]) QueueFree ¶
func (o *Extension[T]) QueueFree()
QueueFree is promoted from Node.Instance.QueueFree.
func (*Extension[T]) RemoveChild ¶
RemoveChild is promoted from Node.Instance.RemoveChild.
func (*Extension[T]) RemoveFromGroup ¶
RemoveFromGroup is promoted from Node.Instance.RemoveFromGroup.
func (*Extension[T]) RemoveResource ¶
func (*Extension[T]) RenameResource ¶
func (*Extension[T]) RequestReady ¶
func (o *Extension[T]) RequestReady()
RequestReady is promoted from Node.Instance.RequestReady.
func (*Extension[T]) ResetPhysicsInterpolation ¶
func (o *Extension[T]) ResetPhysicsInterpolation()
ResetPhysicsInterpolation is promoted from Node.Instance.ResetPhysicsInterpolation.
func (*Extension[T]) RpcConfig ¶
RpcConfig is promoted from Node.Instance.RpcConfig.
func (*Extension[T]) SceneFilePath ¶
func (*Extension[T]) SetAutoTranslateMode ¶
func (o *Extension[T]) SetAutoTranslateMode(value Node.AutoTranslateMode) *Extension[T]
func (*Extension[T]) SetDeferredThreadGroup ¶
SetDeferredThreadGroup is promoted from Node.Instance.SetDeferredThreadGroup.
func (*Extension[T]) SetDisplayFolded ¶
SetDisplayFolded is promoted from Node.Instance.SetDisplayFolded.
func (*Extension[T]) SetEditableInstance ¶
SetEditableInstance is promoted from Node.Instance.SetEditableInstance.
func (*Extension[T]) SetEditorDescription ¶
func (*Extension[T]) SetPhysicsInterpolationMode ¶
func (o *Extension[T]) SetPhysicsInterpolationMode(value Node.PhysicsInterpolationMode) *Extension[T]
func (*Extension[T]) SetPhysicsProcess ¶
SetPhysicsProcess is promoted from Node.Instance.SetPhysicsProcess.
func (*Extension[T]) SetPhysicsProcessInternal ¶
SetPhysicsProcessInternal is promoted from Node.Instance.SetPhysicsProcessInternal.
func (*Extension[T]) SetProcess ¶
SetProcess is promoted from Node.Instance.SetProcess.
func (*Extension[T]) SetProcessInput ¶
SetProcessInput is promoted from Node.Instance.SetProcessInput.
func (*Extension[T]) SetProcessInternal ¶
SetProcessInternal is promoted from Node.Instance.SetProcessInternal.
func (*Extension[T]) SetProcessMode ¶
func (o *Extension[T]) SetProcessMode(value Node.ProcessMode) *Extension[T]
func (*Extension[T]) SetProcessPhysicsPriority ¶
func (*Extension[T]) SetProcessPriority ¶
func (*Extension[T]) SetProcessShortcutInput ¶
SetProcessShortcutInput is promoted from Node.Instance.SetProcessShortcutInput.
func (*Extension[T]) SetProcessThreadGroup ¶
func (o *Extension[T]) SetProcessThreadGroup(value Node.ProcessThreadGroup) *Extension[T]
func (*Extension[T]) SetProcessThreadGroupOrder ¶
func (*Extension[T]) SetProcessThreadMessages ¶
func (o *Extension[T]) SetProcessThreadMessages(value Node.ProcessThreadMessages) *Extension[T]
func (*Extension[T]) SetProcessUnhandledInput ¶
SetProcessUnhandledInput is promoted from Node.Instance.SetProcessUnhandledInput.
func (*Extension[T]) SetProcessUnhandledKeyInput ¶
SetProcessUnhandledKeyInput is promoted from Node.Instance.SetProcessUnhandledKeyInput.
func (*Extension[T]) SetSceneFilePath ¶
func (*Extension[T]) SetSceneInstanceLoadPlaceholder ¶
SetSceneInstanceLoadPlaceholder is promoted from Node.Instance.SetSceneInstanceLoadPlaceholder.
func (*Extension[T]) SetThreadSafe ¶
SetThreadSafe is promoted from Node.Instance.SetThreadSafe.
func (*Extension[T]) SetTranslationDomainInherited ¶
SetTranslationDomainInherited is promoted from Node.Instance.SetTranslationDomainInherited.
func (*Extension[T]) SetUniqueNameInOwner ¶
func (*Extension[T]) UniqueNameInOwner ¶
func (*Extension[T]) UpdateConfigurationWarnings ¶
func (o *Extension[T]) UpdateConfigurationWarnings()
UpdateConfigurationWarnings is promoted from Node.Instance.UpdateConfigurationWarnings.
type ID ¶
ID is a typed object ID (reference) to an instance of this class, use it to store references to objects with unknown lifetimes, as an ID will not panic on use if the underlying object has been destroyed.
type Instance ¶
type Instance [1]gdclass.ResourcePreloader
Instance of the class with convieniently typed arguments and results.
var Nil Instance
Nil is a nil/null instance of the class. Equivalent to the zero value.
func (Instance) AddResource ¶
func (Instance) AsObject ¶
func (o Instance) AsObject() [1]gdreference.Object
func (Instance) AsResourcePreloader ¶
func (Instance) AutoTranslateMode ¶
func (self Instance) AutoTranslateMode() Node.AutoTranslateMode
AutoTranslateMode is promoted from Node.Instance.AutoTranslateMode.
func (Instance) CanAutoTranslate ¶
CanAutoTranslate is promoted from Node.Instance.CanAutoTranslate.
func (Instance) CanProcess ¶
CanProcess is promoted from Node.Instance.CanProcess.
func (Instance) CreateTween ¶
CreateTween is promoted from Node.Instance.CreateTween.
func (Instance) EditorDescription ¶
EditorDescription is promoted from Node.Instance.EditorDescription.
func (Instance) FindParent ¶
FindParent is promoted from Node.Instance.FindParent.
func (Instance) GetAccessibilityElement ¶
func (self Instance) GetAccessibilityElement() RID.AccessibilityElement
GetAccessibilityElement is promoted from Node.Instance.GetAccessibilityElement.
func (Instance) GetGroups ¶
GetGroups is promoted from Node.Instance.GetGroups.
func (Instance) GetMultiplayerAuthority ¶
GetMultiplayerAuthority is promoted from Node.Instance.GetMultiplayerAuthority.
func (Instance) GetNode ¶
GetNode is promoted from Node.Instance.GetNode.
func (Instance) GetNodeOrNull ¶
GetNodeOrNull is promoted from Node.Instance.GetNodeOrNull.
func (Instance) GetNodeRpcConfig ¶
GetNodeRpcConfig is promoted from Node.Instance.GetNodeRpcConfig.
func (Instance) GetParent ¶
GetParent is promoted from Node.Instance.GetParent.
func (Instance) GetPath ¶
GetPath is promoted from Node.Instance.GetPath.
func (Instance) GetPhysicsProcessDeltaTime ¶
GetPhysicsProcessDeltaTime is promoted from Node.Instance.GetPhysicsProcessDeltaTime.
func (Instance) GetProcessDeltaTime ¶
GetProcessDeltaTime is promoted from Node.Instance.GetProcessDeltaTime.
func (Instance) GetResourceList ¶
func (Instance) GetSceneInstanceLoadPlaceholder ¶
GetSceneInstanceLoadPlaceholder is promoted from Node.Instance.GetSceneInstanceLoadPlaceholder.
func (Instance) GetTreeString ¶
GetTreeString is promoted from Node.Instance.GetTreeString.
func (Instance) GetTreeStringPretty ¶
GetTreeStringPretty is promoted from Node.Instance.GetTreeStringPretty.
func (Instance) HasNode ¶
HasNode is promoted from Node.Instance.HasNode.
func (Instance) HasNodeAndResource ¶
HasNodeAndResource is promoted from Node.Instance.HasNodeAndResource.
func (Instance) HasResource ¶
func (Instance) IsAncestorOf ¶
IsAncestorOf is promoted from Node.Instance.IsAncestorOf.
func (Instance) IsDisplayedFolded ¶
IsDisplayedFolded is promoted from Node.Instance.IsDisplayedFolded.
func (Instance) IsEditableInstance ¶
IsEditableInstance is promoted from Node.Instance.IsEditableInstance.
func (Instance) IsGreaterThan ¶
IsGreaterThan is promoted from Node.Instance.IsGreaterThan.
func (Instance) IsInGroup ¶
IsInGroup is promoted from Node.Instance.IsInGroup.
func (Instance) IsInsideTree ¶
IsInsideTree is promoted from Node.Instance.IsInsideTree.
func (Instance) IsMultiplayerAuthority ¶
IsMultiplayerAuthority is promoted from Node.Instance.IsMultiplayerAuthority.
func (Instance) IsNodeReady ¶
IsNodeReady is promoted from Node.Instance.IsNodeReady.
func (Instance) IsPartOfEditedScene ¶
IsPartOfEditedScene is promoted from Node.Instance.IsPartOfEditedScene.
func (Instance) IsPhysicsInterpolated ¶
IsPhysicsInterpolated is promoted from Node.Instance.IsPhysicsInterpolated.
func (Instance) IsPhysicsInterpolatedAndEnabled ¶
IsPhysicsInterpolatedAndEnabled is promoted from Node.Instance.IsPhysicsInterpolatedAndEnabled.
func (Instance) IsPhysicsProcessing ¶
IsPhysicsProcessing is promoted from Node.Instance.IsPhysicsProcessing.
func (Instance) IsPhysicsProcessingInternal ¶
IsPhysicsProcessingInternal is promoted from Node.Instance.IsPhysicsProcessingInternal.
func (Instance) IsProcessing ¶
IsProcessing is promoted from Node.Instance.IsProcessing.
func (Instance) IsProcessingInput ¶
IsProcessingInput is promoted from Node.Instance.IsProcessingInput.
func (Instance) IsProcessingInternal ¶
IsProcessingInternal is promoted from Node.Instance.IsProcessingInternal.
func (Instance) IsProcessingShortcutInput ¶
IsProcessingShortcutInput is promoted from Node.Instance.IsProcessingShortcutInput.
func (Instance) IsProcessingUnhandledInput ¶
IsProcessingUnhandledInput is promoted from Node.Instance.IsProcessingUnhandledInput.
func (Instance) IsProcessingUnhandledKeyInput ¶
IsProcessingUnhandledKeyInput is promoted from Node.Instance.IsProcessingUnhandledKeyInput.
func (Instance) MoveChild ¶
MoveChild is promoted from Node.Instance.MoveChild.
func (Instance) Multiplayer ¶
func (self Instance) Multiplayer() MultiplayerAPI.Instance
Multiplayer is promoted from Node.Instance.Multiplayer.
func (Instance) NotifyDeferredThreadGroup ¶
NotifyDeferredThreadGroup is promoted from Node.Instance.NotifyDeferredThreadGroup.
func (Instance) NotifyThreadSafe ¶
NotifyThreadSafe is promoted from Node.Instance.NotifyThreadSafe.
func (Instance) OnChildEnteredTree ¶
func (self Instance) OnChildEnteredTree(cb func(node Node.Instance), flags ...Signal.Flags) Instance
OnChildEnteredTree is promoted from Node.Instance.OnChildEnteredTree.
func (Instance) OnChildExitingTree ¶
func (self Instance) OnChildExitingTree(cb func(node Node.Instance), flags ...Signal.Flags) Instance
OnChildExitingTree is promoted from Node.Instance.OnChildExitingTree.
func (Instance) OnChildOrderChanged ¶
OnChildOrderChanged is promoted from Node.Instance.OnChildOrderChanged.
func (Instance) OnEditorDescriptionChanged ¶
func (self Instance) OnEditorDescriptionChanged(cb func(node Node.Instance), flags ...Signal.Flags) Instance
OnEditorDescriptionChanged is promoted from Node.Instance.OnEditorDescriptionChanged.
func (Instance) OnEditorStateChanged ¶
OnEditorStateChanged is promoted from Node.Instance.OnEditorStateChanged.
func (Instance) OnReady ¶
OnReady is promoted from Node.Instance.OnReady.
func (Instance) OnRenamed ¶
OnRenamed is promoted from Node.Instance.OnRenamed.
func (Instance) OnReplacingBy ¶
OnReplacingBy is promoted from Node.Instance.OnReplacingBy.
func (Instance) OnTreeEntered ¶
OnTreeEntered is promoted from Node.Instance.OnTreeEntered.
func (Instance) OnTreeExited ¶
OnTreeExited is promoted from Node.Instance.OnTreeExited.
func (Instance) OnTreeExiting ¶
OnTreeExiting is promoted from Node.Instance.OnTreeExiting.
func (Instance) Owner ¶
Owner is promoted from Node.Instance.Owner.
func (Instance) PhysicsInterpolationMode ¶
func (self Instance) PhysicsInterpolationMode() Node.PhysicsInterpolationMode
PhysicsInterpolationMode is promoted from Node.Instance.PhysicsInterpolationMode.
func (Instance) PrintTree ¶
func (self Instance) PrintTree()
PrintTree is promoted from Node.Instance.PrintTree.
func (Instance) PrintTreePretty ¶
func (self Instance) PrintTreePretty()
PrintTreePretty is promoted from Node.Instance.PrintTreePretty.
func (Instance) ProcessMode ¶
func (self Instance) ProcessMode() Node.ProcessMode
ProcessMode is promoted from Node.Instance.ProcessMode.
func (Instance) ProcessPhysicsPriority ¶
ProcessPhysicsPriority is promoted from Node.Instance.ProcessPhysicsPriority.
func (Instance) ProcessPriority ¶
ProcessPriority is promoted from Node.Instance.ProcessPriority.
func (Instance) ProcessThreadGroup ¶
func (self Instance) ProcessThreadGroup() Node.ProcessThreadGroup
ProcessThreadGroup is promoted from Node.Instance.ProcessThreadGroup.
func (Instance) ProcessThreadGroupOrder ¶
ProcessThreadGroupOrder is promoted from Node.Instance.ProcessThreadGroupOrder.
func (Instance) ProcessThreadMessages ¶
func (self Instance) ProcessThreadMessages() Node.ProcessThreadMessages
ProcessThreadMessages is promoted from Node.Instance.ProcessThreadMessages.
func (Instance) PropagateNotification ¶
PropagateNotification is promoted from Node.Instance.PropagateNotification.
func (Instance) QueueAccessibilityUpdate ¶
func (self Instance) QueueAccessibilityUpdate()
QueueAccessibilityUpdate is promoted from Node.Instance.QueueAccessibilityUpdate.
func (Instance) QueueFree ¶
func (self Instance) QueueFree()
QueueFree is promoted from Node.Instance.QueueFree.
func (Instance) RemoveChild ¶
RemoveChild is promoted from Node.Instance.RemoveChild.
func (Instance) RemoveFromGroup ¶
RemoveFromGroup is promoted from Node.Instance.RemoveFromGroup.
func (Instance) RemoveResource ¶
func (Instance) RenameResource ¶
func (Instance) RequestReady ¶
func (self Instance) RequestReady()
RequestReady is promoted from Node.Instance.RequestReady.
func (Instance) ResetPhysicsInterpolation ¶
func (self Instance) ResetPhysicsInterpolation()
ResetPhysicsInterpolation is promoted from Node.Instance.ResetPhysicsInterpolation.
func (Instance) RpcConfig ¶
RpcConfig is promoted from Node.Instance.RpcConfig.
func (Instance) SceneFilePath ¶
SceneFilePath is promoted from Node.Instance.SceneFilePath.
func (Instance) SetAutoTranslateMode ¶
func (self Instance) SetAutoTranslateMode(value Node.AutoTranslateMode) Instance
SetAutoTranslateMode is promoted from Node.Instance.SetAutoTranslateMode.
func (Instance) SetDeferredThreadGroup ¶
SetDeferredThreadGroup is promoted from Node.Instance.SetDeferredThreadGroup.
func (Instance) SetDisplayFolded ¶
SetDisplayFolded is promoted from Node.Instance.SetDisplayFolded.
func (Instance) SetEditableInstance ¶
SetEditableInstance is promoted from Node.Instance.SetEditableInstance.
func (Instance) SetEditorDescription ¶
SetEditorDescription is promoted from Node.Instance.SetEditorDescription.
func (Instance) SetName ¶
SetName is promoted from Node.Instance.SetName.
func (Instance) SetOwner ¶
SetOwner is promoted from Node.Instance.SetOwner.
func (Instance) SetPhysicsInterpolationMode ¶
func (self Instance) SetPhysicsInterpolationMode(value Node.PhysicsInterpolationMode) Instance
SetPhysicsInterpolationMode is promoted from Node.Instance.SetPhysicsInterpolationMode.
func (Instance) SetPhysicsProcess ¶
SetPhysicsProcess is promoted from Node.Instance.SetPhysicsProcess.
func (Instance) SetPhysicsProcessInternal ¶
SetPhysicsProcessInternal is promoted from Node.Instance.SetPhysicsProcessInternal.
func (Instance) SetProcess ¶
SetProcess is promoted from Node.Instance.SetProcess.
func (Instance) SetProcessInput ¶
SetProcessInput is promoted from Node.Instance.SetProcessInput.
func (Instance) SetProcessInternal ¶
SetProcessInternal is promoted from Node.Instance.SetProcessInternal.
func (Instance) SetProcessMode ¶
func (self Instance) SetProcessMode(value Node.ProcessMode) Instance
SetProcessMode is promoted from Node.Instance.SetProcessMode.
func (Instance) SetProcessPhysicsPriority ¶
SetProcessPhysicsPriority is promoted from Node.Instance.SetProcessPhysicsPriority.
func (Instance) SetProcessPriority ¶
SetProcessPriority is promoted from Node.Instance.SetProcessPriority.
func (Instance) SetProcessShortcutInput ¶
SetProcessShortcutInput is promoted from Node.Instance.SetProcessShortcutInput.
func (Instance) SetProcessThreadGroup ¶
func (self Instance) SetProcessThreadGroup(value Node.ProcessThreadGroup) Instance
SetProcessThreadGroup is promoted from Node.Instance.SetProcessThreadGroup.
func (Instance) SetProcessThreadGroupOrder ¶
SetProcessThreadGroupOrder is promoted from Node.Instance.SetProcessThreadGroupOrder.
func (Instance) SetProcessThreadMessages ¶
func (self Instance) SetProcessThreadMessages(value Node.ProcessThreadMessages) Instance
SetProcessThreadMessages is promoted from Node.Instance.SetProcessThreadMessages.
func (Instance) SetProcessUnhandledInput ¶
SetProcessUnhandledInput is promoted from Node.Instance.SetProcessUnhandledInput.
func (Instance) SetProcessUnhandledKeyInput ¶
SetProcessUnhandledKeyInput is promoted from Node.Instance.SetProcessUnhandledKeyInput.
func (Instance) SetSceneFilePath ¶
SetSceneFilePath is promoted from Node.Instance.SetSceneFilePath.
func (Instance) SetSceneInstanceLoadPlaceholder ¶
SetSceneInstanceLoadPlaceholder is promoted from Node.Instance.SetSceneInstanceLoadPlaceholder.
func (Instance) SetThreadSafe ¶
SetThreadSafe is promoted from Node.Instance.SetThreadSafe.
func (Instance) SetTranslationDomainInherited ¶
SetTranslationDomainInherited is promoted from Node.Instance.SetTranslationDomainInherited.
func (Instance) SetUniqueNameInOwner ¶
SetUniqueNameInOwner is promoted from Node.Instance.SetUniqueNameInOwner.
func (Instance) UniqueNameInOwner ¶
UniqueNameInOwner is promoted from Node.Instance.UniqueNameInOwner.
func (Instance) UpdateConfigurationWarnings ¶
func (self Instance) UpdateConfigurationWarnings()
UpdateConfigurationWarnings is promoted from Node.Instance.UpdateConfigurationWarnings.
type Singleton ¶
Singleton can be embedded in a new struct to create a Go singleton extension of the class.
It will become available as a global inside scripts and any any other Go Extension types will have any *T typed fields filled in to point at this singleton once they have been instantiated.
T must be a type that is embedding this Singleton as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.