Documentation
¶
Index ¶
- Constants
- func AddId(id Resource.UID, path string)
- func Advanced() class
- func CreateId() int
- func CreateIdForPath(path string) int
- func EnsurePath(path_or_uid string) string
- func GetIdPath(id Resource.UID) string
- func HasId(id Resource.UID) bool
- func IdToText(id Resource.UID) string
- func PathToUid(path string) string
- func RemoveId(id Resource.UID)
- func SetId(id Resource.UID, path string)
- func TextToId(text_id string) int
- func UidToPath(uid string) string
- type Extension
- type ID
- type Instance
- type Singleton
Constants ¶
const InvalidId Resource.UID = -1 //gd:ResourceUID.INVALID_ID
Variables ¶
This section is empty.
Functions ¶
func Advanced ¶
func Advanced() class
Advanced exposes a 1:1 low-level instance of the class, undocumented, for those who know what they are doing.
func CreateIdForPath ¶
func EnsurePath ¶
Types ¶
type Extension ¶
Extension can be embedded in a new struct to create a Go extension of this class.
T must be a type that is embedding this Extension as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.
func (*Extension[T]) AsObject ¶
func (o *Extension[T]) AsObject() [1]gdreference.Object
type ID ¶
ID is a typed object ID (reference) to an instance of this class, use it to store references to objects with unknown lifetimes, as an ID will not panic on use if the underlying object has been destroyed.
type Instance ¶
type Instance [1]gdclass.ResourceUID
Instance of the class with convieniently typed arguments and results.
func (Instance) AsObject ¶
func (o Instance) AsObject() [1]gdreference.Object
type Singleton ¶
Singleton can be embedded in a new struct to create a Go singleton extension of the class.
It will become available as a global inside scripts and any any other Go Extension types will have any *T typed fields filled in to point at this singleton once they have been instantiated.
T must be a type that is embedding this Singleton as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.