Documentation
¶
Index ¶
- type Advanced
- type Any
- type Extension
- func (o *Extension[T]) AsObject() [1]gdreference.Object
- func (o *Extension[T]) AsRefCounted() ie.RC
- func (o *Extension[T]) AsResource() Resource.Instance
- func (o *Extension[T]) AsVisualShaderNode() VisualShaderNode.Instance
- func (o *Extension[T]) AsVisualShaderNodeInput() Instance
- func (o *Extension[T]) ClearDefaultInputValues()
- func (o *Extension[T]) DefaultInputValues() []any
- func (o *Extension[T]) EmitChanged()
- func (o *Extension[T]) GetDefaultInputPort(atype VisualShaderNode.PortType) int
- func (o *Extension[T]) GetIdForPath(path string) string
- func (o *Extension[T]) GetInputPortDefaultValue(port int) any
- func (o *Extension[T]) GetInputRealName() string
- func (o *Extension[T]) GetRid() Resource.ID
- func (o *Extension[T]) InputName() string
- func (o *Extension[T]) IsBuiltIn() bool
- func (o *Extension[T]) LinkedParentGraphFrame() int
- func (o *Extension[T]) OnChanged(cb func(), flags ...Signal.Flags) *Extension[T]
- func (o *Extension[T]) OnInputTypeChanged(cb func(), flags ...Signal.Flags) *Extension[T]
- func (o *Extension[T]) OnSetupLocalToSceneRequested(cb func(), flags ...Signal.Flags) *Extension[T]
- func (o *Extension[T]) OutputPortForPreview() int
- func (o *Extension[T]) RemoveInputPortDefaultValue(port int)
- func (o *Extension[T]) ResetState()
- func (o *Extension[T]) ResourceLocalToScene() bool
- func (o *Extension[T]) ResourceName() string
- func (o *Extension[T]) ResourcePath() string
- func (o *Extension[T]) ResourceSceneUniqueId() string
- func (o *Extension[T]) SetDefaultInputValues(value []any) *Extension[T]
- func (o *Extension[T]) SetIdForPath(path string, id string) *Extension[T]
- func (o *Extension[T]) SetInputName(value string) *Extension[T]
- func (o *Extension[T]) SetLinkedParentGraphFrame(value int) *Extension[T]
- func (o *Extension[T]) SetOutputPortForPreview(value int) *Extension[T]
- func (o *Extension[T]) SetPathCache(path string) *Extension[T]
- func (o *Extension[T]) SetResourceLocalToScene(value bool) *Extension[T]
- func (o *Extension[T]) SetResourceName(value string) *Extension[T]
- func (o *Extension[T]) SetResourcePath(value string) *Extension[T]
- func (o *Extension[T]) SetResourceSceneUniqueId(value string) *Extension[T]
- func (o *Extension[T]) SetupLocalToScene()
- func (o *Extension[T]) TakeOverPath(path string)
- type ID
- type Instance
- func (o Instance) AsObject() [1]gdreference.Object
- func (o Instance) AsRefCounted() ie.RC
- func (o Instance) AsResource() Resource.Instance
- func (o Instance) AsVisualShaderNode() VisualShaderNode.Instance
- func (o Instance) AsVisualShaderNodeInput() Instance
- func (self Instance) ClearDefaultInputValues()
- func (self Instance) DefaultInputValues() []any
- func (self Instance) EmitChanged()
- func (self Instance) GetDefaultInputPort(atype VisualShaderNode.PortType) int
- func (self Instance) GetIdForPath(path string) string
- func (self Instance) GetInputPortDefaultValue(port int) any
- func (self Instance) GetInputRealName() string
- func (self Instance) GetRid() Resource.ID
- func (self Instance) ID() ID
- func (self Instance) InputName() string
- func (self Instance) IsBuiltIn() bool
- func (self Instance) LinkedParentGraphFrame() int
- func (self Instance) OnChanged(cb func(), flags ...Signal.Flags) Instance
- func (self Instance) OnInputTypeChanged(cb func(), flags ...Signal.Flags) Instance
- func (self Instance) OnSetupLocalToSceneRequested(cb func(), flags ...Signal.Flags) Instance
- func (self Instance) OutputPortForPreview() int
- func (self Instance) RemoveInputPortDefaultValue(port int)
- func (self Instance) ResetState()
- func (self Instance) ResourceLocalToScene() bool
- func (self Instance) ResourceName() string
- func (self Instance) ResourcePath() string
- func (self Instance) ResourceSceneUniqueId() string
- func (self Instance) SetDefaultInputValues(value []any) Instance
- func (self Instance) SetIdForPath(path string, id string) Instance
- func (self Instance) SetInputName(value string) Instance
- func (self Instance) SetLinkedParentGraphFrame(value int) Instance
- func (self *Instance) SetObject(obj [1]gdreference.Object) bool
- func (self Instance) SetOutputPortForPreview(value int) Instance
- func (self Instance) SetPathCache(path string) Instance
- func (self Instance) SetResourceLocalToScene(value bool) Instance
- func (self Instance) SetResourceName(value string) Instance
- func (self Instance) SetResourcePath(value string) Instance
- func (self Instance) SetResourceSceneUniqueId(value string) Instance
- func (self Instance) SetupLocalToScene()
- func (self Instance) TakeOverPath(path string)
- func (self Instance) Virtual(name string) reflect.Value
- type Singleton
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Advanced ¶
type Advanced = class
Advanced exposes a 1:1 low-level instance of the class, undocumented, for those who know what they are doing.
type Extension ¶
Extension can be embedded in a new struct to create a Go extension of this class.
T must be a type that is embedding this Extension as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.
func (*Extension[T]) AsObject ¶
func (o *Extension[T]) AsObject() [1]gdreference.Object
func (*Extension[T]) AsRefCounted ¶
func (*Extension[T]) AsResource ¶
func (*Extension[T]) AsVisualShaderNode ¶
func (o *Extension[T]) AsVisualShaderNode() VisualShaderNode.Instance
func (*Extension[T]) AsVisualShaderNodeInput ¶
func (*Extension[T]) ClearDefaultInputValues ¶
func (o *Extension[T]) ClearDefaultInputValues()
ClearDefaultInputValues is promoted from VisualShaderNode.Instance.ClearDefaultInputValues.
func (*Extension[T]) DefaultInputValues ¶
func (*Extension[T]) EmitChanged ¶
func (o *Extension[T]) EmitChanged()
EmitChanged is promoted from Resource.Instance.EmitChanged.
func (*Extension[T]) GetDefaultInputPort ¶
func (o *Extension[T]) GetDefaultInputPort(atype VisualShaderNode.PortType) int
GetDefaultInputPort is promoted from VisualShaderNode.Instance.GetDefaultInputPort.
func (*Extension[T]) GetIdForPath ¶
GetIdForPath is promoted from Resource.Instance.GetIdForPath.
func (*Extension[T]) GetInputPortDefaultValue ¶
GetInputPortDefaultValue is promoted from VisualShaderNode.Instance.GetInputPortDefaultValue.
func (*Extension[T]) GetInputRealName ¶
func (*Extension[T]) GetRid ¶
GetRid is promoted from Resource.Instance.GetRid.
func (*Extension[T]) IsBuiltIn ¶
IsBuiltIn is promoted from Resource.Instance.IsBuiltIn.
func (*Extension[T]) LinkedParentGraphFrame ¶
func (*Extension[T]) OnChanged ¶
OnChanged is promoted from Resource.Instance.OnChanged.
func (*Extension[T]) OnInputTypeChanged ¶
func (*Extension[T]) OnSetupLocalToSceneRequested ¶
OnSetupLocalToSceneRequested is promoted from Resource.Instance.OnSetupLocalToSceneRequested.
func (*Extension[T]) OutputPortForPreview ¶
func (*Extension[T]) RemoveInputPortDefaultValue ¶
RemoveInputPortDefaultValue is promoted from VisualShaderNode.Instance.RemoveInputPortDefaultValue.
func (*Extension[T]) ResetState ¶
func (o *Extension[T]) ResetState()
ResetState is promoted from Resource.Instance.ResetState.
func (*Extension[T]) ResourceLocalToScene ¶
func (*Extension[T]) ResourceName ¶
func (*Extension[T]) ResourcePath ¶
func (*Extension[T]) ResourceSceneUniqueId ¶
func (*Extension[T]) SetDefaultInputValues ¶
func (*Extension[T]) SetIdForPath ¶
SetIdForPath is promoted from Resource.Instance.SetIdForPath.
func (*Extension[T]) SetInputName ¶
func (*Extension[T]) SetLinkedParentGraphFrame ¶
func (*Extension[T]) SetOutputPortForPreview ¶
func (*Extension[T]) SetPathCache ¶
SetPathCache is promoted from Resource.Instance.SetPathCache.
func (*Extension[T]) SetResourceLocalToScene ¶
func (*Extension[T]) SetResourceName ¶
func (*Extension[T]) SetResourcePath ¶
func (*Extension[T]) SetResourceSceneUniqueId ¶
func (*Extension[T]) SetupLocalToScene ¶
func (o *Extension[T]) SetupLocalToScene()
SetupLocalToScene is promoted from Resource.Instance.SetupLocalToScene.
func (*Extension[T]) TakeOverPath ¶
TakeOverPath is promoted from Resource.Instance.TakeOverPath.
type ID ¶
ID is a typed object ID (reference) to an instance of this class, use it to store references to objects with unknown lifetimes, as an ID will not panic on use if the underlying object has been destroyed.
type Instance ¶
type Instance [1]gdclass.VisualShaderNodeInput
Instance of the class with convieniently typed arguments and results.
var Nil Instance
Nil is a nil/null instance of the class. Equivalent to the zero value.
func (Instance) AsObject ¶
func (o Instance) AsObject() [1]gdreference.Object
func (Instance) AsRefCounted ¶
func (Instance) AsResource ¶
func (Instance) AsVisualShaderNode ¶
func (o Instance) AsVisualShaderNode() VisualShaderNode.Instance
func (Instance) AsVisualShaderNodeInput ¶
func (Instance) ClearDefaultInputValues ¶
func (self Instance) ClearDefaultInputValues()
ClearDefaultInputValues is promoted from VisualShaderNode.Instance.ClearDefaultInputValues.
func (Instance) DefaultInputValues ¶
DefaultInputValues is promoted from VisualShaderNode.Instance.DefaultInputValues.
func (Instance) EmitChanged ¶
func (self Instance) EmitChanged()
EmitChanged is promoted from Resource.Instance.EmitChanged.
func (Instance) GetDefaultInputPort ¶
func (self Instance) GetDefaultInputPort(atype VisualShaderNode.PortType) int
GetDefaultInputPort is promoted from VisualShaderNode.Instance.GetDefaultInputPort.
func (Instance) GetIdForPath ¶
GetIdForPath is promoted from Resource.Instance.GetIdForPath.
func (Instance) GetInputPortDefaultValue ¶
GetInputPortDefaultValue is promoted from VisualShaderNode.Instance.GetInputPortDefaultValue.
func (Instance) GetInputRealName ¶
func (Instance) GetRid ¶
GetRid is promoted from Resource.Instance.GetRid.
func (Instance) IsBuiltIn ¶
IsBuiltIn is promoted from Resource.Instance.IsBuiltIn.
func (Instance) LinkedParentGraphFrame ¶
LinkedParentGraphFrame is promoted from VisualShaderNode.Instance.LinkedParentGraphFrame.
func (Instance) OnChanged ¶
OnChanged is promoted from Resource.Instance.OnChanged.
func (Instance) OnInputTypeChanged ¶
func (Instance) OnSetupLocalToSceneRequested ¶
OnSetupLocalToSceneRequested is promoted from Resource.Instance.OnSetupLocalToSceneRequested.
func (Instance) OutputPortForPreview ¶
OutputPortForPreview is promoted from VisualShaderNode.Instance.OutputPortForPreview.
func (Instance) RemoveInputPortDefaultValue ¶
RemoveInputPortDefaultValue is promoted from VisualShaderNode.Instance.RemoveInputPortDefaultValue.
func (Instance) ResetState ¶
func (self Instance) ResetState()
ResetState is promoted from Resource.Instance.ResetState.
func (Instance) ResourceLocalToScene ¶
ResourceLocalToScene is promoted from Resource.Instance.ResourceLocalToScene.
func (Instance) ResourceName ¶
ResourceName is promoted from Resource.Instance.ResourceName.
func (Instance) ResourcePath ¶
ResourcePath is promoted from Resource.Instance.ResourcePath.
func (Instance) ResourceSceneUniqueId ¶
ResourceSceneUniqueId is promoted from Resource.Instance.ResourceSceneUniqueId.
func (Instance) SetDefaultInputValues ¶
SetDefaultInputValues is promoted from VisualShaderNode.Instance.SetDefaultInputValues.
func (Instance) SetIdForPath ¶
SetIdForPath is promoted from Resource.Instance.SetIdForPath.
func (Instance) SetInputName ¶
SetInputName sets the property returned by [GetInputName]. Returns the instance, so that property settings can be chained.
func (Instance) SetLinkedParentGraphFrame ¶
SetLinkedParentGraphFrame is promoted from VisualShaderNode.Instance.SetLinkedParentGraphFrame.
func (Instance) SetOutputPortForPreview ¶
SetOutputPortForPreview is promoted from VisualShaderNode.Instance.SetOutputPortForPreview.
func (Instance) SetPathCache ¶
SetPathCache is promoted from Resource.Instance.SetPathCache.
func (Instance) SetResourceLocalToScene ¶
SetResourceLocalToScene is promoted from Resource.Instance.SetResourceLocalToScene.
func (Instance) SetResourceName ¶
SetResourceName is promoted from Resource.Instance.SetResourceName.
func (Instance) SetResourcePath ¶
SetResourcePath is promoted from Resource.Instance.SetResourcePath.
func (Instance) SetResourceSceneUniqueId ¶
SetResourceSceneUniqueId is promoted from Resource.Instance.SetResourceSceneUniqueId.
func (Instance) SetupLocalToScene ¶
func (self Instance) SetupLocalToScene()
SetupLocalToScene is promoted from Resource.Instance.SetupLocalToScene.
func (Instance) TakeOverPath ¶
TakeOverPath is promoted from Resource.Instance.TakeOverPath.
type Singleton ¶
Singleton can be embedded in a new struct to create a Go singleton extension of the class.
It will become available as a global inside scripts and any any other Go Extension types will have any *T typed fields filled in to point at this singleton once they have been instantiated.
T must be a type that is embedding this Singleton as the first field. It is unsafe and invalid to use this type directly, or embedded in any other way.